@@ -39,8 +39,7 @@
 
 #include <string>
 #include <iosfwd>
-
-#include "SharedHandle.h"
+#include <memory>
 
 namespace aria2 {
 
@@ -51,7 +50,7 @@ private:
   std::string password_;
 public:
   AuthConfig();
-  AuthConfig(const std::string& user, const std::string& password);
+  AuthConfig(std::string user, std::string password);
   ~AuthConfig();
 
   // Don't allow copying
@@ -69,11 +68,13 @@ public:
   {
     return password_;
   }
+
+  static std::unique_ptr<AuthConfig> create
+  (std::string user, std::string password);
 };
 
-typedef SharedHandle<AuthConfig> AuthConfigHandle;
-
-std::ostream& operator<<(std::ostream& o, const AuthConfigHandle& authConfig);
+std::ostream& operator<<(std::ostream& o,
+                         const std::shared_ptr<AuthConfig>& authConfig);
 
 } // namespace aria2
 
