@@ -47,9 +47,10 @@ public:
 
   static const char NAME[];
 
-  static BtCancelMessage* create(const unsigned char* data, size_t dataLength);
+  static std::unique_ptr<BtCancelMessage> create
+  (const unsigned char* data, size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
