@@ -44,39 +44,34 @@ class ExtensionMessageFactory;
 class BtExtendedMessage:public SimpleBtMessage
 {
 private:
-  SharedHandle<ExtensionMessage> extensionMessage_;
+  std::unique_ptr<ExtensionMessage> extensionMessage_;
 
   size_t msgLength_;
 public:
-  BtExtendedMessage(const SharedHandle<ExtensionMessage>& extensionMessage =
-                    SharedHandle<ExtensionMessage>());
-  virtual ~BtExtendedMessage();
+  BtExtendedMessage(std::unique_ptr<ExtensionMessage> extensionMessage =
+                    std::unique_ptr<ExtensionMessage>{});
 
   static const uint8_t ID = 20;
 
   static const char NAME[];
 
-  static BtExtendedMessage* create
-  (const SharedHandle<ExtensionMessageFactory>& factory,
-   const SharedHandle<Peer>& peer,
+  static std::unique_ptr<BtExtendedMessage> create
+  (ExtensionMessageFactory* factory,
+   const std::shared_ptr<Peer>& peer,
    const unsigned char* data,
    size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
-  virtual unsigned char* createMessage();
+  virtual unsigned char* createMessage() CXX11_OVERRIDE;
 
-  virtual size_t getMessageLength();
+  virtual size_t getMessageLength() CXX11_OVERRIDE;
 
-  virtual bool sendPredicate() const;
+  virtual bool sendPredicate() const CXX11_OVERRIDE;
 
-  virtual std::string toString() const;
-
-  const SharedHandle<ExtensionMessage>& getExtensionMessage() const
-  {
-    return extensionMessage_;
-  }
+  virtual std::string toString() const CXX11_OVERRIDE;
 
+  const std::unique_ptr<ExtensionMessage>& getExtensionMessage() const;
 };
 
 } // namespace aria2
