@@ -39,7 +39,6 @@
 
 #include <string>
 
-#include "SharedHandle.h"
 #include "BtAbortOutstandingRequestEvent.h"
 #include "BtCancelSendingPieceEvent.h"
 #include "BtChokingEvent.h"
@@ -56,8 +55,6 @@ public:
 
   virtual ~BtMessage() {}
 
-  virtual bool isSendingInProgress() = 0;
-
   virtual bool isInvalidate() = 0;
 
   virtual bool isUploading() = 0;
@@ -84,8 +81,6 @@ public:
 
 };
 
-typedef SharedHandle<BtMessage> BtMessageHandle;
-
 } // namespace aria2
 
 #endif // D_BT_MESSAGE_H
