@@ -49,16 +49,16 @@ private:
   int32_t begin_;
   int32_t blockLength_;
   const unsigned char* data_;
-  SharedHandle<DownloadContext> downloadContext_;
-  SharedHandle<PeerStorage> peerStorage_;
+  DownloadContext* downloadContext_;
+  PeerStorage* peerStorage_;
 
   static size_t MESSAGE_HEADER_LENGTH;
 
-  bool checkPieceHash(const SharedHandle<Piece>& piece);
+  bool checkPieceHash(const std::shared_ptr<Piece>& piece);
 
-  void onNewPiece(const SharedHandle<Piece>& piece);
+  void onNewPiece(const std::shared_ptr<Piece>& piece);
 
-  void onWrongPiece(const SharedHandle<Piece>& piece);
+  void onWrongPiece(const std::shared_ptr<Piece>& piece);
 
   void pushPieceData(int64_t offset, int32_t length) const;
 public:
@@ -88,26 +88,27 @@ public:
 
   void setBlockLength(int32_t blockLength) { blockLength_ = blockLength; }
 
-  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);
+  void setDownloadContext(DownloadContext* downloadContext);
 
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+  void setPeerStorage(PeerStorage* peerStorage);
 
-  static BtPieceMessage* create(const unsigned char* data, size_t dataLength);
+  static std::unique_ptr<BtPieceMessage> create
+  (const unsigned char* data, size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
   void createMessageHeader(unsigned char* msgHeader) const;
 
   size_t getMessageHeaderLength();
 
-  virtual void send();
+  virtual void send() CXX11_OVERRIDE;
 
-  virtual std::string toString() const;
+  virtual std::string toString() const CXX11_OVERRIDE;
 
-  virtual void onChokingEvent(const BtChokingEvent& event);
+  virtual void onChokingEvent(const BtChokingEvent& event) CXX11_OVERRIDE;
 
   virtual void onCancelSendingPieceEvent
-  (const BtCancelSendingPieceEvent& event);
+  (const BtCancelSendingPieceEvent& event) CXX11_OVERRIDE;
 };
 
 } // namespace aria2
