@@ -48,44 +48,67 @@
 #include "DownloadContext.h"
 #include "download_helper.h"
 #include "fmt.h"
+#include "ValueBaseBencodeParser.h"
+#include "DiskWriter.h"
+#include "AbstractSingleDiskAdaptor.h"
+#include "BencodeDiskWriter.h"
 
 namespace aria2 {
 
 BtPostDownloadHandler::BtPostDownloadHandler()
 {
-  SharedHandle<RequestGroupCriteria> cri
+  std::shared_ptr<RequestGroupCriteria> cri
     (new ContentTypeRequestGroupCriteria
-     (DownloadHandlerConstants::getBtContentTypes().begin(),
-      DownloadHandlerConstants::getBtContentTypes().end(),
-      DownloadHandlerConstants::getBtExtensions().begin(),
-      DownloadHandlerConstants::getBtExtensions().end()));
+     (getBtContentTypes(), getBtExtensions()));
   setCriteria(cri);
 }
 
 BtPostDownloadHandler::~BtPostDownloadHandler() {}
 
 void BtPostDownloadHandler::getNextRequestGroups
-(std::vector<SharedHandle<RequestGroup> >& groups,
+(std::vector<std::shared_ptr<RequestGroup> >& groups,
  RequestGroup* requestGroup)
 {
   A2_LOG_INFO(fmt("Generating RequestGroups for Torrent file %s",
                   requestGroup->getFirstFilePath().c_str()));
-  std::string content;
-  try {
-    requestGroup->getPieceStorage()->getDiskAdaptor()->openExistingFile();
-    content = util::toString(requestGroup->getPieceStorage()->getDiskAdaptor());
-    requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();    
-  } catch(Exception& e) {
-    requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
-    throw;
+  std::unique_ptr<ValueBase> torrent;
+  if(requestGroup->inMemoryDownload()) {
+    auto& dw = static_cast<AbstractSingleDiskAdaptor*>
+      (requestGroup->getPieceStorage()->getDiskAdaptor().get())
+      ->getDiskWriter();
+    auto bdw = static_cast<bittorrent::BencodeDiskWriter*>(dw.get());
+    int error = bdw->finalize();
+    if(error == 0) {
+      torrent = bdw->getResult();
+    }
+  } else {
+    std::string content;
+    try {
+      requestGroup->getPieceStorage()->getDiskAdaptor()->openExistingFile();
+      content = util::toString(requestGroup->getPieceStorage()
+                               ->getDiskAdaptor());
+      requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
+    } catch(Exception& e) {
+      requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
+      throw;
+    }
+    ssize_t error;
+    torrent = bittorrent::ValueBaseBencodeParser().parseFinal
+      (content.c_str(), content.size(), error);
   }
-  std::vector<SharedHandle<RequestGroup> > newRgs;
+  if(!torrent) {
+    throw DL_ABORT_EX2("Could not parse BitTorrent metainfo",
+                       error_code::BENCODE_PARSE_ERROR);
+  }
+  std::vector<std::shared_ptr<RequestGroup> > newRgs;
   createRequestGroupForBitTorrent(newRgs, requestGroup->getOption(),
                                   std::vector<std::string>(),
-                                  content);
+                                  "",
+                                  torrent.get());
   requestGroup->followedBy(newRgs.begin(), newRgs.end());
-  SharedHandle<MetadataInfo> mi =
-    createMetadataInfoFromFirstFileEntry(requestGroup->getDownloadContext());
+  std::shared_ptr<MetadataInfo> mi =
+    createMetadataInfoFromFirstFileEntry(requestGroup->getGroupId(),
+                                         requestGroup->getDownloadContext());
   if(mi) {
     setMetadataInfo(newRgs.begin(), newRgs.end(), mi);
   }
