@@ -40,8 +40,6 @@
 #include <string>
 #include <vector>
 
-#include "SharedHandle.h"
-
 namespace aria2 {
 
 class ChunkChecksum {
@@ -65,8 +63,8 @@ public:
   size_t countPieceHash() const;
 
   const std::string& getPieceHash(size_t index) const;
-  
-  void setPieceHashes(const std::vector<std::string>& pieceHashes);
+
+  void setPieceHashes(std::vector<std::string> pieceHashes);
   const std::vector<std::string>& getPieceHashes() const
   {
     return pieceHashes_;
