@@ -39,6 +39,7 @@
 
 #include <string>
 #include <functional>
+#include <memory>
 
 #include "TimerA2.h"
 
@@ -62,15 +63,16 @@ private:
 
   time_t summaryInterval_;
 
-  SharedHandle<SizeFormatter> sizeFormatter_;
+  std::shared_ptr<SizeFormatter> sizeFormatter_;
   bool readoutVisibility_;
   bool truncate_;
+  bool isTTY_;
 public:
   ConsoleStatCalc(time_t summaryInterval, bool humanReadable = true);
 
   virtual ~ConsoleStatCalc() {}
 
-  virtual void calculateStat(const DownloadEngine* e);
+  virtual void calculateStat(const DownloadEngine* e) CXX11_OVERRIDE;
 
   void setReadoutVisibility(bool visibility)
   {
