@@ -109,7 +109,7 @@ void showMetalinkFile
 } // namespace
 #endif // ENABLE_METALINK
 
-#if defined ENABLE_BITTORRENT || defined ENABLE_METALINK
+#if defined(ENABLE_BITTORRENT) || defined(ENABLE_METALINK)
 namespace {
 void showFiles
 (const std::vector<std::string>& uris, const std::shared_ptr<Option>& op)
@@ -161,7 +161,7 @@ Context::Context(bool standalone,
       throw DL_ABORT_EX("Option processing failed");
     }
   }
-  SimpleRandomizer::init();
+  SimpleRandomizer::getInstance()->init();
 #ifdef ENABLE_BITTORRENT
   bittorrent::generateStaticPeerId(op->get(PREF_PEER_ID_PREFIX));
 #endif // ENABLE_BITTORRENT
@@ -221,7 +221,7 @@ Context::Context(bool standalone,
         } else {
           createRequestGroupForUriList(requestGroups, op);
         }
-#if defined ENABLE_BITTORRENT || defined ENABLE_METALINK
+#if defined(ENABLE_BITTORRENT) || defined(ENABLE_METALINK)
       } else if(op->get(PREF_SHOW_FILES) == A2_V_TRUE) {
         showFiles(args, op);
         return;
