@@ -34,9 +34,7 @@
 /* copyright --> */
 #include "DHTAutoSaveCommand.h"
 
-#include <cerrno>
 #include <cstring>
-#include <fstream>
 
 #include "DHTRoutingTable.h"
 #include "DHTNode.h"
@@ -44,30 +42,35 @@
 #include "DHTRoutingTableSerializer.h"
 #include "RecoverableException.h"
 #include "DownloadEngine.h"
-#include "util.h"
 #include "DHTBucket.h"
 #include "RequestGroupMan.h"
 #include "prefs.h"
 #include "Option.h"
 #include "message.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "a2functional.h"
 #include "FileEntry.h"
 #include "DlAbortEx.h"
-#include "StringFormat.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-DHTAutoSaveCommand::DHTAutoSaveCommand(int32_t cuid, DownloadEngine* e, time_t interval):
-  TimeBasedCommand(cuid, e, interval) {}
+DHTAutoSaveCommand::DHTAutoSaveCommand
+(cuid_t cuid, DownloadEngine* e, int family, time_t interval)
+  : TimeBasedCommand{cuid, e, interval},
+    family_{family},
+    routingTable_{nullptr}
+{}
 
 DHTAutoSaveCommand::~DHTAutoSaveCommand() {}
 
 void DHTAutoSaveCommand::preProcess()
 {
-  if(_e->_requestGroupMan->downloadFinished() || _e->isHaltRequested()) {
+  if(getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
+     getDownloadEngine()->isHaltRequested()) {
     save();
-    _exit = true;
+    enableExit();
   }
 }
 
@@ -78,69 +81,49 @@ void DHTAutoSaveCommand::process()
 
 void DHTAutoSaveCommand::save()
 {
-  std::string dhtFile = _e->option->get(PREF_DHT_FILE_PATH);
-  logger->info("Saving DHT routing table to %s.", dhtFile.c_str());
+  std::string dhtFile =
+    getDownloadEngine()->getOption()->
+    get(family_ == AF_INET? PREF_DHT_FILE_PATH : PREF_DHT_FILE_PATH6);
+  A2_LOG_INFO(fmt("Saving DHT routing table to %s.", dhtFile.c_str()));
 
-  std::string tempFile = dhtFile;
-  tempFile += "__temp";
-  {
-    File f(tempFile);
-    if(!f.isFile()) {
-      File dir(f.getDirname());
-      if(!dir.exists()) {
-        if(!dir.mkdirs()) {
-          logger->info(EX_MAKE_DIR, dir.getPath().c_str(), strerror(errno));
-          return;
-        }
-      } else if(!dir.isDir()) {
-        logger->info(EX_NOT_DIRECTORY, dir.getPath().c_str());
-        return;
-      }
-    }
-  }
-  std::deque<SharedHandle<DHTNode> > nodes;
-  std::deque<SharedHandle<DHTBucket> > buckets;
-  _routingTable->getBuckets(buckets);
-  for(std::deque<SharedHandle<DHTBucket> >::const_iterator i = buckets.begin(); i != buckets.end(); ++i) {
+  // Removing tempFile is unnecessary because the file is truncated on
+  // open.  But the bug in 1.10.4 creates directory for this path.
+  // Because it is directory, opening directory as file fails.  So we
+  // first remove it here.
+  File tempFile(dhtFile+"__temp");
+  tempFile.remove();
 
-    const SharedHandle<DHTBucket>& bucket = *i;
-    std::deque<SharedHandle<DHTNode> > goodNodes;
-    bucket->getGoodNodes(goodNodes);
+  File(File(dhtFile).getDirname()).mkdirs();
+  std::vector<std::shared_ptr<DHTNode> > nodes;
+  std::vector<std::shared_ptr<DHTBucket> > buckets;
+  routingTable_->getBuckets(buckets);
+  for (const auto& b : buckets) {
+    std::vector<std::shared_ptr<DHTNode> > goodNodes;
+    b->getGoodNodes(goodNodes);
     nodes.insert(nodes.end(), goodNodes.begin(), goodNodes.end());
   }
 
-  DHTRoutingTableSerializer serializer;
-  serializer.setLocalNode(_localNode);
+  DHTRoutingTableSerializer serializer(family_);
+  serializer.setLocalNode(localNode_);
   serializer.setNodes(nodes);
 
   try {
-    {
-      std::ofstream o(tempFile.c_str(), std::ios::out|std::ios::binary);
-      if(!o) {
-        throw DL_ABORT_EX
-          (StringFormat("Failed to save DHT routing table to %s. cause:%s",
-                        dhtFile.c_str(), strerror(errno)).str());
-      }
-      serializer.serialize(o);
-    }
-    if(!File(tempFile).renameTo(dhtFile)) {
-      logger->error("Cannot move file from %s to %s.",
-                    tempFile.c_str(), dhtFile.c_str());
-    }
+    serializer.serialize(dhtFile);
   } catch(RecoverableException& e) {
-    logger->error("Exception caught while saving DHT routing table to %s",
-                  e, dhtFile.c_str());
+    A2_LOG_ERROR_EX(fmt("Exception caught while saving DHT routing table to %s",
+                        dhtFile.c_str()),
+                    e);
   }
 }
 
-void DHTAutoSaveCommand::setLocalNode(const SharedHandle<DHTNode>& localNode)
+void DHTAutoSaveCommand::setLocalNode(const std::shared_ptr<DHTNode>& localNode)
 {
-  _localNode = localNode;
+  localNode_ = localNode;
 }
 
-void DHTAutoSaveCommand::setRoutingTable(const SharedHandle<DHTRoutingTable>& routingTable)
+void DHTAutoSaveCommand::setRoutingTable(DHTRoutingTable* routingTable)
 {
-  _routingTable = routingTable;
+  routingTable_ = routingTable;
 }
 
 } // namespace aria2
