@@ -61,24 +61,23 @@ const std::string DHTGetPeersReplyMessage::NODES6("nodes6");
 
 DHTGetPeersReplyMessage::DHTGetPeersReplyMessage
 (int family,
- const SharedHandle<DHTNode>& localNode,
- const SharedHandle<DHTNode>& remoteNode,
+ const std::shared_ptr<DHTNode>& localNode,
+ const std::shared_ptr<DHTNode>& remoteNode,
  const std::string& token,
- const std::string& transactionID):
-  DHTResponseMessage(localNode, remoteNode, transactionID),
-  family_(family),
-  token_(token) {}
-
-DHTGetPeersReplyMessage::~DHTGetPeersReplyMessage() {}
+ const std::string& transactionID)
+  : DHTResponseMessage{localNode, remoteNode, transactionID},
+    family_{family},
+    token_{token}
+{}
 
 void DHTGetPeersReplyMessage::doReceivedAction()
 {
   // Returned peers and nodes are handled in DHTPeerLookupTask.
 }
 
-SharedHandle<Dict> DHTGetPeersReplyMessage::getResponse()
+std::unique_ptr<Dict> DHTGetPeersReplyMessage::getResponse()
 {
-  SharedHandle<Dict> rDict = Dict::g();
+  auto rDict = Dict::g();
   rDict->put(DHTMessage::ID, String::g(getLocalNode()->getID(), DHT_ID_LENGTH));
   rDict->put(TOKEN, token_);
   // TODO want parameter
@@ -88,14 +87,12 @@ SharedHandle<Dict> DHTGetPeersReplyMessage::getResponse()
     const int unit = clen+20;
     size_t offset = 0;
     size_t k = 0;
-    for(std::vector<SharedHandle<DHTNode> >::const_iterator i =
-          closestKNodes_.begin(), eoi = closestKNodes_.end();
+    for(auto i = std::begin(closestKNodes_), eoi = std::end(closestKNodes_);
         i != eoi && k < DHTBucket::K; ++i) {
-      SharedHandle<DHTNode> node = *i;
-      memcpy(buffer+offset, node->getID(), DHT_ID_LENGTH);
+      memcpy(buffer+offset, (*i)->getID(), DHT_ID_LENGTH);
       unsigned char compact[COMPACT_LEN_IPV6];
       int compactlen = bittorrent::packcompact
-        (compact, node->getIPAddress(), node->getPort());
+        (compact, (*i)->getIPAddress(), (*i)->getPort());
       if(compactlen == clen) {
         memcpy(buffer+20+offset, compact, compactlen);
         offset += unit;
@@ -128,20 +125,18 @@ SharedHandle<Dict> DHTGetPeersReplyMessage::getResponse()
     // template may get bigger than 395 bytes. So we use 25 as maximum
     // number of peer info that a message can carry.
     static const size_t MAX_VALUES_SIZE = 25;
-    SharedHandle<List> valuesList = List::g();
-    for(std::vector<SharedHandle<Peer> >::const_iterator i = values_.begin(),
-          eoi = values_.end(); i != eoi && valuesList->size() < MAX_VALUES_SIZE;
-        ++i) {
-      const SharedHandle<Peer>& peer = *i;
+    auto valuesList = List::g();
+    for(auto i = std::begin(values_), eoi = std::end(values_);
+        i != eoi && valuesList->size() < MAX_VALUES_SIZE; ++i) {
       unsigned char compact[COMPACT_LEN_IPV6];
       const int clen = bittorrent::getCompactLength(family_);
       int compactlen = bittorrent::packcompact
-        (compact, peer->getIPAddress(), peer->getPort());
+        (compact, (*i)->getIPAddress(), (*i)->getPort());
       if(compactlen == clen) {
         valuesList->append(String::g(compact, compactlen));
       }
     }
-    rDict->put(VALUES, valuesList);
+    rDict->put(VALUES, std::move(valuesList));
   }
   return rDict;
 }
@@ -164,4 +159,16 @@ std::string DHTGetPeersReplyMessage::toStringOptional() const
              static_cast<unsigned long>(closestKNodes_.size()));
 }
 
+void DHTGetPeersReplyMessage::setClosestKNodes
+(std::vector<std::shared_ptr<DHTNode>> closestKNodes)
+{
+  closestKNodes_ = std::move(closestKNodes);
+}
+
+void DHTGetPeersReplyMessage::setValues
+(std::vector<std::shared_ptr<Peer>> peers)
+{
+  values_ = std::move(peers);
+}
+
 } // namespace aria2
