@@ -39,7 +39,6 @@
 
 #include <string>
 
-#include "SharedHandle.h"
 #include "DHTConstants.h"
 #include "TimerA2.h"
 
@@ -61,14 +60,14 @@ private:
   Timer lastContact_;
 public:
   DHTNode();
-  
+
   /**
    * id must be 20 bytes length
    */
   DHTNode(const unsigned char* id);
 
   ~DHTNode();
-  
+
   void generateID();
 
   const unsigned char* getID() const
@@ -116,6 +115,8 @@ public:
 
   bool operator==(const DHTNode& node) const;
 
+  bool operator!=(const DHTNode& node) const;
+
   bool operator<(const DHTNode& node) const;
 
   std::string toString() const;
