@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_NODE_LOOKUP_TASK_H_
-#define _D_DHT_NODE_LOOKUP_TASK_H_
+#ifndef D_DHT_NODE_LOOKUP_TASK_H
+#define D_DHT_NODE_LOOKUP_TASK_H
 
 #include "DHTAbstractNodeLookupTask.h"
 
@@ -47,15 +47,15 @@ public:
   DHTNodeLookupTask(const unsigned char* targetNodeID);
 
   virtual void getNodesFromMessage
-  (std::vector<SharedHandle<DHTNode> >& nodes,
-   const DHTFindNodeReplyMessage* message);
+  (std::vector<std::shared_ptr<DHTNode> >& nodes,
+   const DHTFindNodeReplyMessage* message) CXX11_OVERRIDE;
 
-  virtual SharedHandle<DHTMessage> createMessage
-  (const SharedHandle<DHTNode>& remoteNode);
+  virtual std::unique_ptr<DHTMessage> createMessage
+  (const std::shared_ptr<DHTNode>& remoteNode) CXX11_OVERRIDE;
 
-  virtual SharedHandle<DHTMessageCallback> createCallback();
+  virtual std::unique_ptr<DHTMessageCallback> createCallback() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_DHT_NODE_LOOKUP_TASK_H_
+#endif // D_DHT_NODE_LOOKUP_TASK_H
