@@ -83,12 +83,11 @@ private:
     template<typename OutputIterator>
     void getAllGoodAddrs(OutputIterator out) const
     {
-      for(std::vector<AddrEntry>::const_iterator i = addrEntries_.begin(),
-            eoi = addrEntries_.end(); i != eoi; ++i) {
-        if((*i).good_) {
-          *out++ = (*i).addr_;
+      for(auto & elem : addrEntries_) {
+        if(elem.good_) {
+          *out++ = elem.addr_;
         }
-      }      
+      }
     }
 
     void markBad(const std::string& addr);
@@ -98,8 +97,8 @@ private:
     bool operator==(const CacheEntry& e) const;
   };
 
-  typedef std::set<SharedHandle<CacheEntry>,
-                   DerefLess<SharedHandle<CacheEntry> > > CacheEntrySet;
+  typedef std::set<std::shared_ptr<CacheEntry>,
+                   DerefLess<std::shared_ptr<CacheEntry> > > CacheEntrySet;
   CacheEntrySet entries_;
 public:
   DNSCache();
@@ -109,12 +108,12 @@ public:
   DNSCache& operator=(const DNSCache& c);
 
   const std::string& find(const std::string& hostname, uint16_t port) const;
-  
+
   template<typename OutputIterator>
   void findAll
   (OutputIterator out, const std::string& hostname, uint16_t port) const
   {
-    SharedHandle<CacheEntry> target(new CacheEntry(hostname, port));
+    std::shared_ptr<CacheEntry> target(new CacheEntry(hostname, port));
     CacheEntrySet::iterator i = entries_.find(target);
     if(i != entries_.end()) {
       (*i)->getAllGoodAddrs(out);
