@@ -37,6 +37,8 @@
 
 #include "BtProgressInfoFile.h"
 
+#include <memory>
+
 namespace aria2 {
 
 class DownloadContext;
@@ -47,44 +49,41 @@ class Option;
 
 class DefaultBtProgressInfoFile : public BtProgressInfoFile {
 private:
-  SharedHandle<DownloadContext> dctx_;
-  SharedHandle<PieceStorage> pieceStorage_;
+  std::shared_ptr<DownloadContext> dctx_;
+  std::shared_ptr<PieceStorage> pieceStorage_;
 #ifdef ENABLE_BITTORRENT
-  SharedHandle<PeerStorage> peerStorage_;
-  SharedHandle<BtRuntime> btRuntime_;
+  std::shared_ptr<PeerStorage> peerStorage_;
+  std::shared_ptr<BtRuntime> btRuntime_;
 #endif // ENABLE_BITTORRENT
   const Option* option_;
   std::string filename_;
 
   bool isTorrentDownload();
-
-  static const std::string V0000;
-  static const std::string V0001;
 public:
-  DefaultBtProgressInfoFile(const SharedHandle<DownloadContext>& btContext,
-                            const SharedHandle<PieceStorage>& pieceStorage,
+  DefaultBtProgressInfoFile(const std::shared_ptr<DownloadContext>& btContext,
+                            const std::shared_ptr<PieceStorage>& pieceStorage,
                             const Option* option);
 
   virtual ~DefaultBtProgressInfoFile();
 
-  virtual std::string getFilename() { return filename_; }
-  
-  virtual bool exists();
+  virtual std::string getFilename() CXX11_OVERRIDE { return filename_; }
 
-  virtual void save();
+  virtual bool exists() CXX11_OVERRIDE;
 
-  virtual void load();
+  virtual void save() CXX11_OVERRIDE;
 
-  virtual void removeFile();
+  virtual void load() CXX11_OVERRIDE;
+
+  virtual void removeFile() CXX11_OVERRIDE;
 
   // re-set filename using current dctx_.
-  virtual void updateFilename();
+  virtual void updateFilename() CXX11_OVERRIDE;
 
 #ifdef ENABLE_BITTORRENT
   // for torrents
-  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+  void setPeerStorage(const std::shared_ptr<PeerStorage>& peerStorage);
 
-  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
+  void setBtRuntime(const std::shared_ptr<BtRuntime>& btRuntime);
 #endif // ENABLE_BITTORRENT
 
   static const std::string& getSuffix()
