@@ -53,7 +53,7 @@ namespace aria2 {
 
 namespace {
 
-const size_t MAX_PEER_LIST_SIZE = 1024;
+const size_t MAX_PEER_LIST_SIZE = 512;
 const size_t MAX_PEER_LIST_UPDATE = 100;
 
 } // namespace
@@ -69,30 +69,27 @@ DefaultPeerStorage::~DefaultPeerStorage()
 {
   delete seederStateChoke_;
   delete leecherStateChoke_;
+  assert(uniqPeers_.size() == unusedPeers_.size() + usedPeers_.size());
 }
 
-namespace {
-class FindIdenticalPeer {
-private:
-  SharedHandle<Peer> peer_;
-public:
-  FindIdenticalPeer(const SharedHandle<Peer>& peer):peer_(peer) {}
-
-  bool operator()(const SharedHandle<Peer>& peer) const {
-    return (*peer_ == *peer) ||
-      ((peer_->getIPAddress() == peer->getIPAddress()) &&
-       (peer_->getPort() == peer->getPort()));
-  }
-};
-} // namespace
-
-bool DefaultPeerStorage::isPeerAlreadyAdded(const SharedHandle<Peer>& peer)
+size_t DefaultPeerStorage::countAllPeer() const
 {
-  return std::find_if(peers_.begin(), peers_.end(),
-                      FindIdenticalPeer(peer)) != peers_.end();
+  return unusedPeers_.size() + usedPeers_.size();
 }
 
-bool DefaultPeerStorage::addPeer(const SharedHandle<Peer>& peer) {
+bool DefaultPeerStorage::isPeerAlreadyAdded(const std::shared_ptr<Peer>& peer)
+{
+  return uniqPeers_.count(std::make_pair(peer->getIPAddress(),
+                                         peer->getOrigPort()));
+}
+
+void DefaultPeerStorage::addUniqPeer(const std::shared_ptr<Peer>& peer)
+{
+  uniqPeers_.insert(std::make_pair(peer->getIPAddress(), peer->getOrigPort()));
+}
+
+bool DefaultPeerStorage::addPeer(const std::shared_ptr<Peer>& peer)
+{
   if(isPeerAlreadyAdded(peer)) {
     A2_LOG_DEBUG(fmt("Adding %s:%u is rejected because it has been already"
                      " added.",
@@ -104,23 +101,24 @@ bool DefaultPeerStorage::addPeer(const SharedHandle<Peer>& peer) {
                      peer->getIPAddress().c_str(), peer->getPort()));
     return false;
   }
-  const size_t peerListSize = peers_.size();
+  const size_t peerListSize = unusedPeers_.size();
   if(peerListSize >= maxPeerListSize_) {
     deleteUnusedPeer(peerListSize-maxPeerListSize_+1);
   }
-  peers_.push_front(peer);
-  A2_LOG_DEBUG(fmt("Now peer list contains %lu peers",
-                   static_cast<unsigned long>(peers_.size())));
+  unusedPeers_.push_front(peer);
+  addUniqPeer(peer);
+  A2_LOG_DEBUG(fmt("Now unused peer list contains %lu peers",
+                   static_cast<unsigned long>(unusedPeers_.size())));
   return true;
 }
 
-void DefaultPeerStorage::addPeer(const std::vector<SharedHandle<Peer> >& peers)
+void DefaultPeerStorage::addPeer(const std::vector<std::shared_ptr<Peer> >& peers)
 {
   size_t added = 0;
   size_t addMax = std::min(maxPeerListSize_, MAX_PEER_LIST_UPDATE);
-  for(std::vector<SharedHandle<Peer> >::const_iterator itr = peers.begin(),
+  for(auto itr = peers.begin(),
         eoi = peers.end(); itr != eoi && added < addMax; ++itr) {
-    const SharedHandle<Peer>& peer = *itr;
+    const std::shared_ptr<Peer>& peer = *itr;
     if(isPeerAlreadyAdded(peer)) {
       A2_LOG_DEBUG(fmt("Adding %s:%u is rejected because it has been already"
                        " added.",
@@ -134,133 +132,79 @@ void DefaultPeerStorage::addPeer(const std::vector<SharedHandle<Peer> >& peers)
       A2_LOG_DEBUG(fmt(MSG_ADDING_PEER,
                        peer->getIPAddress().c_str(), peer->getPort()));
     }
-    peers_.push_front(peer);
+    unusedPeers_.push_front(peer);
+    addUniqPeer(peer);
     ++added;
   }
-  const size_t peerListSize = peers_.size();
-  if(peerListSize >= maxPeerListSize_) {
+  const size_t peerListSize = unusedPeers_.size();
+  if(peerListSize > maxPeerListSize_) {
     deleteUnusedPeer(peerListSize-maxPeerListSize_);
   }
-  A2_LOG_DEBUG(fmt("Now peer list contains %lu peers",
-                   static_cast<unsigned long>(peers_.size())));
+  A2_LOG_DEBUG(fmt("Now unused peer list contains %lu peers",
+                   static_cast<unsigned long>(unusedPeers_.size())));
 }
 
-void DefaultPeerStorage::addDroppedPeer(const SharedHandle<Peer>& peer)
+void DefaultPeerStorage::addDroppedPeer(const std::shared_ptr<Peer>& peer)
 {
+  // Make sure that no duplicated peer exists in droppedPeers_. If
+  // exists, erase older one.
+  for(auto i = droppedPeers_.begin(),
+        eoi = droppedPeers_.end(); i != eoi; ++i) {
+    if((*i)->getIPAddress() == peer->getIPAddress() &&
+       (*i)->getPort() == peer->getPort()) {
+      droppedPeers_.erase(i);
+      break;
+    }
+  }
   droppedPeers_.push_front(peer);
   if(droppedPeers_.size() > 50) {
     droppedPeers_.pop_back();
   }
 }
 
-const std::deque<SharedHandle<Peer> >& DefaultPeerStorage::getPeers()
+const std::deque<std::shared_ptr<Peer> >& DefaultPeerStorage::getUnusedPeers()
 {
-  return peers_;
+  return unusedPeers_;
 }
 
-const std::deque<SharedHandle<Peer> >& DefaultPeerStorage::getDroppedPeers()
+const PeerSet& DefaultPeerStorage::getUsedPeers()
+{
+  return usedPeers_;
+}
+
+const std::deque<std::shared_ptr<Peer> >& DefaultPeerStorage::getDroppedPeers()
 {
   return droppedPeers_;
 }
 
-namespace {
-class FindFinePeer {
-public:
-  bool operator()(const SharedHandle<Peer>& peer) const {
-    return peer->unused() && peer->isGood();
-  }
-};
-} // namespace
-
-SharedHandle<Peer> DefaultPeerStorage::getUnusedPeer() {
-  std::deque<SharedHandle<Peer> >::const_iterator itr =
-    std::find_if(peers_.begin(), peers_.end(), FindFinePeer());
-  if(itr == peers_.end()) {
-    return SharedHandle<Peer>();
-  } else {
-    return *itr;
-  }
-}
-
-namespace {
-class FindPeer {
-private:
-  std::string ipaddr;
-  uint16_t port;
-public:
-  FindPeer(const std::string& ipaddr, uint16_t port):
-    ipaddr(ipaddr), port(port) {}
-
-  bool operator()(const SharedHandle<Peer>& peer) const {
-    return ipaddr == peer->getIPAddress() && port == peer->getPort();
-  }
-};
-} // namespace
-
-SharedHandle<Peer> DefaultPeerStorage::getPeer(const std::string& ipaddr,
-                                               uint16_t port) const {
-  std::deque<SharedHandle<Peer> >::const_iterator itr =
-    std::find_if(peers_.begin(), peers_.end(), FindPeer(ipaddr, port));
-  if(itr == peers_.end()) {
-    return SharedHandle<Peer>();
-  } else {
-    return *itr;
-  }
-}
-
-size_t DefaultPeerStorage::countPeer() const {
-  return peers_.size();
-}
-
 bool DefaultPeerStorage::isPeerAvailable() {
-  return getUnusedPeer();
-}
-
-namespace {
-class CollectActivePeer {
-private:
-  std::vector<SharedHandle<Peer> >& activePeers_;
-public:
-  CollectActivePeer(std::vector<SharedHandle<Peer> >& activePeers):
-    activePeers_(activePeers) {}
-
-  void operator()(const SharedHandle<Peer>& peer)
-  {
-    if(peer->isActive()) {
-      activePeers_.push_back(peer);
-    }
-  }
-};
-} // namespace
-
-void DefaultPeerStorage::getActivePeers
-(std::vector<SharedHandle<Peer> >& activePeers)
-{
-  std::for_each(peers_.begin(), peers_.end(), CollectActivePeer(activePeers));
+  return !unusedPeers_.empty();
 }
 
 bool DefaultPeerStorage::isBadPeer(const std::string& ipaddr)
 {
-  std::map<std::string, time_t>::iterator i = badPeers_.find(ipaddr);
+  auto i = badPeers_.find(ipaddr);
   if(i == badPeers_.end()) {
     return false;
-  } else if(global::wallclock().getTime() >= (*i).second) {
+  }
+
+  if(global::wallclock().getTime() >= (*i).second) {
     badPeers_.erase(i);
     return false;
-  } else {
-    return true;
   }
+
+  return true;
 }
 
 void DefaultPeerStorage::addBadPeer(const std::string& ipaddr)
 {
   if(lastBadPeerCleaned_.difference(global::wallclock()) >= 3600) {
-    for(std::map<std::string, time_t>::iterator i = badPeers_.begin(),
+    for(auto i = badPeers_.begin(),
           eoi = badPeers_.end(); i != eoi;) {
       if(global::wallclock().getTime() >= (*i).second) {
         A2_LOG_DEBUG(fmt("Purge %s from bad peer", (*i).first.c_str()));
         badPeers_.erase(i++);
-        eoi = badPeers_.end();
+        // badPeers_.end() will not be invalidated.
       } else {
         ++i;
       }
@@ -274,27 +218,38 @@ void DefaultPeerStorage::addBadPeer(const std::string& ipaddr)
 }
 
 void DefaultPeerStorage::deleteUnusedPeer(size_t delSize) {
-  std::deque<SharedHandle<Peer> > temp;
-  for(std::deque<SharedHandle<Peer> >::const_reverse_iterator itr =
-        peers_.rbegin(), eoi = peers_.rend(); itr != eoi; ++itr) {
-    const SharedHandle<Peer>& p = *itr;
-    if(p->unused() && delSize > 0) {
-      onErasingPeer(p);
-      --delSize;
-    } else {
-      temp.push_front(p);
-    }
+  for(; delSize > 0 && !unusedPeers_.empty(); --delSize) {
+    onErasingPeer(unusedPeers_.back());
+    unusedPeers_.pop_back();
   }
-  peers_.swap(temp);
 }
 
-void DefaultPeerStorage::onErasingPeer(const SharedHandle<Peer>& peer) {}
+std::shared_ptr<Peer> DefaultPeerStorage::checkoutPeer(cuid_t cuid)
+{
+  if(!isPeerAvailable()) {
+    return nullptr;
+  }
+  std::shared_ptr<Peer> peer = unusedPeers_.front();
+  unusedPeers_.pop_front();
+  peer->usedBy(cuid);
+  usedPeers_.insert(peer);
+  A2_LOG_DEBUG(fmt("Checkout peer %s:%u to CUID#%" PRId64,
+                   peer->getIPAddress().c_str(), peer->getPort(),
+                   peer->usedBy()));
+  return peer;
+}
 
-void DefaultPeerStorage::onReturningPeer(const SharedHandle<Peer>& peer)
+void DefaultPeerStorage::onErasingPeer(const std::shared_ptr<Peer>& peer)
+{
+  uniqPeers_.erase(std::make_pair(peer->getIPAddress(),
+                                  peer->getOrigPort()));
+}
+
+void DefaultPeerStorage::onReturningPeer(const std::shared_ptr<Peer>& peer)
 {
   if(peer->isActive()) {
     if(peer->isDisconnectedGracefully() && !peer->isIncomingPeer()) {
-      peer->startBadCondition();
+      peer->startDrop();
       addDroppedPeer(peer);
     }
     // Execute choking algorithm if unchoked and interested peer is
@@ -303,20 +258,20 @@ void DefaultPeerStorage::onReturningPeer(const SharedHandle<Peer>& peer)
       executeChoke();
     }
   }
+  peer->usedBy(0);
 }
 
-void DefaultPeerStorage::returnPeer(const SharedHandle<Peer>& peer)
+void DefaultPeerStorage::returnPeer(const std::shared_ptr<Peer>& peer)
 {
-  std::deque<SharedHandle<Peer> >::iterator itr =
-    std::find_if(peers_.begin(), peers_.end(), derefEqual(peer));
-  if(itr == peers_.end()) {
-    A2_LOG_DEBUG(fmt("Cannot find peer %s:%u in PeerStorage.",
-                     peer->getIPAddress().c_str(), peer->getPort()));
-  } else {
-    peers_.erase(itr);
-
+  A2_LOG_DEBUG(fmt("Peer %s:%u returned from CUID#%" PRId64,
+                   peer->getIPAddress().c_str(), peer->getPort(),
+                   peer->usedBy()));
+  if(usedPeers_.erase(peer)) {
     onReturningPeer(peer);
     onErasingPeer(peer);
+  } else {
+    A2_LOG_DEBUG(fmt("Cannot find peer %s:%u in usedPeers_",
+                     peer->getIPAddress().c_str(), peer->getPort()));
   }
 }
 
@@ -334,21 +289,19 @@ bool DefaultPeerStorage::chokeRoundIntervalElapsed()
 
 void DefaultPeerStorage::executeChoke()
 {
-  std::vector<SharedHandle<Peer> > activePeers;
-  getActivePeers(activePeers);
   if(pieceStorage_->downloadFinished()) {
-    return seederStateChoke_->executeChoke(activePeers);
+    return seederStateChoke_->executeChoke(usedPeers_);
   } else {
-    return leecherStateChoke_->executeChoke(activePeers);
+    return leecherStateChoke_->executeChoke(usedPeers_);
   }
 }
 
-void DefaultPeerStorage::setPieceStorage(const SharedHandle<PieceStorage>& ps)
+void DefaultPeerStorage::setPieceStorage(const std::shared_ptr<PieceStorage>& ps)
 {
   pieceStorage_ = ps;
 }
 
-void DefaultPeerStorage::setBtRuntime(const SharedHandle<BtRuntime>& btRuntime)
+void DefaultPeerStorage::setBtRuntime(const std::shared_ptr<BtRuntime>& btRuntime)
 {
   btRuntime_ = btRuntime;
 }
