@@ -75,12 +75,12 @@ public:
 
 class DefaultPieceStorage : public PieceStorage {
 private:
-  SharedHandle<DownloadContext> downloadContext_;
+  std::shared_ptr<DownloadContext> downloadContext_;
   BitfieldMan* bitfieldMan_;
-  SharedHandle<DiskAdaptor> diskAdaptor_;
-  SharedHandle<DiskWriterFactory> diskWriterFactory_;
-  typedef std::set<SharedHandle<Piece>,
-                   DerefLess<SharedHandle<Piece> > > UsedPieceSet;
+  std::shared_ptr<DiskAdaptor> diskAdaptor_;
+  std::shared_ptr<DiskWriterFactory> diskWriterFactory_;
+  typedef std::set<std::shared_ptr<Piece>,
+                   DerefLess<std::shared_ptr<Piece> > > UsedPieceSet;
   UsedPieceSet usedPieces_;
 
   bool endGame_;
@@ -88,27 +88,29 @@ private:
   const Option* option_;
   std::deque<HaveEntry> haves_;
 
-  SharedHandle<PieceStatMan> pieceStatMan_;
+  std::shared_ptr<PieceStatMan> pieceStatMan_;
 
-  SharedHandle<PieceSelector> pieceSelector_;
-  SharedHandle<StreamPieceSelector> streamPieceSelector_;
+  std::unique_ptr<PieceSelector> pieceSelector_;
+  std::unique_ptr<StreamPieceSelector> streamPieceSelector_;
+
+  WrDiskCache* wrDiskCache_;
 #ifdef ENABLE_BITTORRENT
   void getMissingPiece
-  (std::vector<SharedHandle<Piece> >& pieces,
+  (std::vector<std::shared_ptr<Piece> >& pieces,
    size_t minMissingBlocks,
    const unsigned char* bitfield,
    size_t length,
    cuid_t cuid);
 
   void createFastIndexBitfield(BitfieldMan& bitfield,
-                               const SharedHandle<Peer>& peer);
+                               const std::shared_ptr<Peer>& peer);
 #endif // ENABLE_BITTORRENT
 
-  SharedHandle<Piece> checkOutPiece(size_t index, cuid_t cuid);
+  std::shared_ptr<Piece> checkOutPiece(size_t index, cuid_t cuid);
   //   size_t deleteUsedPiecesByFillRate(int fillRate, size_t toDelete);
   //   void reduceUsedPieces(size_t upperBound);
-  void deleteUsedPiece(const SharedHandle<Piece>& piece);
-  SharedHandle<Piece> findUsedPiece(size_t index) const;
+  void deleteUsedPiece(const std::shared_ptr<Piece>& piece);
+  std::shared_ptr<Piece> findUsedPiece(size_t index) const;
 
   // Returns the sum of completed length of in-flight pieces
   int64_t getInFlightPieceCompletedLength() const;
@@ -120,107 +122,112 @@ public:
   // random when more than 2 pieces has the same rarity.
   // If it is set to false, a piece whose index is smallest has the highest
   // priority.
-  DefaultPieceStorage(const SharedHandle<DownloadContext>& downloadContext,
+  DefaultPieceStorage(const std::shared_ptr<DownloadContext>& downloadContext,
                       const Option* option);
 
   virtual ~DefaultPieceStorage();
 
 #ifdef ENABLE_BITTORRENT
 
-  virtual bool hasMissingPiece(const SharedHandle<Peer>& peer);
+  virtual bool hasMissingPiece(const std::shared_ptr<Peer>& peer)
+    CXX11_OVERRIDE;
 
   virtual void getMissingPiece
-  (std::vector<SharedHandle<Piece> >& pieces,
+  (std::vector<std::shared_ptr<Piece> >& pieces,
    size_t minMissingBlocks,
-   const SharedHandle<Peer>& peer,
-   cuid_t cuid);
+   const std::shared_ptr<Peer>& peer,
+   cuid_t cuid) CXX11_OVERRIDE;
 
   virtual void getMissingPiece
-  (std::vector<SharedHandle<Piece> >& pieces,
+  (std::vector<std::shared_ptr<Piece> >& pieces,
    size_t minMissingBlocks,
-   const SharedHandle<Peer>& peer,
+   const std::shared_ptr<Peer>& peer,
    const std::vector<size_t>& excludedIndexes,
-   cuid_t cuid);
+   cuid_t cuid) CXX11_OVERRIDE;
 
   virtual void getMissingFastPiece
-  (std::vector<SharedHandle<Piece> >& pieces,
+  (std::vector<std::shared_ptr<Piece> >& pieces,
    size_t minMissingBlocks,
-   const SharedHandle<Peer>& peer,
-   cuid_t cuid);
+   const std::shared_ptr<Peer>& peer,
+   cuid_t cuid) CXX11_OVERRIDE;
 
   virtual void getMissingFastPiece
-  (std::vector<SharedHandle<Piece> >& pieces,
+  (std::vector<std::shared_ptr<Piece> >& pieces,
    size_t minMissingBlocks,
-   const SharedHandle<Peer>& peer,
+   const std::shared_ptr<Peer>& peer,
    const std::vector<size_t>& excludedIndexes,
-   cuid_t cuid);
+   cuid_t cuid) CXX11_OVERRIDE;
 
-  virtual SharedHandle<Piece> getMissingPiece
-  (const SharedHandle<Peer>& peer,
-   cuid_t cuid);
+  virtual std::shared_ptr<Piece> getMissingPiece
+  (const std::shared_ptr<Peer>& peer,
+   cuid_t cuid) CXX11_OVERRIDE;
 
-  virtual  SharedHandle<Piece> getMissingPiece
-  (const SharedHandle<Peer>& peer,
+  virtual  std::shared_ptr<Piece> getMissingPiece
+  (const std::shared_ptr<Peer>& peer,
    const std::vector<size_t>& excludedIndexes,
+   cuid_t cuid) CXX11_OVERRIDE;
+
+  std::shared_ptr<Piece> getMissingFastPiece
+  (const std::shared_ptr<Peer>& peer,
    cuid_t cuid);
 
-  SharedHandle<Piece> getMissingFastPiece
-  (const SharedHandle<Peer>& peer,
-   cuid_t cuid);
-
-  SharedHandle<Piece> getMissingFastPiece
-  (const SharedHandle<Peer>& peer,
+  std::shared_ptr<Piece> getMissingFastPiece
+  (const std::shared_ptr<Peer>& peer,
    const std::vector<size_t>& excludedIndexes,
    cuid_t cuid);
 
 #endif // ENABLE_BITTORRENT
 
-  virtual bool hasMissingUnusedPiece();
+  virtual bool hasMissingUnusedPiece() CXX11_OVERRIDE;
 
-  virtual SharedHandle<Piece> getMissingPiece
+  virtual std::shared_ptr<Piece> getMissingPiece
   (size_t minSplitSize,
    const unsigned char* ignoreBitfield,
    size_t length,
-   cuid_t cuid);
+   cuid_t cuid) CXX11_OVERRIDE;
 
-  virtual SharedHandle<Piece> getMissingPiece(size_t index, cuid_t cuid);
+  virtual std::shared_ptr<Piece> getMissingPiece(size_t index, cuid_t cuid)
+    CXX11_OVERRIDE;
 
-  virtual SharedHandle<Piece> getPiece(size_t index);
+  virtual std::shared_ptr<Piece> getPiece(size_t index) CXX11_OVERRIDE;
 
-  virtual void completePiece(const SharedHandle<Piece>& piece);
+  virtual void completePiece(const std::shared_ptr<Piece>& piece)
+    CXX11_OVERRIDE;
 
-  virtual void cancelPiece(const SharedHandle<Piece>& piece, cuid_t cuid);
+  virtual void cancelPiece(const std::shared_ptr<Piece>& piece, cuid_t cuid)
+    CXX11_OVERRIDE;
 
-  virtual bool hasPiece(size_t index);
+  virtual bool hasPiece(size_t index) CXX11_OVERRIDE;
 
-  virtual bool isPieceUsed(size_t index);
+  virtual bool isPieceUsed(size_t index) CXX11_OVERRIDE;
 
-  virtual int64_t getTotalLength();
+  virtual int64_t getTotalLength() CXX11_OVERRIDE;
 
-  virtual int64_t getFilteredTotalLength();
+  virtual int64_t getFilteredTotalLength() CXX11_OVERRIDE;
 
-  virtual int64_t getCompletedLength();
+  virtual int64_t getCompletedLength() CXX11_OVERRIDE;
 
-  virtual int64_t getFilteredCompletedLength();
+  virtual int64_t getFilteredCompletedLength() CXX11_OVERRIDE;
 
-  virtual void initStorage();
+  virtual void initStorage() CXX11_OVERRIDE;
 
-  virtual void setupFileFilter();
+  virtual void setupFileFilter() CXX11_OVERRIDE;
 
-  virtual void clearFileFilter();
+  virtual void clearFileFilter() CXX11_OVERRIDE;
 
-  virtual bool downloadFinished();
+  virtual bool downloadFinished() CXX11_OVERRIDE;
 
-  virtual bool allDownloadFinished();
+  virtual bool allDownloadFinished() CXX11_OVERRIDE;
 
   virtual void setBitfield(const unsigned char* bitfield,
-                           size_t bitfieldLength);
+                           size_t bitfieldLength) CXX11_OVERRIDE;
 
-  virtual size_t getBitfieldLength();
+  virtual size_t getBitfieldLength() CXX11_OVERRIDE;
 
-  virtual const unsigned char* getBitfield();
+  virtual const unsigned char* getBitfield() CXX11_OVERRIDE;
 
-  virtual void setEndGamePieceNum(size_t num) {
+  virtual void setEndGamePieceNum(size_t num) CXX11_OVERRIDE
+  {
     endGamePieceNum_ = num;
   }
 
@@ -228,82 +235,92 @@ public:
     return endGamePieceNum_;
   }
 
-  virtual bool isSelectiveDownloadingMode();
+  virtual bool isSelectiveDownloadingMode() CXX11_OVERRIDE;
 
-  virtual bool isEndGame()
+  virtual bool isEndGame() CXX11_OVERRIDE
   {
     return endGame_;
   }
 
-  virtual void enterEndGame()
+  virtual void enterEndGame() CXX11_OVERRIDE
   {
     endGame_ = true;
   }
 
-  virtual SharedHandle<DiskAdaptor> getDiskAdaptor();
+  virtual std::shared_ptr<DiskAdaptor> getDiskAdaptor() CXX11_OVERRIDE;
 
-  virtual int32_t getPieceLength(size_t index);
+  virtual WrDiskCache* getWrDiskCache() CXX11_OVERRIDE;
 
-  virtual void advertisePiece(cuid_t cuid, size_t index);
+  virtual void flushWrDiskCacheEntry() CXX11_OVERRIDE;
+
+  virtual int32_t getPieceLength(size_t index) CXX11_OVERRIDE;
+
+  virtual void advertisePiece(cuid_t cuid, size_t index) CXX11_OVERRIDE;
 
   virtual void
   getAdvertisedPieceIndexes(std::vector<size_t>& indexes,
-                            cuid_t myCuid, const Timer& lastCheckTime);
+                            cuid_t myCuid, const Timer& lastCheckTime)
+    CXX11_OVERRIDE;
 
-  virtual void removeAdvertisedPiece(time_t elapsed);
+  virtual void removeAdvertisedPiece(time_t elapsed) CXX11_OVERRIDE;
 
-  virtual void markAllPiecesDone();
+  virtual void markAllPiecesDone() CXX11_OVERRIDE;
 
-  virtual void markPiecesDone(int64_t length);
+  virtual void markPiecesDone(int64_t length) CXX11_OVERRIDE;
 
-  virtual void markPieceMissing(size_t index);
+  virtual void markPieceMissing(size_t index) CXX11_OVERRIDE;
 
   virtual void addInFlightPiece
-  (const std::vector<SharedHandle<Piece> >& pieces);
+  (const std::vector<std::shared_ptr<Piece> >& pieces) CXX11_OVERRIDE;
 
-  virtual size_t countInFlightPiece();
+  virtual size_t countInFlightPiece() CXX11_OVERRIDE;
 
   virtual void getInFlightPieces
-  (std::vector<SharedHandle<Piece> >& pieces);
+  (std::vector<std::shared_ptr<Piece> >& pieces) CXX11_OVERRIDE;
 
-  virtual void addPieceStats(size_t index);
+  virtual void addPieceStats(size_t index) CXX11_OVERRIDE;
 
   virtual void addPieceStats(const unsigned char* bitfield,
-                             size_t bitfieldLength);
+                             size_t bitfieldLength) CXX11_OVERRIDE;
 
   virtual void subtractPieceStats(const unsigned char* bitfield,
-                                  size_t bitfieldLength);
+                                  size_t bitfieldLength) CXX11_OVERRIDE;
 
   virtual void updatePieceStats(const unsigned char* newBitfield,
                                 size_t newBitfieldLength,
-                                const unsigned char* oldBitfield);
+                                const unsigned char* oldBitfield)
+    CXX11_OVERRIDE;
 
-  virtual size_t getNextUsedIndex(size_t index);
+  virtual size_t getNextUsedIndex(size_t index) CXX11_OVERRIDE;
 
-  virtual void onDownloadIncomplete();
+  virtual void onDownloadIncomplete() CXX11_OVERRIDE;
 
   /**
    * This method is made private for test purpose only.
    */
-  void addUsedPiece(const SharedHandle<Piece>& piece);
+  void addUsedPiece(const std::shared_ptr<Piece>& piece);
 
   void setDiskWriterFactory
-  (const SharedHandle<DiskWriterFactory>& diskWriterFactory);
+  (const std::shared_ptr<DiskWriterFactory>& diskWriterFactory);
 
-  const SharedHandle<PieceStatMan>& getPieceStatMan() const
+  const std::shared_ptr<PieceStatMan>& getPieceStatMan() const
   {
     return pieceStatMan_;
   }
 
-  void setPieceSelector(const SharedHandle<PieceSelector>& pieceSelector)
-  {
-    pieceSelector_ = pieceSelector;
-  }
+  void setPieceSelector(std::unique_ptr<PieceSelector> pieceSelector);
 
-  const SharedHandle<PieceSelector>& getPieceSelector() const
+  const std::unique_ptr<PieceSelector>& getPieceSelector() const
   {
     return pieceSelector_;
   }
+
+  std::unique_ptr<PieceSelector> popPieceSelector();
+
+  void setWrDiskCache(WrDiskCache* wrDiskCache)
+  {
+    wrDiskCache_ = wrDiskCache;
+  }
 };
 
 } // namespace aria2
