@@ -51,7 +51,7 @@ DownloadContext::DownloadContext():
   pieceLength_(0),
   checksumVerified_(false),
   knowsTotalLength_(true),
-  ownerRequestGroup_(0),
+  ownerRequestGroup_(nullptr),
   attrs_(MAX_CTX_ATTR),
   downloadStopTime_(0),
   acceptMetalink_(true) {}
@@ -62,12 +62,12 @@ DownloadContext::DownloadContext(int32_t pieceLength,
   pieceLength_(pieceLength),
   checksumVerified_(false),
   knowsTotalLength_(true),
-  ownerRequestGroup_(0),
+  ownerRequestGroup_(nullptr),
   attrs_(MAX_CTX_ATTR),
   downloadStopTime_(0),
   acceptMetalink_(true)
 {
-  SharedHandle<FileEntry> fileEntry(new FileEntry(path, totalLength, 0));
+  std::shared_ptr<FileEntry> fileEntry(new FileEntry(path, totalLength, 0));
   fileEntries_.push_back(fileEntry);
 }
 
@@ -91,19 +91,18 @@ int64_t DownloadContext::calculateSessionTime() const
   return startTime.differenceInMillis(downloadStopTime_);
 }
 
-SharedHandle<FileEntry>
+std::shared_ptr<FileEntry>
 DownloadContext::findFileEntryByOffset(int64_t offset) const
 {
   if(fileEntries_.empty() ||
      (offset > 0 && fileEntries_.back()->getLastOffset() <= offset)) {
-    return SharedHandle<FileEntry>();
+    return nullptr;
   }
 
-  SharedHandle<FileEntry> obj(new FileEntry());
+  std::shared_ptr<FileEntry> obj(new FileEntry());
   obj->setOffset(offset);
-  std::vector<SharedHandle<FileEntry> >::const_iterator i =
-    std::upper_bound(fileEntries_.begin(), fileEntries_.end(), obj,
-                     DerefLess<SharedHandle<FileEntry> >());
+  auto i = std::upper_bound(fileEntries_.begin(), fileEntries_.end(), obj,
+                            DerefLess<std::shared_ptr<FileEntry> >());
   if(i != fileEntries_.end() && (*i)->getOffset() == offset) {
     return *i;
   } else {
@@ -125,9 +124,11 @@ void DownloadContext::setFilePathWithIndex
 
 void DownloadContext::setFileFilter(SegList<int>& sgl)
 {
+  using namespace std::placeholders;
+
   if(!sgl.hasNext() || fileEntries_.size() == 1) {
     std::for_each(fileEntries_.begin(), fileEntries_.end(),
-                  std::bind2nd(mem_fun_sh(&FileEntry::setRequested), true));
+                  std::bind(&FileEntry::setRequested, _1, true));
     return;
   }
   assert(sgl.peek() >= 1);
@@ -148,17 +149,17 @@ void DownloadContext::setFileFilter(SegList<int>& sgl)
 }
 
 void DownloadContext::setAttribute
-(ContextAttributeType key, const SharedHandle<ContextAttribute>& value)
+(ContextAttributeType key, std::unique_ptr<ContextAttribute> value)
 {
   assert(key < MAX_CTX_ATTR);
-  attrs_[key] = value;
+  attrs_[key] = std::move(value);
 }
 
-const SharedHandle<ContextAttribute>& DownloadContext::getAttribute
+const std::unique_ptr<ContextAttribute>& DownloadContext::getAttribute
 (ContextAttributeType key)
 {
   assert(key < MAX_CTX_ATTR);
-  const SharedHandle<ContextAttribute>& attr = attrs_[key];
+  const std::unique_ptr<ContextAttribute>& attr = attrs_[key];
   if(attr) {
     return attr;
   } else {
@@ -170,12 +171,12 @@ const SharedHandle<ContextAttribute>& DownloadContext::getAttribute
 bool DownloadContext::hasAttribute(ContextAttributeType key) const
 {
   assert(key < MAX_CTX_ATTR);
-  return attrs_[key];
+  return attrs_[key].get();
 }
 
 void DownloadContext::releaseRuntimeResource()
 {
-  for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
+  for(std::vector<std::shared_ptr<FileEntry> >::const_iterator i =
         fileEntries_.begin(), eoi = fileEntries_.end(); i != eoi; ++i) {
     (*i)->putBackRequest();
     (*i)->releaseRuntimeResource();
@@ -211,24 +212,22 @@ const std::string& DownloadContext::getBasePath() const
   }
 }
 
-SharedHandle<FileEntry>
+std::shared_ptr<FileEntry>
 DownloadContext::getFirstRequestedFileEntry() const
 {
-  for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
-        fileEntries_.begin(), eoi = fileEntries_.end(); i != eoi; ++i) {
-    if((*i)->isRequested()) {
-      return *i;
+  for (auto& e : fileEntries_) {
+    if(e->isRequested()) {
+      return e;
     }
   }
-  return SharedHandle<FileEntry>();
+  return nullptr;
 }
 
 size_t DownloadContext::countRequestedFileEntry() const
 {
   size_t numFiles = 0;
-  for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
-        fileEntries_.begin(), eoi = fileEntries_.end(); i != eoi; ++i) {
-    if((*i)->isRequested()) {
+  for (const auto& e: fileEntries_) {
+    if(e->isRequested()) {
       ++numFiles;
     }
   }
@@ -274,9 +273,9 @@ void DownloadContext::setBasePath(const std::string& basePath)
   basePath_ = basePath;
 }
 
-void DownloadContext::setSignature(const SharedHandle<Signature>& signature)
+void DownloadContext::setSignature(std::unique_ptr<Signature> signature)
 {
-  signature_ = signature;
+  signature_ = std::move(signature);
 }
 
 void DownloadContext::updateDownloadLength(size_t bytes)
