@@ -40,6 +40,7 @@
 #include <cerrno>
 #include <algorithm>
 #include <numeric>
+#include <iterator>
 
 #include "StatCalc.h"
 #include "RequestGroup.h"
@@ -82,72 +83,78 @@ namespace global {
 // 2 ... stop signal processed by DownloadEngine
 // 3 ... 2nd stop signal(force shutdown) detected
 // 4 ... 2nd stop signal processed by DownloadEngine
+// 5 ... main loop exited
 volatile sig_atomic_t globalHaltRequested = 0;
 
 } // namespace global
 
-DownloadEngine::DownloadEngine(const SharedHandle<EventPoll>& eventPoll)
-  : eventPoll_(eventPoll),
+DownloadEngine::DownloadEngine(std::unique_ptr<EventPoll> eventPoll)
+  : eventPoll_(std::move(eventPoll)),
     haltRequested_(0),
     noWait_(true),
     refreshInterval_(DEFAULT_REFRESH_INTERVAL),
     lastRefresh_(0),
     cookieStorage_(new CookieStorage()),
 #ifdef ENABLE_BITTORRENT
-    btRegistry_(new BtRegistry()),
+    btRegistry_(make_unique<BtRegistry>()),
 #endif // ENABLE_BITTORRENT
 #ifdef HAVE_ARES_ADDR_NODE
-    asyncDNSServers_(0),
+    asyncDNSServers_(nullptr),
 #endif // HAVE_ARES_ADDR_NODE
-    dnsCache_(new DNSCache()),
-    option_(0)
+    dnsCache_(make_unique<DNSCache>()),
+    option_(nullptr)
 {
   unsigned char sessionId[20];
   util::generateRandomKey(sessionId);
   sessionId_.assign(&sessionId[0], & sessionId[sizeof(sessionId)]);
 }
 
-namespace {
-void cleanQueue(std::deque<Command*>& commands) {
-  std::for_each(commands.begin(), commands.end(), Deleter());
-  commands.clear();
-}
-} // namespace
-
-DownloadEngine::~DownloadEngine() {
-  cleanQueue(commands_);
-  cleanQueue(routineCommands_);
+DownloadEngine::~DownloadEngine()
+{
 #ifdef HAVE_ARES_ADDR_NODE
-  setAsyncDNSServers(0);
+  setAsyncDNSServers(nullptr);
 #endif // HAVE_ARES_ADDR_NODE
 }
 
 namespace {
-void executeCommand(std::deque<Command*>& commands,
+void executeCommand(std::deque<std::unique_ptr<Command>>& commands,
                     Command::STATUS statusFilter)
 {
   size_t max = commands.size();
   for(size_t i = 0; i < max; ++i) {
-    Command* com = commands.front();
+    auto com = std::move(commands.front());
     commands.pop_front();
-    if(com->statusMatch(statusFilter)) {
-      com->transitStatus();
-      if(com->execute()) {
-        delete com;
-        com = 0;
-      }
-    } else {
-      commands.push_back(com);
-    }
-    if(com) {
+    if (!com->statusMatch(statusFilter)) {
       com->clearIOEvents();
+      commands.push_back(std::move(com));
+      continue;
+    }
+    com->transitStatus();
+    if (com->execute()) {
+      com.reset();
+    }
+    else {
+      com->clearIOEvents();
+      com.release();
     }
   }
 }
 } // namespace
 
+namespace {
+class GlobalHaltRequestedFinalizer {
+public:
+  GlobalHaltRequestedFinalizer() {}
+  ~GlobalHaltRequestedFinalizer()
+  {
+    global::globalHaltRequested = 5;
+  }
+};
+} // namespace
+
 int DownloadEngine::run(bool oneshot)
 {
+  GlobalHaltRequestedFinalizer ghrf;
   while(!commands_.empty() || !routineCommands_.empty()) {
     if(!commands_.empty()) {
       waitData();
@@ -186,28 +193,28 @@ void DownloadEngine::waitData()
   eventPoll_->poll(tv);
 }
 
-bool DownloadEngine::addSocketForReadCheck(const SharedHandle<SocketCore>& socket,
+bool DownloadEngine::addSocketForReadCheck(const std::shared_ptr<SocketCore>& socket,
                                            Command* command)
 {
   return eventPoll_->addEvents(socket->getSockfd(), command,
                                EventPoll::EVENT_READ);
 }
 
-bool DownloadEngine::deleteSocketForReadCheck(const SharedHandle<SocketCore>& socket,
+bool DownloadEngine::deleteSocketForReadCheck(const std::shared_ptr<SocketCore>& socket,
                                               Command* command)
 {
   return eventPoll_->deleteEvents(socket->getSockfd(), command,
                                   EventPoll::EVENT_READ);
 }
 
-bool DownloadEngine::addSocketForWriteCheck(const SharedHandle<SocketCore>& socket,
+bool DownloadEngine::addSocketForWriteCheck(const std::shared_ptr<SocketCore>& socket,
                                             Command* command)
 {
   return eventPoll_->addEvents(socket->getSockfd(), command,
                                EventPoll::EVENT_WRITE);
 }
 
-bool DownloadEngine::deleteSocketForWriteCheck(const SharedHandle<SocketCore>& socket,
+bool DownloadEngine::deleteSocketForWriteCheck(const std::shared_ptr<SocketCore>& socket,
                                                Command* command)
 {
   return eventPoll_->deleteEvents(socket->getSockfd(), command,
@@ -237,12 +244,16 @@ void DownloadEngine::afterEachIteration()
     global::globalHaltRequested = 2;
     setNoWait(true);
     setRefreshInterval(0);
-  } else if(global::globalHaltRequested == 3) {
+    return;
+  }
+
+  if(global::globalHaltRequested == 3) {
     A2_LOG_NOTICE(_("Emergency shutdown sequence commencing..."));
     requestForceHalt();
     global::globalHaltRequested = 4;
     setNoWait(true);
     setRefreshInterval(0);
+    return;
   }
 }
 
@@ -258,20 +269,20 @@ void DownloadEngine::requestForceHalt()
   requestGroupMan_->forceHalt();
 }
 
-void DownloadEngine::setStatCalc(const SharedHandle<StatCalc>& statCalc)
+void DownloadEngine::setStatCalc(std::unique_ptr<StatCalc> statCalc)
 {
-  statCalc_ = statCalc;
+  statCalc_ = std::move(statCalc);
 }
 
 #ifdef ENABLE_ASYNC_DNS
 bool DownloadEngine::addNameResolverCheck
-(const SharedHandle<AsyncNameResolver>& resolver, Command* command)
+(const std::shared_ptr<AsyncNameResolver>& resolver, Command* command)
 {
   return eventPoll_->addNameResolver(resolver, command);
 }
 
 bool DownloadEngine::deleteNameResolverCheck
-(const SharedHandle<AsyncNameResolver>& resolver, Command* command)
+(const std::shared_ptr<AsyncNameResolver>& resolver, Command* command)
 {
   return eventPoll_->deleteNameResolver(resolver, command);
 }
@@ -282,9 +293,9 @@ void DownloadEngine::setNoWait(bool b)
   noWait_ = b;
 }
 
-void DownloadEngine::addRoutineCommand(Command* command)
+void DownloadEngine::addRoutineCommand(std::unique_ptr<Command> command)
 {
-  routineCommands_.push_back(command);
+  routineCommands_.push_back(std::move(command));
 }
 
 void DownloadEngine::poolSocket(const std::string& key,
@@ -294,21 +305,21 @@ void DownloadEngine::poolSocket(const std::string& key,
   std::multimap<std::string, SocketPoolEntry>::value_type p(key, entry);
   socketPool_.insert(p);
 
-  if(lastSocketPoolScan_.difference(global::wallclock()) >= 60) {
-    std::multimap<std::string, SocketPoolEntry> newPool;
-    A2_LOG_DEBUG("Scaning SocketPool and erasing timed out entry.");
-    lastSocketPoolScan_ = global::wallclock();
-    for(std::multimap<std::string, SocketPoolEntry>::iterator i =
-          socketPool_.begin(), eoi = socketPool_.end(); i != eoi; ++i) {
-      if(!(*i).second.isTimeout()) {
-        newPool.insert(*i);
-      }
-    }
-    A2_LOG_DEBUG(fmt("%lu entries removed.",
-                     static_cast<unsigned long>
-                     (socketPool_.size()-newPool.size())));
-    socketPool_ = newPool;
+  if(lastSocketPoolScan_.difference(global::wallclock()) < 60) {
+    return;
   }
+  std::multimap<std::string, SocketPoolEntry> newPool;
+  A2_LOG_DEBUG("Scaning SocketPool and erasing timed out entry.");
+  lastSocketPoolScan_ = global::wallclock();
+  for(auto & elem : socketPool_) {
+    if(!elem.second.isTimeout()) {
+      newPool.insert(elem);
+    }
+  }
+  A2_LOG_DEBUG(fmt("%lu entries removed.",
+                    static_cast<unsigned long>
+                    (socketPool_.size()-newPool.size())));
+  socketPool_ = newPool;
 }
 
 namespace {
@@ -336,7 +347,7 @@ void DownloadEngine::poolSocket
  const std::string& username,
  const std::string& proxyhost,
  uint16_t proxyport,
- const SharedHandle<SocketCore>& sock,
+ const std::shared_ptr<SocketCore>& sock,
  const std::string& options,
  time_t timeout)
 {
@@ -349,7 +360,7 @@ void DownloadEngine::poolSocket
  uint16_t port,
  const std::string& proxyhost,
  uint16_t proxyport,
- const SharedHandle<SocketCore>& sock,
+ const std::shared_ptr<SocketCore>& sock,
  time_t timeout)
 {
   SocketPoolEntry e(sock, timeout);
@@ -358,7 +369,7 @@ void DownloadEngine::poolSocket
 
 namespace {
 bool getPeerInfo(std::pair<std::string, uint16_t>& res,
-                 const SharedHandle<SocketCore>& socket)
+                 const std::shared_ptr<SocketCore>& socket)
 {
   try {
     socket->getPeerInfo(res);
@@ -372,44 +383,46 @@ bool getPeerInfo(std::pair<std::string, uint16_t>& res,
 }
 } // namespace
 
-void DownloadEngine::poolSocket(const SharedHandle<Request>& request,
-                                const SharedHandle<Request>& proxyRequest,
-                                const SharedHandle<SocketCore>& socket,
+void DownloadEngine::poolSocket(const std::shared_ptr<Request>& request,
+                                const std::shared_ptr<Request>& proxyRequest,
+                                const std::shared_ptr<SocketCore>& socket,
                                 time_t timeout)
 {
-  if(!proxyRequest) {
-    std::pair<std::string, uint16_t> peerInfo;
-    if(getPeerInfo(peerInfo, socket)) {
-      poolSocket(peerInfo.first, peerInfo.second,
-                 A2STR::NIL, 0, socket, timeout);
-    }
-  } else {
+  if(proxyRequest) {
     // If proxy is defined, then pool socket with its hostname.
     poolSocket(request->getHost(), request->getPort(),
                proxyRequest->getHost(), proxyRequest->getPort(),
                socket, timeout);
+    return;
+  }
+
+  std::pair<std::string, uint16_t> peerInfo;
+  if(getPeerInfo(peerInfo, socket)) {
+    poolSocket(peerInfo.first, peerInfo.second,
+                A2STR::NIL, 0, socket, timeout);
   }
 }
 
 void DownloadEngine::poolSocket
-(const SharedHandle<Request>& request,
+(const std::shared_ptr<Request>& request,
  const std::string& username,
- const SharedHandle<Request>& proxyRequest,
- const SharedHandle<SocketCore>& socket,
+ const std::shared_ptr<Request>& proxyRequest,
+ const std::shared_ptr<SocketCore>& socket,
  const std::string& options,
  time_t timeout)
 {
-  if(!proxyRequest) {
-    std::pair<std::string, uint16_t> peerInfo;
-    if(getPeerInfo(peerInfo, socket)) {
-      poolSocket(peerInfo.first, peerInfo.second, username,
-                 A2STR::NIL, 0, socket, options, timeout);
-    }
-  } else {
+  if(proxyRequest) {
     // If proxy is defined, then pool socket with its hostname.
     poolSocket(request->getHost(), request->getPort(), username,
                proxyRequest->getHost(), proxyRequest->getPort(),
                socket, options, timeout);
+    return;
+  }
+
+  std::pair<std::string, uint16_t> peerInfo;
+  if(getPeerInfo(peerInfo, socket)) {
+    poolSocket(peerInfo.first, peerInfo.second, username,
+                A2STR::NIL, 0, socket, options, timeout);
   }
 }
 
@@ -419,8 +432,7 @@ DownloadEngine::findSocketPoolEntry(const std::string& key)
   std::pair<std::multimap<std::string, SocketPoolEntry>::iterator,
     std::multimap<std::string, SocketPoolEntry>::iterator> range =
     socketPool_.equal_range(key);
-  for(std::multimap<std::string, SocketPoolEntry>::iterator i =
-        range.first, eoi = range.second; i != eoi; ++i) {
+  for(auto i = range.first, eoi = range.second; i != eoi; ++i) {
     const SocketPoolEntry& e = (*i).second;
     // We assume that if socket is readable it means peer shutdowns
     // connection and the socket will receive EOF. So skip it.
@@ -432,15 +444,14 @@ DownloadEngine::findSocketPoolEntry(const std::string& key)
   return socketPool_.end();
 }
 
-SharedHandle<SocketCore>
+std::shared_ptr<SocketCore>
 DownloadEngine::popPooledSocket
 (const std::string& ipaddr, uint16_t port,
  const std::string& proxyhost, uint16_t proxyport)
 {
-  SharedHandle<SocketCore> s;
-  std::multimap<std::string, SocketPoolEntry>::iterator i =
-    findSocketPoolEntry
-    (createSockPoolKey(ipaddr, port, A2STR::NIL, proxyhost, proxyport));
+  std::shared_ptr<SocketCore> s;
+  auto i = findSocketPoolEntry(createSockPoolKey(ipaddr, port, A2STR::NIL,
+                                                 proxyhost, proxyport));
   if(i != socketPool_.end()) {
     s = (*i).second.getSocket();
     socketPool_.erase(i);
@@ -448,17 +459,16 @@ DownloadEngine::popPooledSocket
   return s;
 }
 
-SharedHandle<SocketCore>
+std::shared_ptr<SocketCore>
 DownloadEngine::popPooledSocket
 (std::string& options,
  const std::string& ipaddr, uint16_t port,
  const std::string& username,
  const std::string& proxyhost, uint16_t proxyport)
 {
-  SharedHandle<SocketCore> s;
-  std::multimap<std::string, SocketPoolEntry>::iterator i =
-    findSocketPoolEntry
-    (createSockPoolKey(ipaddr, port, username, proxyhost, proxyport));
+  std::shared_ptr<SocketCore> s;
+  auto i = findSocketPoolEntry(createSockPoolKey(ipaddr, port, username,
+                                                 proxyhost, proxyport));
   if(i != socketPool_.end()) {
     s = (*i).second.getSocket();
     options = (*i).second.getOptions();
@@ -467,14 +477,13 @@ DownloadEngine::popPooledSocket
   return s;
 }
 
-SharedHandle<SocketCore>
+std::shared_ptr<SocketCore>
 DownloadEngine::popPooledSocket
 (const std::vector<std::string>& ipaddrs, uint16_t port)
 {
-  SharedHandle<SocketCore> s;
-  for(std::vector<std::string>::const_iterator i = ipaddrs.begin(),
-        eoi = ipaddrs.end(); i != eoi; ++i) {
-    s = popPooledSocket(*i, port, A2STR::NIL, 0);
+  std::shared_ptr<SocketCore> s;
+  for(const auto & ipaddr : ipaddrs) {
+    s = popPooledSocket(ipaddr, port, A2STR::NIL, 0);
     if(s) {
       break;
     }
@@ -482,16 +491,15 @@ DownloadEngine::popPooledSocket
   return s;
 }
 
-SharedHandle<SocketCore>
+std::shared_ptr<SocketCore>
 DownloadEngine::popPooledSocket
 (std::string& options,
  const std::vector<std::string>& ipaddrs, uint16_t port,
  const std::string& username)
 {
-  SharedHandle<SocketCore> s;
-  for(std::vector<std::string>::const_iterator i = ipaddrs.begin(),
-        eoi = ipaddrs.end(); i != eoi; ++i) {
-    s = popPooledSocket(options, *i, port, username, A2STR::NIL, 0);
+  std::shared_ptr<SocketCore> s;
+  for(const auto & ipaddr : ipaddrs) {
+    s = popPooledSocket(options, ipaddr, port, username, A2STR::NIL, 0);
     if(s) {
       break;
     }
@@ -500,7 +508,7 @@ DownloadEngine::popPooledSocket
 }
 
 DownloadEngine::SocketPoolEntry::SocketPoolEntry
-(const SharedHandle<SocketCore>& socket,
+(const std::shared_ptr<SocketCore>& socket,
  const std::string& options,
  time_t timeout)
   : socket_(socket),
@@ -509,7 +517,7 @@ DownloadEngine::SocketPoolEntry::SocketPoolEntry
 {}
 
 DownloadEngine::SocketPoolEntry::SocketPoolEntry
-(const SharedHandle<SocketCore>& socket, time_t timeout)
+(const std::shared_ptr<SocketCore>& socket, time_t timeout)
   : socket_(socket),
     timeout_(timeout)
 {}
@@ -551,9 +559,20 @@ void DownloadEngine::removeCachedIPAddress
 }
 
 void DownloadEngine::setAuthConfigFactory
-(const SharedHandle<AuthConfigFactory>& factory)
+(std::unique_ptr<AuthConfigFactory> factory)
 {
-  authConfigFactory_ = factory;
+  authConfigFactory_ = std::move(factory);
+}
+
+const std::unique_ptr<AuthConfigFactory>&
+DownloadEngine::getAuthConfigFactory() const
+{
+  return authConfigFactory_;
+}
+
+const std::unique_ptr<CookieStorage>& DownloadEngine::getCookieStorage() const
+{
+  return cookieStorage_;
 }
 
 void DownloadEngine::setRefreshInterval(int64_t interval)
@@ -561,32 +580,34 @@ void DownloadEngine::setRefreshInterval(int64_t interval)
   refreshInterval_ = std::min(static_cast<int64_t>(999), interval);
 }
 
-void DownloadEngine::addCommand(const std::vector<Command*>& commands)
+void DownloadEngine::addCommand
+(std::vector<std::unique_ptr<Command>> commands)
 {
-  commands_.insert(commands_.end(), commands.begin(), commands.end());
+  commands_.insert(commands_.end(),
+                   std::make_move_iterator(std::begin(commands)),
+                   std::make_move_iterator(std::end(commands)));
 }
 
-void DownloadEngine::addCommand(Command* command)
+void DownloadEngine::addCommand(std::unique_ptr<Command> command)
 {
-  commands_.push_back(command);
+  commands_.push_back(std::move(command));
 }
 
-void DownloadEngine::setRequestGroupMan
-(const SharedHandle<RequestGroupMan>& rgman)
+void DownloadEngine::setRequestGroupMan(std::unique_ptr<RequestGroupMan> rgman)
 {
-  requestGroupMan_ = rgman;
+  requestGroupMan_ = std::move(rgman);
 }
 
 void DownloadEngine::setFileAllocationMan
-(const SharedHandle<FileAllocationMan>& faman)
+(std::unique_ptr<FileAllocationMan> faman)
 {
-  fileAllocationMan_ = faman;
+  fileAllocationMan_ = std::move(faman);
 }
 
 void DownloadEngine::setCheckIntegrityMan
-(const SharedHandle<CheckIntegrityMan>& ciman)
+(std::unique_ptr<CheckIntegrityMan> ciman)
 {
-  checkIntegrityMan_ = ciman;
+  checkIntegrityMan_ = std::move(ciman);
 }
 
 #ifdef HAVE_ARES_ADDR_NODE
@@ -604,9 +625,9 @@ void DownloadEngine::setAsyncDNSServers(ares_addr_node* asyncDNSServers)
 
 #ifdef ENABLE_WEBSOCKET
 void DownloadEngine::setWebSocketSessionMan
-(const SharedHandle<rpc::WebSocketSessionMan>& wsman)
+(std::unique_ptr<rpc::WebSocketSessionMan> wsman)
 {
-  webSocketSessionMan_ = wsman;
+  webSocketSessionMan_ = std::move(wsman);
 }
 #endif // ENABLE_WEBSOCKET
 
