@@ -59,6 +59,9 @@
 #include "a2io.h"
 #include "DownloadContext.h"
 #include "array_fun.h"
+#ifdef HAVE_LIBUV
+# include "LibuvEventPoll.h"
+#endif // HAVE_LIBUV
 #ifdef HAVE_EPOLL
 # include "EpollEventPoll.h"
 #endif // HAVE_EPOLL
@@ -81,100 +84,116 @@ namespace aria2 {
 
 DownloadEngineFactory::DownloadEngineFactory() {}
 
-SharedHandle<DownloadEngine>
-DownloadEngineFactory::newDownloadEngine
-(Option* op, const std::vector<SharedHandle<RequestGroup> >& requestGroups)
+namespace {
+std::unique_ptr<EventPoll> createEventPoll(Option* op)
 {
-  const size_t MAX_CONCURRENT_DOWNLOADS =
-    op->getAsInt(PREF_MAX_CONCURRENT_DOWNLOADS);
-  SharedHandle<EventPoll> eventPoll;
   const std::string& pollMethod = op->get(PREF_EVENT_POLL);
+#ifdef HAVE_LIBUV
+  if (pollMethod == V_LIBUV) {
+    auto ep = make_unique<LibuvEventPoll>();
+    if(!ep->good()) {
+      throw DL_ABORT_EX("Initializing LibuvEventPoll failed."
+                        " Try --event-poll=select");
+    }
+    return std::move(ep);
+  }
+  else
+#endif // HAVE_LIBUV
 #ifdef HAVE_EPOLL
   if(pollMethod == V_EPOLL) {
-    SharedHandle<EpollEventPoll> ep(new EpollEventPoll());
-    if(ep->good()) {
-      eventPoll = ep;
-    } else {
+    auto ep = make_unique<EpollEventPoll>();
+    if(!ep->good()) {
       throw DL_ABORT_EX("Initializing EpollEventPoll failed."
                         " Try --event-poll=select");
     }
+    return std::move(ep);
   } else
 #endif // HAVE_EPLL
 #ifdef HAVE_KQUEUE
-    if(pollMethod == V_KQUEUE) {
-      SharedHandle<KqueueEventPoll> kp(new KqueueEventPoll());
-      if(kp->good()) {
-        eventPoll = kp;
-      } else {
-        throw DL_ABORT_EX("Initializing KqueueEventPoll failed."
-                          " Try --event-poll=select");
-      }
-    } else
+  if(pollMethod == V_KQUEUE) {
+    auto kp = make_unique<KqueueEventPoll>();
+    if(!kp->good()) {
+      throw DL_ABORT_EX("Initializing KqueueEventPoll failed."
+                        " Try --event-poll=select");
+    }
+    return std::move(kp);
+  } else
 #endif // HAVE_KQUEUE
 #ifdef HAVE_PORT_ASSOCIATE
-      if(pollMethod == V_PORT) {
-        SharedHandle<PortEventPoll> pp(new PortEventPoll());
-        if(pp->good()) {
-          eventPoll = pp;
-        } else {
-          throw DL_ABORT_EX("Initializing PortEventPoll failed."
-                            " Try --event-poll=select");
-        }
-      } else
+  if(pollMethod == V_PORT) {
+    auto pp = make_unique<PortEventPoll>();
+    if(!pp->good()) {
+      throw DL_ABORT_EX("Initializing PortEventPoll failed."
+                        " Try --event-poll=select");
+    }
+    return std::move(pp);
+  } else
 #endif // HAVE_PORT_ASSOCIATE
 #ifdef HAVE_POLL
-        if(pollMethod == V_POLL) {
-          eventPoll.reset(new PollEventPoll());
-        } else
+  if(pollMethod == V_POLL) {
+    return make_unique<PollEventPoll>();
+  } else
 #endif // HAVE_POLL
-          if(pollMethod == V_SELECT) {
-            eventPoll.reset(new SelectEventPoll());
-          } else {
-            abort();
-          }
-  SharedHandle<DownloadEngine> e(new DownloadEngine(eventPoll));
-  e->setOption(op);
+  if(pollMethod == V_SELECT) {
+    return make_unique<SelectEventPoll>();
+  }
+  assert(0);
+  return nullptr;
+}
+} // namespace
 
-  SharedHandle<RequestGroupMan>
-    requestGroupMan(new RequestGroupMan(requestGroups, MAX_CONCURRENT_DOWNLOADS,
-                                        op));
-  requestGroupMan->initWrDiskCache();
-  e->setRequestGroupMan(requestGroupMan);
-  e->setFileAllocationMan
-    (SharedHandle<FileAllocationMan>(new FileAllocationMan()));
+std::unique_ptr<DownloadEngine>
+DownloadEngineFactory::newDownloadEngine
+(Option* op, std::vector<std::shared_ptr<RequestGroup>> requestGroups)
+{
+  const size_t MAX_CONCURRENT_DOWNLOADS =
+    op->getAsInt(PREF_MAX_CONCURRENT_DOWNLOADS);
+  auto e = make_unique<DownloadEngine>(createEventPoll(op));
+  e->setOption(op);
+  {
+    auto requestGroupMan = make_unique<RequestGroupMan>
+      (std::move(requestGroups), MAX_CONCURRENT_DOWNLOADS, op);
+    requestGroupMan->initWrDiskCache();
+    e->setRequestGroupMan(std::move(requestGroupMan));
+  }
+  e->setFileAllocationMan(make_unique<FileAllocationMan>());
 #ifdef ENABLE_MESSAGE_DIGEST
-  e->setCheckIntegrityMan
-    (SharedHandle<CheckIntegrityMan>(new CheckIntegrityMan()));
+  e->setCheckIntegrityMan(make_unique<CheckIntegrityMan>());
 #endif // ENABLE_MESSAGE_DIGEST
-  e->addRoutineCommand(new FillRequestGroupCommand(e->newCUID(), e.get()));
-  e->addRoutineCommand(new FileAllocationDispatcherCommand
-                       (e->newCUID(), e->getFileAllocationMan(), e.get()));
+  e->addRoutineCommand(make_unique<FillRequestGroupCommand>
+                       (e->newCUID(), e.get()));
+  e->addRoutineCommand(make_unique<FileAllocationDispatcherCommand>
+                       (e->newCUID(), e->getFileAllocationMan().get(),
+                        e.get()));
 #ifdef ENABLE_MESSAGE_DIGEST
-  e->addRoutineCommand(new CheckIntegrityDispatcherCommand
-                       (e->newCUID(), e->getCheckIntegrityMan(), e.get()));
+  e->addRoutineCommand(make_unique<CheckIntegrityDispatcherCommand>
+                       (e->newCUID(), e->getCheckIntegrityMan().get(),
+                        e.get()));
 #endif // ENABLE_MESSAGE_DIGEST
 
   if(op->getAsInt(PREF_AUTO_SAVE_INTERVAL) > 0) {
     e->addRoutineCommand
-      (new AutoSaveCommand(e->newCUID(), e.get(),
-                           op->getAsInt(PREF_AUTO_SAVE_INTERVAL)));
+      (make_unique<AutoSaveCommand>(e->newCUID(), e.get(),
+                                    op->getAsInt(PREF_AUTO_SAVE_INTERVAL)));
   }
   if(op->getAsInt(PREF_SAVE_SESSION_INTERVAL) > 0) {
-    e->addRoutineCommand
-      (new SaveSessionCommand(e->newCUID(), e.get(),
-                              op->getAsInt(PREF_SAVE_SESSION_INTERVAL)));
+    e->addRoutineCommand(make_unique<SaveSessionCommand>
+                         (e->newCUID(), e.get(),
+                          op->getAsInt(PREF_SAVE_SESSION_INTERVAL)));
   }
-  e->addRoutineCommand(new HaveEraseCommand(e->newCUID(), e.get(), 10));
+  e->addRoutineCommand(make_unique<HaveEraseCommand>
+                       (e->newCUID(), e.get(), 10));
   {
     time_t stopSec = op->getAsInt(PREF_STOP);
     if(stopSec > 0) {
-      e->addRoutineCommand(new TimedHaltCommand(e->newCUID(), e.get(),
-                                                stopSec));
+      e->addRoutineCommand(make_unique<TimedHaltCommand>(e->newCUID(), e.get(),
+                                                         stopSec));
     }
   }
   if(op->defined(PREF_STOP_WITH_PROCESS)) {
     unsigned int pid = op->getAsInt(PREF_STOP_WITH_PROCESS);
-    e->addRoutineCommand(new WatchProcessCommand(e->newCUID(), e.get(), pid));
+    e->addRoutineCommand(make_unique<WatchProcessCommand>(e->newCUID(),
+                                                          e.get(), pid));
   }
   if(op->getAsBool(PREF_ENABLE_RPC)) {
     bool ok = false;
@@ -185,13 +204,11 @@ DownloadEngineFactory::newDownloadEngine
     static int families[] = { AF_INET, AF_INET6 };
     size_t familiesLength = op->getAsBool(PREF_DISABLE_IPV6)?1:2;
     for(size_t i = 0; i < familiesLength; ++i) {
-      HttpListenCommand* httpListenCommand =
-        new HttpListenCommand(e->newCUID(), e.get(), families[i], secure);
+      auto httpListenCommand = make_unique<HttpListenCommand>
+        (e->newCUID(), e.get(), families[i], secure);
       if(httpListenCommand->bindPort(op->getAsInt(PREF_RPC_LISTEN_PORT))){
-        e->addCommand(httpListenCommand);
+        e->addCommand(std::move(httpListenCommand));
         ok = true;
-      } else {
-        delete httpListenCommand;
       }
     }
     if(!ok) {
