@@ -40,8 +40,8 @@
 #include <deque>
 #include <algorithm>
 #include <functional>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "a2netcompat.h"
 #include "Command.h"
 #ifdef ENABLE_ASYNC_DNS
@@ -59,10 +59,10 @@ public:
 
   virtual int getEvents() const = 0;
 
-  virtual void addSelf(const SharedHandle<SocketEntry>& socketEntry) const = 0;
+  virtual void addSelf(const std::shared_ptr<SocketEntry>& socketEntry) const = 0;
 
   virtual void removeSelf
-  (const SharedHandle<SocketEntry>& socketEntry) const = 0;
+  (const std::shared_ptr<SocketEntry>& socketEntry) const = 0;
 };
 
 template<typename SocketEntry, typename EventPoll>
@@ -78,7 +78,7 @@ public:
   {
     return command_;
   }
-    
+
   void addEvents(int events)
   {
     events_ |= events;
@@ -86,14 +86,14 @@ public:
 
   void removeEvents(int events)
   {
-    events_ &= (~events); 
+    events_ &= (~events);
   }
 
   bool eventsEmpty() const
   {
     return events_ == 0;
   }
-        
+
   bool operator==(const CommandEvent& commandEvent) const
   {
     return command_ == commandEvent.command_;
@@ -124,28 +124,28 @@ public:
     }
   }
 
-  virtual void addSelf(const SharedHandle<SocketEntry>& socketEntry) const
+  virtual void addSelf(const std::shared_ptr<SocketEntry>& socketEntry) const
   {
     socketEntry->addCommandEvent(*this);
   }
 
-  virtual void removeSelf(const SharedHandle<SocketEntry>& socketEntry) const
+  virtual void removeSelf(const std::shared_ptr<SocketEntry>& socketEntry) const
   {
     socketEntry->removeCommandEvent(*this);
   }
 };
-  
+
 #ifdef ENABLE_ASYNC_DNS
 
 template<typename SocketEntry, typename EventPoll>
 class ADNSEvent : public Event<SocketEntry> {
 private:
-  SharedHandle<AsyncNameResolver> resolver_;
+  std::shared_ptr<AsyncNameResolver> resolver_;
   Command* command_;
   sock_t socket_;
   int events_;
 public:
-  ADNSEvent(const SharedHandle<AsyncNameResolver>& resolver, Command* command,
+  ADNSEvent(const std::shared_ptr<AsyncNameResolver>& resolver, Command* command,
             sock_t socket, int events):
     resolver_(resolver), command_(command), socket_(socket), events_(events) {}
 
@@ -153,7 +153,7 @@ public:
   {
     return *resolver_ == *event.resolver_;
   }
-    
+
   virtual int getEvents() const
   {
     return events_;
@@ -179,12 +179,12 @@ public:
     command_->setStatusActive();
   }
 
-  virtual void addSelf(const SharedHandle<SocketEntry>& socketEntry) const
+  virtual void addSelf(const std::shared_ptr<SocketEntry>& socketEntry) const
   {
     socketEntry->addADNSEvent(*this);
   }
 
-  virtual void removeSelf(const SharedHandle<SocketEntry>& socketEntry) const
+  virtual void removeSelf(const std::shared_ptr<SocketEntry>& socketEntry) const
   {
     socketEntry->removeADNSEvent(*this);
   }
@@ -198,11 +198,11 @@ template<typename CommandEvent, typename ADNSEvent>
 class SocketEntry {
 protected:
   sock_t socket_;
-    
+
   std::deque<CommandEvent> commandEvents_;
-    
+
 #ifdef ENABLE_ASYNC_DNS
-    
+
   std::deque<ADNSEvent> adnsEvents_;
 
 #endif // ENABLE_ASYNC_DNS
@@ -247,7 +247,7 @@ public:
   }
 
 #ifdef ENABLE_ASYNC_DNS
-    
+
   void addADNSEvent(const ADNSEvent& aev)
   {
     typename std::deque<ADNSEvent>::iterator i =
@@ -287,18 +287,15 @@ public:
     return commandEvents_.empty();
 #endif // !ENABLE_ASYNC_DNS)
   }
-    
+
   void processEvents(int events)
   {
+    using namespace std::placeholders;
     std::for_each(commandEvents_.begin(), commandEvents_.end(),
-                  std::bind2nd(std::mem_fun_ref
-                               (&CommandEvent::processEvents),
-                               events));
+                  std::bind(&CommandEvent::processEvents, _1, events));
 #ifdef ENABLE_ASYNC_DNS
     std::for_each(adnsEvents_.begin(), adnsEvents_.end(),
-                  std::bind2nd(std::mem_fun_ref
-                               (&ADNSEvent::processEvents),
-                               events));
+                  std::bind(&ADNSEvent::processEvents, _1, events));
 #endif // ENABLE_ASYNC_DNS
   }
 };
@@ -308,16 +305,16 @@ public:
 template<typename EventPoll>
 class AsyncNameResolverEntry {
 private:
-  SharedHandle<AsyncNameResolver> nameResolver_;
+  std::shared_ptr<AsyncNameResolver> nameResolver_;
 
   Command* command_;
 
   size_t socketsSize_;
-  
+
   sock_t sockets_[ARES_GETSOCK_MAXNUM];
 
 public:
-  AsyncNameResolverEntry(const SharedHandle<AsyncNameResolver>& nameResolver,
+  AsyncNameResolverEntry(const std::shared_ptr<AsyncNameResolver>& nameResolver,
                          Command* command):
     nameResolver_(nameResolver), command_(command), socketsSize_(0) {}
 
@@ -358,7 +355,7 @@ public:
     }
     socketsSize_ = i;
   }
-    
+
   void removeSocketEvents(EventPoll* e)
   {
     for(size_t i = 0; i < socketsSize_; ++i) {
