@@ -50,7 +50,7 @@
 #include "AuthConfig.h"
 #include "DlRetryEx.h"
 #include "DlAbortEx.h"
-#include "Socket.h"
+#include "SocketCore.h"
 #include "A2STR.h"
 #include "fmt.h"
 #include "AuthConfig.h"
@@ -62,9 +62,9 @@ namespace aria2 {
 
 FtpConnection::FtpConnection
 (cuid_t cuid,
- const SocketHandle& socket,
- const SharedHandle<Request>& req,
- const SharedHandle<AuthConfig>& authConfig,
+ const std::shared_ptr<SocketCore>& socket,
+ const std::shared_ptr<Request>& req,
+ const std::shared_ptr<AuthConfig>& authConfig,
  const Option* op)
   : cuid_(cuid),
     socket_(socket),
@@ -85,7 +85,7 @@ bool FtpConnection::sendUser()
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, "USER ********"));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -99,7 +99,7 @@ bool FtpConnection::sendPass()
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, "PASS ********"));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -113,7 +113,7 @@ bool FtpConnection::sendType()
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_,request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -125,7 +125,7 @@ bool FtpConnection::sendPwd()
     std::string request = "PWD\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_,request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -139,7 +139,7 @@ bool FtpConnection::sendCwd(const std::string& dir)
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_,request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -154,7 +154,7 @@ bool FtpConnection::sendMdtm()
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -169,7 +169,7 @@ bool FtpConnection::sendSize()
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -181,7 +181,7 @@ bool FtpConnection::sendEpsv()
     std::string request("EPSV\r\n");
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -193,24 +193,23 @@ bool FtpConnection::sendPasv()
     std::string request("PASV\r\n");
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
 }
 
-SharedHandle<SocketCore> FtpConnection::createServerSocket()
+std::shared_ptr<SocketCore> FtpConnection::createServerSocket()
 {
   std::pair<std::string, uint16_t> addrinfo;
   socket_->getAddrInfo(addrinfo);
-  SharedHandle<SocketCore> serverSocket(new SocketCore());
-  serverSocket->bind(addrinfo.first, 0, AF_UNSPEC);
+  std::shared_ptr<SocketCore> serverSocket(new SocketCore());
+  serverSocket->bind(addrinfo.first.c_str(), 0, AF_UNSPEC);
   serverSocket->beginListen();
-  serverSocket->setNonBlockingMode();
   return serverSocket;
 }
 
-bool FtpConnection::sendEprt(const SharedHandle<SocketCore>& serverSocket)
+bool FtpConnection::sendEprt(const std::shared_ptr<SocketCore>& serverSocket)
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
     sockaddr_union sockaddr;
@@ -224,13 +223,13 @@ bool FtpConnection::sendEprt(const SharedHandle<SocketCore>& serverSocket)
           addrinfo.first.c_str(),
           addrinfo.second);
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST, cuid_, request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
 }
 
-bool FtpConnection::sendPort(const SharedHandle<SocketCore>& serverSocket)
+bool FtpConnection::sendPort(const std::shared_ptr<SocketCore>& serverSocket)
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
     std::pair<std::string, uint16_t> addrinfo;
@@ -244,13 +243,13 @@ bool FtpConnection::sendPort(const SharedHandle<SocketCore>& serverSocket)
                               addrinfo.second/256, addrinfo.second%256);
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
 }
 
-bool FtpConnection::sendRest(const SharedHandle<Segment>& segment)
+bool FtpConnection::sendRest(const std::shared_ptr<Segment>& segment)
 {
   if(socketBuffer_.sendBufferIsEmpty()) {
     std::string request =
@@ -259,7 +258,7 @@ bool FtpConnection::sendRest(const SharedHandle<Segment>& segment)
           segment->getPositionToWrite() : static_cast<int64_t>(0LL));
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -274,7 +273,7 @@ bool FtpConnection::sendRetr()
     request += "\r\n";
     A2_LOG_INFO(fmt(MSG_SENDING_REQUEST,
                     cuid_, request.c_str()));
-    socketBuffer_.pushStr(request);
+    socketBuffer_.pushStr(std::move(request));
   }
   socketBuffer_.send();
   return socketBuffer_.sendBufferIsEmpty();
@@ -314,7 +313,7 @@ FtpConnection::findEndOfResponse
     if(p == std::string::npos) {
       return std::string::npos;
     }
-    p = buf.find(A2STR::CRLF, p+6);
+    p = buf.find("\r\n", p+6);
     if(p == std::string::npos) {
       return std::string::npos;
     } else {
@@ -322,7 +321,7 @@ FtpConnection::findEndOfResponse
     }
   } else {
     // single line response
-    std::string::size_type p = buf.find(A2STR::CRLF);    
+    std::string::size_type p = buf.find("\r\n");
     if(p == std::string::npos) {
       return std::string::npos;
     } else {
@@ -333,7 +332,7 @@ FtpConnection::findEndOfResponse
 
 bool FtpConnection::bulkReceiveResponse(std::pair<int, std::string>& response)
 {
-  char buf[1024];  
+  char buf[1024];
   while(1) {
     size_t size = sizeof(buf);
     socket_->readData(buf, size);
@@ -404,11 +403,13 @@ int FtpConnection::receiveSizeResponse(int64_t& size)
   std::pair<int, std::string> response;
   if(bulkReceiveResponse(response)) {
     if(response.first == 213) {
-      std::pair<Sip, Sip> rp;
-      util::divide(rp, response.second.begin(), response.second.end(), ' ');
-      size = util::parseLLInt(std::string(rp.second.first, rp.second.second));
-      if(size < 0) {
-        throw DL_ABORT_EX("Size must be positive");
+      auto rp = util::divide(std::begin(response.second),
+                             std::end(response.second),
+                             ' ');
+      if(!util::parseLLIntNoThrow(size, std::string(rp.second.first,
+                                                    rp.second.second)) ||
+         size < 0) {
+        throw DL_ABORT_EX("Size must be positive integer");
       }
     }
     return response.first;
@@ -417,6 +418,25 @@ int FtpConnection::receiveSizeResponse(int64_t& size)
   }
 }
 
+namespace {
+template<typename T>
+bool getInteger(T* dest, const char* first, const char* last)
+{
+  int res = 0;
+  // We assume *dest won't overflow.
+  for(; first != last; ++first) {
+    if(util::isDigit(*first)) {
+      res *= 10;
+      res += (*first)-'0';
+    } else {
+      return false;
+    }
+  }
+  *dest = res;
+  return true;
+}
+} // namespace
+
 int FtpConnection::receiveMdtmResponse(Time& time)
 {
   // MDTM command, specified in RFC3659.
@@ -430,13 +450,18 @@ int FtpConnection::receiveMdtmResponse(Time& time)
         // and included strptime doesn't parse data for this format.
         struct tm tm;
         memset(&tm, 0, sizeof(tm));
-        tm.tm_sec = util::parseInt(std::string(&buf[12], &buf[14]));
-        tm.tm_min = util::parseInt(std::string(&buf[10], &buf[12]));
-        tm.tm_hour = util::parseInt(std::string(&buf[8], &buf[10]));
-        tm.tm_mday = util::parseInt(std::string(&buf[6], &buf[8]));
-        tm.tm_mon = util::parseInt(std::string(&buf[4], &buf[6]))-1;
-        tm.tm_year = util::parseInt(std::string(&buf[0], &buf[4]))-1900;
-        time = Time(timegm(&tm));
+        if(getInteger(&tm.tm_sec, &buf[12], &buf[14]) &&
+           getInteger(&tm.tm_min, &buf[10], &buf[12]) &&
+           getInteger(&tm.tm_hour, &buf[8], &buf[10]) &&
+           getInteger(&tm.tm_mday, &buf[6], &buf[8]) &&
+           getInteger(&tm.tm_mon, &buf[4], &buf[6]) &&
+           getInteger(&tm.tm_year, &buf[0], &buf[4])) {
+          tm.tm_mon -= 1;
+          tm.tm_year -= 1900;
+          time = Time(timegm(&tm));
+        } else {
+          time = Time::null();
+        }
       } else {
         time = Time::null();
       }
