@@ -50,15 +50,15 @@ namespace aria2 {
 
 FtpDownloadCommand::FtpDownloadCommand
 (cuid_t cuid,
- const SharedHandle<Request>& req,
- const SharedHandle<FileEntry>& fileEntry,
+ const std::shared_ptr<Request>& req,
+ const std::shared_ptr<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
- const SharedHandle<FtpConnection>& ftpConnection,
+ const std::shared_ptr<FtpConnection>& ftpConnection,
  DownloadEngine* e,
- const SharedHandle<SocketCore>& dataSocket,
- const SharedHandle<SocketCore>& ctrlSocket)
+ const std::shared_ptr<SocketCore>& dataSocket,
+ const std::shared_ptr<SocketCore>& ctrlSocket)
   :DownloadCommand(cuid, req, fileEntry, requestGroup, e, dataSocket,
-                   SharedHandle<SocketRecvBuffer>
+                   std::shared_ptr<SocketRecvBuffer>
                    (new SocketRecvBuffer(dataSocket))),
    ftpConnection_(ftpConnection),
    ctrlSocket_(ctrlSocket) {}
@@ -70,10 +70,10 @@ bool FtpDownloadCommand::prepareForNextSegment()
   if(getOption()->getAsBool(PREF_FTP_REUSE_CONNECTION) &&
      getFileEntry()->gtoloff(getSegments().front()->getPositionToWrite()) ==
      getFileEntry()->getLength()) {
-    Command* command = new FtpFinishDownloadCommand
-      (getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
-       ftpConnection_, getDownloadEngine(), ctrlSocket_);
-    getDownloadEngine()->addCommand(command);
+    getDownloadEngine()->addCommand
+      (make_unique<FtpFinishDownloadCommand>
+       (getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
+        ftpConnection_, getDownloadEngine(), ctrlSocket_));
 
     if(getRequestGroup()->downloadFinished()) {
       // To run checksum checking, we had to call following function here.
