@@ -52,23 +52,24 @@ private:
   static const size_t OUTBUF_LENGTH = 16*1024;
 public:
   GZipDecodingStreamFilter
-  (const SharedHandle<StreamFilter>& delegate = SharedHandle<StreamFilter>());
+  (std::unique_ptr<StreamFilter> delegate = nullptr);
 
   virtual ~GZipDecodingStreamFilter();
 
-  virtual void init();
+  virtual void init() CXX11_OVERRIDE;
 
-  virtual ssize_t transform(const SharedHandle<BinaryStream>& out,
-                            const SharedHandle<Segment>& segment,
-                            const unsigned char* inbuf, size_t inlen);
+  virtual ssize_t transform(const std::shared_ptr<BinaryStream>& out,
+                            const std::shared_ptr<Segment>& segment,
+                            const unsigned char* inbuf, size_t inlen)
+    CXX11_OVERRIDE;
 
-  virtual bool finished();
+  virtual bool finished() CXX11_OVERRIDE;
 
-  virtual void release();
+  virtual void release() CXX11_OVERRIDE;
 
-  virtual const std::string& getName() const;
+  virtual const std::string& getName() const CXX11_OVERRIDE;
 
-  virtual size_t getBytesProcessed() const
+  virtual size_t getBytesProcessed() const CXX11_OVERRIDE
   {
     return bytesProcessed_;
   }
