@@ -35,18 +35,20 @@
 #include "HttpProxyRequestCommand.h"
 #include "HttpProxyResponseCommand.h"
 #include "Request.h"
-#include "Socket.h"
+#include "SocketCore.h"
+#include "SocketRecvBuffer.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
 HttpProxyRequestCommand::HttpProxyRequestCommand
 (cuid_t cuid,
- const SharedHandle<Request>& req,
- const SharedHandle<FileEntry>& fileEntry,
+ const std::shared_ptr<Request>& req,
+ const std::shared_ptr<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
  DownloadEngine* e,
- const SharedHandle<Request>& proxyRequest,
- const SocketHandle& s)
+ const std::shared_ptr<Request>& proxyRequest,
+ const std::shared_ptr<SocketCore>& s)
   :
   AbstractProxyRequestCommand(cuid, req, fileEntry, requestGroup, e,
                               proxyRequest, s)
@@ -54,9 +56,9 @@ HttpProxyRequestCommand::HttpProxyRequestCommand
 
 HttpProxyRequestCommand::~HttpProxyRequestCommand() {}
 
-Command* HttpProxyRequestCommand::getNextCommand()
+std::unique_ptr<Command> HttpProxyRequestCommand::getNextCommand()
 {
-  return new HttpProxyResponseCommand
+  return make_unique<HttpProxyResponseCommand>
     (getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
      getHttpConnection(), getDownloadEngine(), getSocket());
 }
