@@ -32,11 +32,13 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_SERVER_COMMAND_H_
-#define _D_HTTP_SERVER_COMMAND_H_
+#ifndef D_HTTP_SERVER_COMMAND_H
+#define D_HTTP_SERVER_COMMAND_H
 
 #include "Command.h"
-#include "SharedHandle.h"
+
+#include <memory>
+
 #include "TimerA2.h"
 
 namespace aria2 {
@@ -47,24 +49,29 @@ class HttpServer;
 
 class HttpServerCommand : public Command {
 private:
-  DownloadEngine* _e;
-  SharedHandle<SocketCore> _socket;
-  SharedHandle<HttpServer> _httpServer;
-  Timer _timeoutTimer;
+  DownloadEngine* e_;
+  std::shared_ptr<SocketCore> socket_;
+  std::shared_ptr<HttpServer> httpServer_;
+  Timer timeoutTimer_;
+  bool writeCheck_;
+
+  void checkSocketRecvBuffer();
+  void updateWriteCheck();
 public:
   HttpServerCommand(cuid_t cuid, DownloadEngine* e,
-                    const SharedHandle<SocketCore>& socket);
+                    const std::shared_ptr<SocketCore>& socket,
+                    bool secure);
 
   HttpServerCommand(cuid_t cuid,
-                    const SharedHandle<HttpServer>& httpServer,
+                    const std::shared_ptr<HttpServer>& httpServer,
                     DownloadEngine* e,
-                    const SharedHandle<SocketCore>& socket);
+                    const std::shared_ptr<SocketCore>& socket);
 
   virtual ~HttpServerCommand();
-  
-  virtual bool execute();
+
+  virtual bool execute() CXX11_OVERRIDE;
 };
 
-} // namespace aria2 
+} // namespace aria2
 
-#endif // _D_HTTP_SERVER_COMMAND_H_
+#endif // D_HTTP_SERVER_COMMAND_H
