@@ -65,17 +65,17 @@ namespace aria2 {
 
 HttpSkipResponseCommand::HttpSkipResponseCommand
 (cuid_t cuid,
- const SharedHandle<Request>& req,
- const SharedHandle<FileEntry>& fileEntry,
+ const std::shared_ptr<Request>& req,
+ const std::shared_ptr<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
- const SharedHandle<HttpConnection>& httpConnection,
- const SharedHandle<HttpResponse>& httpResponse,
+ const std::shared_ptr<HttpConnection>& httpConnection,
+ std::unique_ptr<HttpResponse> httpResponse,
  DownloadEngine* e,
- const SharedHandle<SocketCore>& s)
+ const std::shared_ptr<SocketCore>& s)
   : AbstractCommand(cuid, req, fileEntry, requestGroup, e, s,
                     httpConnection->getSocketRecvBuffer()),
     httpConnection_(httpConnection),
-    httpResponse_(httpResponse),
+    httpResponse_(std::move(httpResponse)),
     streamFilter_(new NullSinkStreamFilter()),
     sinkFilterOnly_(true),
     totalLength_(httpResponse_->getEntityLength()),
@@ -87,13 +87,13 @@ HttpSkipResponseCommand::HttpSkipResponseCommand
 HttpSkipResponseCommand::~HttpSkipResponseCommand() {}
 
 void HttpSkipResponseCommand::installStreamFilter
-(const SharedHandle<StreamFilter>& streamFilter)
+(std::unique_ptr<StreamFilter> streamFilter)
 {
   if(!streamFilter) {
     return;
   }
-  streamFilter->installDelegate(streamFilter_);
-  streamFilter_ = streamFilter;
+  streamFilter->installDelegate(std::move(streamFilter_));
+  streamFilter_ = std::move(streamFilter);
   const std::string& name = streamFilter_->getName();
   sinkFilterOnly_ = util::endsWith(name, SinkStreamFilter::NAME);
 }
@@ -132,8 +132,8 @@ bool HttpSkipResponseCommand::executeInternal()
       } else {
         // receivedBytes_ is not updated if transferEncoding is set.
         // The return value is safely ignored here.
-        streamFilter_->transform(SharedHandle<BinaryStream>(),
-                                 SharedHandle<Segment>(),
+        streamFilter_->transform(std::shared_ptr<BinaryStream>(),
+                                 std::shared_ptr<Segment>(),
                                  getSocketRecvBuffer()->getBuffer(),
                                  getSocketRecvBuffer()->getBufferLength());
         bufSize = streamFilter_->getBytesProcessed();
@@ -148,13 +148,17 @@ bool HttpSkipResponseCommand::executeInternal()
     return processResponse();
   }
 
+  if(eof) {
+    // we may get EOF before non-sink streamFilter reports its
+    // completion. There are some broken servers to prevent
+    // streamFilter from completion. Since we just discard the
+    // response body anyway, so we assume that the response is
+    // completed.
+    return processResponse();
+  }
   bool finished = false;
   if(sinkFilterOnly_) {
-    if(eof) {
-      return processResponse();
-    } else {
-      finished = (totalLength_ == receivedBytes_);
-    }
+    finished = (totalLength_ == receivedBytes_);
   } else {
     finished = streamFilter_->finished();
   }
@@ -169,7 +173,7 @@ bool HttpSkipResponseCommand::executeInternal()
     return processResponse();
   } else {
     setWriteCheckSocketIf(getSocket(), getSocket()->wantWrite());
-    getDownloadEngine()->addCommand(this);
+    addCommandSelf();
     return false;
   }
 }
