@@ -47,13 +47,12 @@ private:
   static const size_t MESSAGE_LENGTH = 9;
 protected:
   template<typename T>
-  static T* create(const unsigned char* data, size_t dataLength)
+  static std::unique_ptr<T> create(const unsigned char* data,
+                                   size_t dataLength)
   {
     bittorrent::assertPayloadLengthEqual(5, dataLength, T::NAME);
     bittorrent::assertID(T::ID, data, T::NAME);
-    T* message(new T());
-    message->setIndex(bittorrent::getIntParam(data, 1));
-    return message;
+    return make_unique<T>(bittorrent::getIntParam(data, 1));
   }
 public:
   IndexBtMessage(uint8_t id, const char* name, size_t index)
@@ -64,11 +63,11 @@ public:
 
   size_t getIndex() const { return index_; }
 
-  virtual unsigned char* createMessage();
+  virtual unsigned char* createMessage() CXX11_OVERRIDE;
 
-  virtual size_t getMessageLength();
+  virtual size_t getMessageLength() CXX11_OVERRIDE;
 
-  virtual std::string toString() const;
+  virtual std::string toString() const CXX11_OVERRIDE;
 };
 
 } // namespace aria2
