@@ -32,32 +32,27 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_INDEX_BT_VALIDATOR_H_
-#define _D_INDEX_BT_VALIDATOR_H_
+#ifndef D_INDEX_BT_VALIDATOR_H
+#define D_INDEX_BT_VALIDATOR_H
 
 #include "BtMessageValidator.h"
-#include "IndexBtMessage.h"
-#include "bittorrent_helper.h"
 
 namespace aria2 {
 
+class IndexBtMessage;
+
 class IndexBtMessageValidator : public BtMessageValidator {
 private:
-  const IndexBtMessage* _message;
-  size_t _numPiece;
+  const IndexBtMessage* message_;
+  size_t numPiece_;
 public:
-  IndexBtMessageValidator(const IndexBtMessage* message,
-                          size_t numPiece):
-    _message(message),
-    _numPiece(numPiece) {}
+  IndexBtMessageValidator(const IndexBtMessage* message, size_t numPiece);
 
-  virtual void validate()
-  {
-    bittorrent::checkIndex(_message->getIndex(), _numPiece);
-  }
+  ~IndexBtMessageValidator();
 
+  virtual void validate() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_INDEX_BT_MESSAGE_VALIDATOR_H_
+#endif // D_INDEX_BT_MESSAGE_VALIDATOR_H
