@@ -34,14 +34,18 @@
 /* copyright --> */
 #include "LibgnutlsTLSContext.h"
 
+#include <sstream>
+
 #ifdef HAVE_LIBGNUTLS
 # include <gnutls/x509.h>
+# include <gnutls/pkcs12.h>
 #endif // HAVE_LIBGNUTLS
 
 #include "LogFactory.h"
 #include "Logger.h"
 #include "fmt.h"
 #include "message.h"
+#include "BufferedFile.h"
 
 namespace aria2 {
 
@@ -83,6 +87,9 @@ bool GnuTLSContext::good() const
 bool GnuTLSContext::addCredentialFile(const std::string& certfile,
                                    const std::string& keyfile)
 {
+  if (keyfile.empty()) {
+    return addP12CredentialFile(certfile);
+  }
   int ret = gnutls_certificate_set_x509_key_file(certCred_,
                                                  certfile.c_str(),
                                                  keyfile.c_str(),
@@ -100,6 +107,25 @@ bool GnuTLSContext::addCredentialFile(const std::string& certfile,
     return false;
   }
 }
+bool GnuTLSContext::addP12CredentialFile(const std::string& p12file)
+{
+  std::stringstream ss;
+  BufferedFile(p12file.c_str(), "rb").transfer(ss);
+  auto datastr = ss.str();
+  const gnutls_datum_t data = {
+    (unsigned char*)datastr.c_str(),
+    (unsigned int)datastr.length()
+  };
+  int err = gnutls_certificate_set_x509_simple_pkcs12_mem(
+      certCred_, &data, GNUTLS_X509_FMT_DER, "");
+  if (err != GNUTLS_E_SUCCESS) {
+    A2_LOG_ERROR("Failed to import PKCS12 file. "
+                 "If you meant to use PEM, you'll also have to specify "
+                 "--rpc-private-key. See the manual.");
+    return false;
+  }
+  return true;
+}
 
 bool GnuTLSContext::addSystemTrustedCACerts()
 {
