@@ -46,7 +46,8 @@ public:
   // { 1,2,3,4,7,10,11,12,13,14,15,100,112,113,114 }, then
   // returns 15 because { 10, 11, 12, 13, 14, 15 } is the longest sequence.
   virtual bool select
-  (size_t& index, const unsigned char* bitfield, size_t nbits) const;
+  (size_t& index, const unsigned char* bitfield, size_t nbits) const
+    CXX11_OVERRIDE;
 };
 
 } // namespace aria2
