@@ -42,7 +42,7 @@
 #include "LogFactory.h"
 #include "Logger.h"
 #include "BtHandshakeMessage.h"
-#include "Socket.h"
+#include "SocketCore.h"
 #include "a2netcompat.h"
 #include "DHKeyExchange.h"
 #include "ARC4Encryptor.h"
@@ -72,7 +72,7 @@ const unsigned char* GENERATOR = reinterpret_cast<const unsigned char*>("2");
 
 MSEHandshake::MSEHandshake
 (cuid_t cuid,
- const SocketHandle& socket,
+ const std::shared_ptr<SocketCore>& socket,
  const Option* op)
   : cuid_(cuid),
     socket_(socket),
@@ -81,12 +81,12 @@ MSEHandshake::MSEHandshake
     rbufLength_(0),
     socketBuffer_(socket),
     negotiatedCryptoType_(CRYPTO_NONE),
-    dh_(0),
+    dh_(nullptr),
     initiator_(true),
     markerIndex_(0),
     padLength_(0),
     iaLength_(0),
-    ia_(0),
+    ia_(nullptr),
     sha1_(MessageDigest::sha1())
 {}
 
@@ -104,14 +104,13 @@ MSEHandshake::HANDSHAKE_TYPE MSEHandshake::identifyHandshakeType()
   }
   if(rbuf_[0] == BtHandshakeMessage::PSTR_LENGTH &&
      memcmp(BtHandshakeMessage::BT_PSTR, rbuf_+1, 19) == 0) {
-    A2_LOG_DEBUG(fmt("CUID#%lld - This is legacy BitTorrent handshake.",
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - This is legacy BitTorrent handshake.",
                      cuid_));
     return HANDSHAKE_LEGACY;
-  } else {
-    A2_LOG_DEBUG(fmt("CUID#%lld - This may be encrypted BitTorrent handshake.",
-                     cuid_));
-    return HANDSHAKE_ENCRYPTED;
   }
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - This may be encrypted BitTorrent handshake.",
+                    cuid_));
+  return HANDSHAKE_ENCRYPTED;
 }
 
 void MSEHandshake::initEncryptionFacility(bool initiator)
@@ -120,23 +119,21 @@ void MSEHandshake::initEncryptionFacility(bool initiator)
   dh_ = new DHKeyExchange();
   dh_->init(PRIME, PRIME_BITS, GENERATOR, 160);
   dh_->generatePublicKey();
-  A2_LOG_DEBUG(fmt("CUID#%lld - DH initialized.", cuid_));
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - DH initialized.", cuid_));
   initiator_ = initiator;
 }
 
 void MSEHandshake::sendPublicKey()
 {
-  A2_LOG_DEBUG(fmt("CUID#%lld - Sending public key.",
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Sending public key.",
                    cuid_));
-  unsigned char* buf = new unsigned char[KEY_LENGTH+MAX_PAD_LENGTH];
-  array_ptr<unsigned char> bufp(buf);
-  dh_->getPublicKey(buf, KEY_LENGTH);
+  auto buf = make_unique<unsigned char[]>(KEY_LENGTH+MAX_PAD_LENGTH);
+  dh_->getPublicKey(buf.get(), KEY_LENGTH);
 
   size_t padLength =
     SimpleRandomizer::getInstance()->getRandomNumber(MAX_PAD_LENGTH+1);
-  dh_->generateNonce(buf+KEY_LENGTH, padLength);
-  socketBuffer_.pushBytes(buf, KEY_LENGTH+padLength);
-  bufp.reset(0);
+  dh_->generateNonce(buf.get()+KEY_LENGTH, padLength);
+  socketBuffer_.pushBytes(buf.release(), KEY_LENGTH+padLength);
 }
 
 void MSEHandshake::read()
@@ -174,7 +171,7 @@ bool MSEHandshake::receivePublicKey()
     wantRead_ = true;
     return false;
   }
-  A2_LOG_DEBUG(fmt("CUID#%lld - public key received.", cuid_));
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - public key received.", cuid_));
   // TODO handle exception. in catch, resbufLength = 0;
   dh_->computeSecret(secret_, sizeof(secret_), rbuf_, KEY_LENGTH);
   // shift buffer
@@ -190,20 +187,20 @@ void MSEHandshake::initCipher(const unsigned char* infoHash)
   memcpy(s, initiator_?"keyA":"keyB", 4);
   memcpy(s+4, secret_, KEY_LENGTH);
   memcpy(s+4+KEY_LENGTH, infoHash, INFO_HASH_LENGTH);
-  
+
   unsigned char localCipherKey[20];
   sha1_->reset();
   message_digest::digest(localCipherKey, sizeof(localCipherKey),
-                         sha1_, s, sizeof(s));
-  encryptor_.reset(new ARC4Encryptor());
+                         sha1_.get(), s, sizeof(s));
+  encryptor_ = make_unique<ARC4Encryptor>();
   encryptor_->init(localCipherKey, sizeof(localCipherKey));
 
   unsigned char peerCipherKey[20];
   memcpy(s, initiator_?"keyB":"keyA", 4);
   sha1_->reset();
   message_digest::digest(peerCipherKey, sizeof(peerCipherKey),
-                         sha1_, s, sizeof(s));
-  decryptor_.reset(new ARC4Encryptor());
+                         sha1_.get(), s, sizeof(s));
+  decryptor_ = make_unique<ARC4Encryptor>();
   decryptor_->init(peerCipherKey, sizeof(peerCipherKey));
 
   // discard first 1024 bytes ARC4 output.
@@ -234,7 +231,7 @@ void MSEHandshake::createReq1Hash(unsigned char* md) const
   memcpy(buffer, "req1", 4);
   memcpy(buffer+4, secret_, KEY_LENGTH);
   sha1_->reset();
-  message_digest::digest(md, 20, sha1_, buffer, 4+KEY_LENGTH);
+  message_digest::digest(md, 20, sha1_.get(), buffer, 4+KEY_LENGTH);
 }
 
 void MSEHandshake::createReq23Hash(unsigned char* md, const unsigned char* infoHash) const
@@ -244,15 +241,15 @@ void MSEHandshake::createReq23Hash(unsigned char* md, const unsigned char* infoH
   memcpy(x+4, infoHash, INFO_HASH_LENGTH);
   unsigned char xh[20];
   sha1_->reset();
-  message_digest::digest(xh, sizeof(xh), sha1_, x, sizeof(x));
+  message_digest::digest(xh, sizeof(xh), sha1_.get(), x, sizeof(x));
 
   unsigned char y[4+96];
   memcpy(y, "req3", 4);
   memcpy(y+4, secret_, KEY_LENGTH);
   unsigned char yh[20];
   sha1_->reset();
-  message_digest::digest(yh, sizeof(yh), sha1_, y, sizeof(y));
-  
+  message_digest::digest(yh, sizeof(yh), sha1_.get(), y, sizeof(y));
+
   for(size_t i = 0; i < 20; ++i) {
     md[i] = xh[i]^yh[i];
   }
@@ -269,25 +266,25 @@ uint16_t MSEHandshake::decodeLength16(const unsigned char* buffer)
 
 void MSEHandshake::sendInitiatorStep2()
 {
-  A2_LOG_DEBUG(fmt("CUID#%lld - Sending negotiation step2.", cuid_));
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Sending negotiation step2.", cuid_));
   // Assuming no exception
-  unsigned char* md = new unsigned char[20];
-  createReq1Hash(md);
-  socketBuffer_.pushBytes(md, 20);
+  auto md = make_unique<unsigned char[]>((size_t)20);
+  createReq1Hash(md.get());
+  socketBuffer_.pushBytes(md.release(), 20);
   // Assuming no exception
-  md = new unsigned char[20];
-  createReq23Hash(md, infoHash_);
-  socketBuffer_.pushBytes(md, 20);
+  md = make_unique<unsigned char[]>((size_t)20);
+  createReq23Hash(md.get(), infoHash_);
+  socketBuffer_.pushBytes(md.release(), 20);
   // buffer is filled in this order:
   //   VC(VC_LENGTH bytes),
   //   crypto_provide(CRYPTO_BITFIELD_LENGTH bytes),
   //   len(padC)(2 bytes),
   //   padC(len(padC) bytes <= MAX_PAD_LENGTH),
   //   len(IA)(2 bytes)
-  unsigned char* buffer = new unsigned char
-    [40+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+MAX_PAD_LENGTH+2];
-  array_ptr<unsigned char> bufp(buffer);
-  unsigned char* ptr = buffer;
+  auto buffer = make_unique<unsigned char[]>(40+VC_LENGTH+
+                                             CRYPTO_BITFIELD_LENGTH+2+
+                                             MAX_PAD_LENGTH+2);
+  unsigned char* ptr = buffer.get();
   // VC
   memcpy(ptr, VC, sizeof(VC));
   ptr += sizeof(VC);
@@ -317,8 +314,8 @@ void MSEHandshake::sendInitiatorStep2()
     memcpy(ptr, &iaLengthBE, sizeof(iaLengthBE));
   }
   ptr += 2;
-  encryptAndSendData(buffer, ptr-buffer);
-  bufp.reset(0);
+  size_t buflen = ptr-buffer.get();
+  encryptAndSendData(buffer.release(), buflen);
 }
 
 // This function reads exactly until the end of VC marker is reached.
@@ -338,7 +335,7 @@ bool MSEHandshake::findInitiatorVCMarker()
     }
   }
   markerIndex_ = ptr-rbuf_;
-  A2_LOG_DEBUG(fmt("CUID#%lld - VC marker found at %lu",
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - VC marker found at %lu",
                    cuid_,
                    static_cast<unsigned long>(markerIndex_)));
   verifyVC(rbuf_+markerIndex_);
@@ -358,18 +355,18 @@ bool MSEHandshake::receiveInitiatorCryptoSelectAndPadDLength()
   decryptor_->encrypt(CRYPTO_BITFIELD_LENGTH, rbufptr, rbufptr);
   if(rbufptr[3]&CRYPTO_PLAIN_TEXT &&
      option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-    A2_LOG_DEBUG(fmt("CUID#%lld - peer prefers plaintext.",
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer prefers plaintext.",
                      cuid_));
     negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
   }
   if(rbufptr[3]&CRYPTO_ARC4) {
-    A2_LOG_DEBUG(fmt("CUID#%lld - peer prefers ARC4",
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer prefers ARC4",
                      cuid_));
     negotiatedCryptoType_ = CRYPTO_ARC4;
   }
   if(negotiatedCryptoType_ == CRYPTO_NONE) {
     throw DL_ABORT_EX
-      (fmt("CUID#%lld - No supported crypto type selected.",
+      (fmt("CUID#%" PRId64 " - No supported crypto type selected.",
            cuid_));
   }
   // padD length
@@ -412,7 +409,7 @@ bool MSEHandshake::findReceiverHashMarker()
     }
   }
   markerIndex_ = ptr-rbuf_;
-  A2_LOG_DEBUG(fmt("CUID#%lld - Hash marker found at %lu.",
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Hash marker found at %lu.",
                    cuid_,
                    static_cast<unsigned long>(markerIndex_)));
   verifyReq1Hash(rbuf_+markerIndex_);
@@ -422,7 +419,7 @@ bool MSEHandshake::findReceiverHashMarker()
 }
 
 bool MSEHandshake::receiveReceiverHashAndPadCLength
-(const std::vector<SharedHandle<DownloadContext> >& downloadContexts)
+(const std::vector<std::shared_ptr<DownloadContext> >& downloadContexts)
 {
   if(20+VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2/*PadC length*/ > rbufLength_) {
     wantRead_ = true;
@@ -431,18 +428,16 @@ bool MSEHandshake::receiveReceiverHashAndPadCLength
   // resolve info hash
   // pointing to the position of HASH('req2', SKEY) xor HASH('req3', S)
   unsigned char* rbufptr = rbuf_;
-  SharedHandle<DownloadContext> downloadContext;
-  for(std::vector<SharedHandle<DownloadContext> >::const_iterator i =
-        downloadContexts.begin(), eoi = downloadContexts.end();
-      i != eoi; ++i) {
+  std::shared_ptr<DownloadContext> downloadContext;
+  for(auto & ctx : downloadContexts) {
     unsigned char md[20];
-    const unsigned char* infohash = bittorrent::getInfoHash(*i);
+    const auto infohash = bittorrent::getInfoHash(ctx);
     createReq23Hash(md, infohash);
     if(memcmp(md, rbufptr, sizeof(md)) == 0) {
-      A2_LOG_DEBUG(fmt("CUID#%lld - info hash found: %s",
+      A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - info hash found: %s",
                        cuid_,
                        util::toHex(infohash, INFO_HASH_LENGTH).c_str()));
-      downloadContext = *i;
+      downloadContext = ctx;
       break;
     }
   }
@@ -460,17 +455,17 @@ bool MSEHandshake::receiveReceiverHashAndPadCLength
   // For now, choose ARC4.
   if(rbufptr[3]&CRYPTO_PLAIN_TEXT &&
      option_->get(PREF_BT_MIN_CRYPTO_LEVEL) == V_PLAIN) {
-    A2_LOG_DEBUG(fmt("CUID#%lld - peer provides plaintext.",
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer provides plaintext.",
                      cuid_));
     negotiatedCryptoType_ = CRYPTO_PLAIN_TEXT;
   } else if(rbufptr[3]&CRYPTO_ARC4) {
-    A2_LOG_DEBUG(fmt("CUID#%lld - peer provides ARC4.",
+    A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - peer provides ARC4.",
                      cuid_));
     negotiatedCryptoType_ = CRYPTO_ARC4;
   }
   if(negotiatedCryptoType_ == CRYPTO_NONE) {
     throw DL_ABORT_EX
-      (fmt("CUID#%lld - No supported crypto type provided.",
+      (fmt("CUID#%" PRId64 " - No supported crypto type provided.",
            cuid_));
   }
   // decrypt PadC length
@@ -491,7 +486,7 @@ bool MSEHandshake::receiveReceiverIALength()
   if(iaLength_ > BtHandshakeMessage::MESSAGE_LENGTH) {
     throw DL_ABORT_EX(fmt("Too large IA length length: %u", iaLength_));
   }
-  A2_LOG_DEBUG(fmt("CUID#%lld - len(IA)=%u.", cuid_, iaLength_));
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - len(IA)=%u.", cuid_, iaLength_));
   // shift rbuf_
   shiftBuffer(2);
   return true;
@@ -509,7 +504,7 @@ bool MSEHandshake::receiveReceiverIA()
   delete [] ia_;
   ia_ = new unsigned char[iaLength_];
   decryptor_->encrypt(iaLength_, ia_, rbuf_);
-  A2_LOG_DEBUG(fmt("CUID#%lld - IA received.", cuid_));
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - IA received.", cuid_));
   // shift rbuf_
   shiftBuffer(iaLength_);
   return true;
@@ -522,10 +517,10 @@ void MSEHandshake::sendReceiverStep2()
   //   cryptoSelect(CRYPTO_BITFIELD_LENGTH bytes),
   //   len(padD)(2bytes),
   //   padD(len(padD)bytes <= MAX_PAD_LENGTH)
-  unsigned char* buffer = new unsigned char
-    [VC_LENGTH+CRYPTO_BITFIELD_LENGTH+2+MAX_PAD_LENGTH];
-  array_ptr<unsigned char> bufp(buffer);
-  unsigned char* ptr = buffer;
+  auto buffer = make_unique<unsigned char[]>(VC_LENGTH+
+                                             CRYPTO_BITFIELD_LENGTH+2+
+                                             MAX_PAD_LENGTH);
+  unsigned char* ptr = buffer.get();
   // VC
   memcpy(ptr, VC, sizeof(VC));
   ptr += sizeof(VC);
@@ -542,16 +537,16 @@ void MSEHandshake::sendReceiverStep2()
   // padD, all zeroed
   memset(ptr, 0, padDLength);
   ptr += padDLength;
-  encryptAndSendData(buffer, ptr-buffer);
-  bufp.reset(0);
+  size_t buflen = ptr - buffer.get();
+  encryptAndSendData(buffer.release(), buflen);
 }
 
 uint16_t MSEHandshake::verifyPadLength(const unsigned char* padlenbuf, const char* padName)
 {
-  A2_LOG_DEBUG(fmt("CUID#%lld - Verifying Pad length for %s",
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Verifying Pad length for %s",
                    cuid_, padName));
   uint16_t padLength = decodeLength16(padlenbuf);
-  A2_LOG_DEBUG(fmt("CUID#%lld - len(%s)=%u",
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - len(%s)=%u",
                    cuid_, padName, padLength));
   if(padLength > 512) {
     throw DL_ABORT_EX
@@ -562,7 +557,7 @@ uint16_t MSEHandshake::verifyPadLength(const unsigned char* padlenbuf, const cha
 
 void MSEHandshake::verifyVC(unsigned char* vcbuf)
 {
-  A2_LOG_DEBUG(fmt("CUID#%lld - Verifying VC.", cuid_));
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Verifying VC.", cuid_));
   decryptor_->encrypt(VC_LENGTH, vcbuf, vcbuf);
   if(memcmp(VC, vcbuf, VC_LENGTH) != 0) {
     throw DL_ABORT_EX
@@ -572,7 +567,7 @@ void MSEHandshake::verifyVC(unsigned char* vcbuf)
 
 void MSEHandshake::verifyReq1Hash(const unsigned char* req1buf)
 {
-  A2_LOG_DEBUG(fmt("CUID#%lld - Verifying req hash.", cuid_));
+  A2_LOG_DEBUG(fmt("CUID#%" PRId64 " - Verifying req hash.", cuid_));
   unsigned char md[20];
   createReq1Hash(md);
   if(memcmp(md, req1buf, sizeof(md)) != 0) {
@@ -585,4 +580,14 @@ bool MSEHandshake::getWantWrite() const
   return !socketBuffer_.sendBufferIsEmpty();
 }
 
+std::unique_ptr<ARC4Encryptor> MSEHandshake::popEncryptor()
+{
+  return std::move(encryptor_);
+}
+
+std::unique_ptr<ARC4Encryptor> MSEHandshake::popDecryptor()
+{
+  return std::move(decryptor_);
+}
+
 } // namespace aria2
