@@ -38,36 +38,37 @@
 #include "common.h"
 
 #include <string>
-
-#include "SharedHandle.h"
+#include <vector>
+#include <memory>
 
 namespace aria2 {
 
 class MessageDigestImpl;
 
 class MessageDigest {
-private:
-  SharedHandle<MessageDigestImpl> pImpl_;
-
-  MessageDigest();
-
-  // We don't implement copy ctor.
-  MessageDigest(const MessageDigest&);
-  // We don't implement assignment operator.
-  MessageDigest& operator=(const MessageDigest&);
 public:
+  // Made public for make_unique
+  MessageDigest(std::unique_ptr<MessageDigestImpl> impl);
+  // We don't implement copy ctor.
+  MessageDigest(const MessageDigest&) = delete;
+  // We don't implement assignment operator.
+  MessageDigest& operator=(const MessageDigest&) = delete;
+
   ~MessageDigest();
 
   // Factory functions
-  static SharedHandle<MessageDigest> sha1();
+  static std::unique_ptr<MessageDigest> sha1();
 
   // Factory function which takes hashType as string.  Throws
   // exception if hashType is not supported.
-  static SharedHandle<MessageDigest> create(const std::string& hashType);
+  static std::unique_ptr<MessageDigest> create(const std::string& hashType);
 
   // Returns true if hashType is supported. Otherwise returns false.
   static bool supports(const std::string& hashType);
 
+  // Returns a vector containing supported hash function textual names.
+  static std::vector<std::string> getSupportedHashTypes();
+
   // Returns string containing supported hash function textual names
   // joined with ','.
   static std::string getSupportedHashTypeString();
@@ -93,7 +94,7 @@ public:
   // Resets this object so that it can be reused.
   void reset();
 
-  void update(const void* data, size_t length);
+  MessageDigest& update(const void* data, size_t length);
 
   // Stores digest in the region pointed by md. It is caller's
   // responsibility to allocate memory at least getDigestLength().
@@ -104,6 +105,8 @@ public:
   // Returns raw digest, not hex digest.  This call can only be called
   // once. To reuse this object, call reset().
   std::string digest();
+private:
+  std::unique_ptr<MessageDigestImpl> pImpl_;
 };
 
 } // namespace aria2
