@@ -40,8 +40,8 @@
 #include <string>
 #include <vector>
 #include <stack>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "MetalinkParserController.h"
 #include "MetalinkParserState.h"
 
@@ -51,7 +51,7 @@ class Metalinker;
 
 class MetalinkParserStateMachine : public ParserStateMachine {
 private:
-  SharedHandle<MetalinkParserController> ctrl_;
+  std::unique_ptr<MetalinkParserController> ctrl_;
 
   std::stack<MetalinkParserState*> stateStack_;
 
@@ -60,7 +60,7 @@ private:
 
   static MetalinkParserState* initialState_;
   static MetalinkParserState* skipTagState_;
-  
+
   // Metalink3
   static MetalinkParserState* metalinkState_;
   static MetalinkParserState* filesState_; // Metalink3Spec
@@ -95,23 +95,23 @@ public:
 
   virtual ~MetalinkParserStateMachine();
 
-  virtual bool needsCharactersBuffering() const;
+  virtual bool needsCharactersBuffering() const CXX11_OVERRIDE;
 
-  virtual bool finished() const;
+  virtual bool finished() const CXX11_OVERRIDE;
 
   virtual void beginElement
   (const char* localname,
    const char* prefix,
    const char* nsUri,
-   const std::vector<XmlAttr>& attrs);
+   const std::vector<XmlAttr>& attrs) CXX11_OVERRIDE;
 
   virtual void endElement
   (const char* localname,
    const char* prefix,
    const char* nsUri,
-   const std::string& characters);
+   const std::string& characters) CXX11_OVERRIDE;
 
-  virtual void reset();
+  virtual void reset() CXX11_OVERRIDE;
 
   void setSkipTagState();
 
@@ -126,7 +126,7 @@ public:
   void setVersionState();
 
   void setLanguageState();
-  
+
   void setOSState();
 
   void setVerificationState(); // Metalink3Spec
@@ -265,10 +265,7 @@ public:
 
   std::string getErrorString() const;
 
-  const SharedHandle<Metalinker>& getResult() const
-  {
-    return ctrl_->getResult();
-  }
+  std::unique_ptr<Metalinker> getResult();
 
   void setBaseUri(const std::string& uri);
 };
