@@ -56,7 +56,7 @@ namespace aria2 {
 
 MetalinkPostDownloadHandler::MetalinkPostDownloadHandler()
 {
-  SharedHandle<RequestGroupCriteria> cri
+  std::shared_ptr<RequestGroupCriteria> cri
     (new ContentTypeRequestGroupCriteria
      (getMetalinkContentTypes(), getMetalinkExtensions()));
   setCriteria(cri);
@@ -67,13 +67,13 @@ MetalinkPostDownloadHandler::~MetalinkPostDownloadHandler() {}
 namespace {
 const std::string& getBaseUri(RequestGroup* requestGroup)
 {
-  const SharedHandle<DownloadContext>& dctx =
+  const std::shared_ptr<DownloadContext>& dctx =
     requestGroup->getDownloadContext();
   if(dctx->getFileEntries().empty()) {
     return A2STR::NIL;
   } else {
     // TODO Check download result for each URI
-    const SharedHandle<FileEntry>& entry = dctx->getFirstFileEntry();
+    const std::shared_ptr<FileEntry>& entry = dctx->getFirstFileEntry();
     const std::deque<std::string>& spentUris = entry->getSpentUris();
     if(spentUris.empty()) {
       const std::deque<std::string>& remainingUris = entry->getRemainingUris();
@@ -90,23 +90,24 @@ const std::string& getBaseUri(RequestGroup* requestGroup)
 } // namespace
 
 void MetalinkPostDownloadHandler::getNextRequestGroups
-(std::vector<SharedHandle<RequestGroup> >& groups,
+(std::vector<std::shared_ptr<RequestGroup> >& groups,
  RequestGroup* requestGroup)
 {
   A2_LOG_DEBUG(fmt("Generating RequestGroups for Metalink file %s",
                    requestGroup->getFirstFilePath().c_str()));
-  SharedHandle<DiskAdaptor> diskAdaptor =
+  std::shared_ptr<DiskAdaptor> diskAdaptor =
     requestGroup->getPieceStorage()->getDiskAdaptor();
   try {
     diskAdaptor->openExistingFile();
     //requestOption.put(PREF_DIR, requestGroup->getDownloadContext()->getDir());
     const std::string& baseUri = getBaseUri(requestGroup);
-    std::vector<SharedHandle<RequestGroup> > newRgs;
+    std::vector<std::shared_ptr<RequestGroup> > newRgs;
     Metalink2RequestGroup().generate(newRgs, diskAdaptor,
                                      requestGroup->getOption(), baseUri);
     requestGroup->followedBy(newRgs.begin(), newRgs.end());
-    SharedHandle<MetadataInfo> mi =
-      createMetadataInfoFromFirstFileEntry(requestGroup->getDownloadContext());
+    std::shared_ptr<MetadataInfo> mi =
+      createMetadataInfoFromFirstFileEntry(requestGroup->getGroupId(),
+                                           requestGroup->getDownloadContext());
     if(mi) {
       setMetadataInfo(newRgs.begin(), newRgs.end(), mi);
     }
