@@ -47,8 +47,8 @@ public:
   virtual ~MetalinkPostDownloadHandler();
 
   virtual void
-  getNextRequestGroups(std::vector<SharedHandle<RequestGroup> >& groups,
-                       RequestGroup* requestGroup);
+  getNextRequestGroups(std::vector<std::shared_ptr<RequestGroup> >& groups,
+                       RequestGroup* requestGroup) CXX11_OVERRIDE;
 };
 
 } // namespace aria2
