@@ -39,8 +39,7 @@
 
 #include <string>
 #include <vector>
-
-#include "SharedHandle.h"
+#include <memory>
 
 namespace aria2 {
 
@@ -48,27 +47,26 @@ class MetalinkEntry;
 
 class Metalinker {
 private:
-  std::vector<SharedHandle<MetalinkEntry> > entries_;
+  std::vector<std::unique_ptr<MetalinkEntry>> entries_;
 public:
   Metalinker();
   ~Metalinker();
 
   // Don't allow copying
-  Metalinker(const Metalinker&);
-  Metalinker& operator=(const Metalinker&);
+  Metalinker(const Metalinker&) = delete;
+  Metalinker& operator=(const Metalinker&) = delete;
 
-  void queryEntry
-  (std::vector<SharedHandle<MetalinkEntry> >& queryResult,
-   const std::string& version,
-   const std::string& language,
-   const std::string& os) const;
+  std::vector<std::unique_ptr<MetalinkEntry>>
+  queryEntry(const std::string& version,
+             const std::string& language,
+             const std::string& os);
 
-  const std::vector<SharedHandle<MetalinkEntry> >& getEntries() const
+  const std::vector<std::unique_ptr<MetalinkEntry>>& getEntries() const
   {
     return entries_;
   }
 
-  void addEntry(const SharedHandle<MetalinkEntry>& entry);
+  void addEntry(std::unique_ptr<MetalinkEntry> entry);
 };
 
 } // namespace aria2
