@@ -45,12 +45,13 @@ class DiskWriter;
 
 class DiskWriterEntry {
 private:
-  SharedHandle<FileEntry> fileEntry_;
-  SharedHandle<DiskWriter> diskWriter_;
+  std::shared_ptr<FileEntry> fileEntry_;
+  std::unique_ptr<DiskWriter> diskWriter_;
   bool open_;
   bool needsFileAllocation_;
+  bool needsDiskWriter_;
 public:
-  DiskWriterEntry(const SharedHandle<FileEntry>& fileEntry);
+  DiskWriterEntry(const std::shared_ptr<FileEntry>& fileEntry);
 
   const std::string& getFilePath() const;
 
@@ -71,14 +72,14 @@ public:
 
   int64_t size() const;
 
-  const SharedHandle<FileEntry>& getFileEntry() const
+  const std::shared_ptr<FileEntry>& getFileEntry() const
   {
     return fileEntry_;
   }
 
-  void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
+  void setDiskWriter(std::unique_ptr<DiskWriter> diskWriter);
 
-  const SharedHandle<DiskWriter>& getDiskWriter() const
+  const std::unique_ptr<DiskWriter>& getDiskWriter() const
   {
     return diskWriter_;
   }
@@ -95,11 +96,18 @@ public:
     needsFileAllocation_ = f;
   }
 
+  bool needsDiskWriter() const
+  {
+    return needsDiskWriter_;
+  }
+
+  void needsDiskWriter(bool f)
+  {
+    needsDiskWriter_ = f;
+  }
 };
 
-typedef SharedHandle<DiskWriterEntry> DiskWriterEntryHandle;
-
-typedef std::vector<DiskWriterEntryHandle> DiskWriterEntries;
+typedef std::vector<std::unique_ptr<DiskWriterEntry>> DiskWriterEntries;
 
 class MultiDiskAdaptor : public DiskAdaptor {
   friend class MultiFileAllocationIterator;
@@ -107,50 +115,54 @@ private:
   int32_t pieceLength_;
   DiskWriterEntries diskWriterEntries_;
 
-  std::vector<SharedHandle<DiskWriterEntry> > openedDiskWriterEntries_;
+  std::vector<DiskWriterEntry*> openedDiskWriterEntries_;
 
   int maxOpenFiles_;
 
   bool readOnly_;
-  bool enableMmap_;
 
   void resetDiskWriterEntries();
 
-  void openIfNot(const SharedHandle<DiskWriterEntry>& entry,
-                 void (DiskWriterEntry::*f)());
- 
+  void openIfNot(DiskWriterEntry* entry, void (DiskWriterEntry::*f)());
+
   static const int DEFAULT_MAX_OPEN_FILES = 100;
 
 public:
   MultiDiskAdaptor();
   ~MultiDiskAdaptor();
 
-  virtual void initAndOpenFile();
+  virtual void initAndOpenFile() CXX11_OVERRIDE;
 
-  virtual void openFile();
+  virtual void openFile() CXX11_OVERRIDE;
 
-  virtual void openExistingFile();
+  virtual void openExistingFile() CXX11_OVERRIDE;
 
-  virtual void closeFile();
+  virtual void closeFile() CXX11_OVERRIDE;
 
   virtual void writeData(const unsigned char* data, size_t len,
-                         int64_t offset);
+                         int64_t offset) CXX11_OVERRIDE;
 
-  virtual ssize_t readData(unsigned char* data, size_t len, int64_t offset);
+  virtual ssize_t readData(unsigned char* data, size_t len, int64_t offset)
+    CXX11_OVERRIDE;
 
-  virtual bool fileExists();
+  virtual void writeCache(const WrDiskCacheEntry* entry) CXX11_OVERRIDE;
 
-  virtual int64_t size();
+  virtual bool fileExists() CXX11_OVERRIDE;
 
-  virtual SharedHandle<FileAllocationIterator> fileAllocationIterator();
+  virtual int64_t size() CXX11_OVERRIDE;
 
-  virtual void enableReadOnly();
+  virtual std::unique_ptr<FileAllocationIterator> fileAllocationIterator()
+    CXX11_OVERRIDE;
 
-  virtual void disableReadOnly();
+  virtual void enableReadOnly() CXX11_OVERRIDE;
 
-  virtual bool isReadOnlyEnabled() const { return readOnly_; }
+  virtual void disableReadOnly() CXX11_OVERRIDE;
 
-  virtual void enableMmap();
+  virtual bool isReadOnlyEnabled() const CXX11_OVERRIDE { return readOnly_; }
+
+  // Enables mmap feature. This method must be called after files are
+  // opened.
+  virtual void enableMmap() CXX11_OVERRIDE;
 
   void setPieceLength(int32_t pieceLength)
   {
@@ -161,22 +173,19 @@ public:
     return pieceLength_;
   }
 
-  virtual void cutTrailingGarbage();
+  virtual void cutTrailingGarbage() CXX11_OVERRIDE;
 
   void setMaxOpenFiles(int maxOpenFiles);
 
-  virtual size_t utime(const Time& actime, const Time& modtime);
+  virtual size_t utime(const Time& actime, const Time& modtime) CXX11_OVERRIDE;
 
-  const std::vector<SharedHandle<DiskWriterEntry> >&
-  getDiskWriterEntries() const
+  const DiskWriterEntries& getDiskWriterEntries() const
   {
     return diskWriterEntries_;
   }
 
 };
 
-typedef SharedHandle<MultiDiskAdaptor> MultiDiskAdaptorHandle;
-
 } // namespace aria2
 
 #endif // D_MULTI_DISK_ADAPTOR_H
