@@ -36,35 +36,36 @@
 #define D_MULTI_FILE_ALLOCATION_ITERATOR_H
 
 #include "FileAllocationIterator.h"
+
 #include <deque>
+#include <memory>
+
+#include "MultiDiskAdaptor.h"
 
 namespace aria2 {
 
-class MultiDiskAdaptor;
 class DiskWriterEntry;
 
 class MultiFileAllocationIterator:public FileAllocationIterator
 {
 private:
   MultiDiskAdaptor* diskAdaptor_;
-  std::deque<SharedHandle<DiskWriterEntry> > entries_;
-  SharedHandle<FileAllocationIterator> fileAllocationIterator_;
-  off_t offset_;
+  DiskWriterEntries::const_iterator entryItr_;
+  std::unique_ptr<FileAllocationIterator> fileAllocationIterator_;
 public:
   MultiFileAllocationIterator(MultiDiskAdaptor* diskAdaptor);
 
   virtual ~MultiFileAllocationIterator();
 
-  virtual void allocateChunk();
-  
-  virtual bool finished();
+  virtual void allocateChunk() CXX11_OVERRIDE;
 
-  virtual off_t getCurrentLength();
+  virtual bool finished() CXX11_OVERRIDE;
 
-  virtual uint64_t getTotalLength();
+  virtual int64_t getCurrentLength() CXX11_OVERRIDE;
 
-  const std::deque<SharedHandle<DiskWriterEntry> >&
-  getDiskWriterEntries() const;
+  virtual int64_t getTotalLength() CXX11_OVERRIDE;
+
+  const DiskWriterEntries& getDiskWriterEntries() const;
 };
 
 } // namespace aria2
