@@ -41,7 +41,7 @@
 
 namespace aria2 {
 
-const std::string NO_DESCRIPTION("");
+const char NO_DESCRIPTION[] = "";
 const std::string NO_DEFAULT_VALUE("");
 
 const std::string PATH_TO_FILE("/path/to/file");
@@ -64,4 +64,17 @@ std::ostream& operator<<(std::ostream& o, const OptionHandler& optionHandler)
   return o;
 }
 
+void write(const Console& out, const OptionHandler& optionHandler)
+{
+  out->printf("%s\n\n", optionHandler.getDescription());
+  std::string possibleValues = optionHandler.createPossibleValuesString();
+  if(!possibleValues.empty()) {
+    out->printf("%s%s\n", POSSIBLE_MSG, possibleValues.c_str());
+  }
+  if(!optionHandler.getDefaultValue().empty()) {
+    out->printf("%s%s\n", DEFAULT_MSG, optionHandler.getDefaultValue().c_str());
+  }
+  out->printf("%s%s\n", TAGS_MSG, optionHandler.toTagString().c_str());
+}
+
 } // namespace aria2
