@@ -42,8 +42,8 @@
 #include <iosfwd>
 #include <functional>
 
-#include "SharedHandle.h"
 #include "console.h"
+#include "prefs.h"
 
 namespace aria2 {
 
@@ -57,19 +57,18 @@ extern const std::string PATH_TO_DIR;
 extern const std::string PATH_TO_COMMAND;
 
 class Option;
-class Pref;
 
 class OptionHandler {
 public:
   virtual ~OptionHandler() {}
-  
-  virtual void parse(Option& option, const std::string& arg) = 0;
+
+  virtual void parse(Option& option, const std::string& arg) const = 0;
 
   virtual std::string createPossibleValuesString() const = 0;
 
-  virtual bool hasTag(const std::string& tag) const = 0;
+  virtual bool hasTag(uint32_t tag) const = 0;
 
-  virtual void addTag(const std::string& tag) = 0;
+  virtual void addTag(uint32_t tag) = 0;
 
   virtual std::string toTagString() const = 0;
 
@@ -83,7 +82,7 @@ public:
 
   virtual void hide() = 0;
 
-  virtual const Pref* getPref() const = 0;
+  virtual PrefPtr getPref() const = 0;
 
   enum ARG_TYPE {
     REQ_ARG,
