@@ -35,26 +35,29 @@
 #ifndef D_OPTION_HANDLER_EXCEPTION_H
 #define D_OPTION_HANDLER_EXCEPTION_H
 #include "RecoverableException.h"
+#include "prefs.h"
 
 namespace aria2 {
 
 class OptionHandlerException:public RecoverableException {
 private:
-  std::string optName_;
-
-  static const std::string MESSAGE;
+  PrefPtr pref_;
 protected:
-  virtual SharedHandle<Exception> copy() const;
+  virtual std::shared_ptr<Exception> copy() const CXX11_OVERRIDE;
 public:
   OptionHandlerException(const char* file, int line,
-                         const std::string& optName);
+                         PrefPtr pref);
 
-  OptionHandlerException(const char* file, int line, const std::string& optName,
+  OptionHandlerException(const char* file, int line,
+                         PrefPtr pref,
                          const Exception& cause);
 
   virtual ~OptionHandlerException() throw();
 
-  const std::string& getOptionName() const throw();
+  PrefPtr getPref() const
+  {
+    return pref_;
+  }
 };
 
 #define OPTION_HANDLER_EXCEPTION(arg)                   \
