@@ -42,7 +42,6 @@
 #include <set>
 #include <algorithm>
 
-#include "SharedHandle.h"
 #include "TimerA2.h"
 #include "BtConstants.h"
 #include "PeerStat.h"
@@ -61,8 +60,9 @@ private:
   // true, then this port is not a port the peer is listening to and
   // we cannot connect to it.
   uint16_t port_;
-
-  std::string id_;
+  // This is the port number passed in the constructor arguments. This
+  // is used to distinguish peer identity.
+  uint16_t origPort_;
 
   cuid_t cuid_;
 
@@ -70,7 +70,7 @@ private:
 
   Timer firstContactTime_;
 
-  Timer badConditionStartTime_;
+  Timer dropStartTime_;
 
   bool seeder_;
 
@@ -94,18 +94,6 @@ public:
 
   ~Peer();
 
-  bool operator==(const Peer& p)
-  {
-    return id_ == p.id_;
-  }
-
-  bool operator!=(const Peer& p)
-  {
-    return !(*this == p);
-  }
-
-  void resetStatus();
-
   const std::string& getIPAddress() const
   {
     return ipaddr_;
@@ -121,6 +109,11 @@ public:
     port_ = port;
   }
 
+  uint16_t getOrigPort() const
+  {
+    return origPort_;
+  }
+
   void usedBy(cuid_t cuid);
 
   cuid_t usedBy() const
@@ -136,7 +129,7 @@ public:
   // Returns true iff res_ != 0.
   bool isActive() const
   {
-    return res_ != 0;
+    return res_ != nullptr;
   }
 
   void setPeerId(const unsigned char* peerId);
@@ -151,14 +144,7 @@ public:
     return seeder_;
   }
 
-  const std::string& getID() const
-  {
-    return id_;
-  }
-
-  void startBadCondition();
-
-  bool isGood() const;
+  void startDrop();
 
   void allocateSessionResource(int32_t pieceLength, int64_t totalLength);
 
@@ -173,9 +159,9 @@ public:
 
   void setFirstContactTime(const Timer& time);
 
-  const Timer& getBadConditionStartTime() const
+  const Timer& getDropStartTime() const
   {
-    return badConditionStartTime_;
+    return dropStartTime_;
   }
 
   // Before calling following member functions,  make sure that
@@ -330,7 +316,13 @@ public:
 template<typename InputIterator>
 size_t countSeeder(InputIterator first, InputIterator last)
 {
-  return std::count_if(first, last, mem_fun_sh(&Peer::isSeeder));
+  size_t res = 0;
+  for(; first != last; ++first) {
+    if((*first)->isActive() && (*first)->isSeeder()) {
+      ++res;
+    }
+  }
+  return res;
 }
 
 } // namespace aria2
