@@ -63,12 +63,12 @@ namespace aria2 {
 
 PeerReceiveHandshakeCommand::PeerReceiveHandshakeCommand
 (cuid_t cuid,
- const SharedHandle<Peer>& peer,
+ const std::shared_ptr<Peer>& peer,
  DownloadEngine* e,
- const SharedHandle<SocketCore>& s,
- const SharedHandle<PeerConnection>& peerConnection)
-  : PeerAbstractCommand(cuid, peer, e, s),
-    peerConnection_(peerConnection)
+ const std::shared_ptr<SocketCore>& s,
+ std::unique_ptr<PeerConnection> peerConnection)
+  : PeerAbstractCommand{cuid, peer, e, s},
+    peerConnection_{std::move(peerConnection)}
 {
   if(peerConnection_) {
     if(peerConnection_->getBufferLength() > 0) {
@@ -76,7 +76,8 @@ PeerReceiveHandshakeCommand::PeerReceiveHandshakeCommand
       getDownloadEngine()->setNoWait(true);
     }
   } else {
-    peerConnection_.reset(new PeerConnection(cuid, getPeer(), getSocket()));
+    peerConnection_ = make_unique<PeerConnection>
+      (cuid, getPeer(), getSocket());
   }
 }
 
@@ -95,26 +96,25 @@ bool PeerReceiveHandshakeCommand::executeInternal()
     size_t dataLength = 0;
     // Ignore return value. The received data is kept in
     // PeerConnection object because of peek = true.
-    peerConnection_->receiveHandshake(0, dataLength, true);
+    peerConnection_->receiveHandshake(nullptr, dataLength, true);
   }
   if(peerConnection_->getBufferLength() >= 48) {
     const unsigned char* data = peerConnection_->getBuffer();
     // check info_hash
     std::string infoHash(&data[28], &data[28+INFO_HASH_LENGTH]);
 
-    SharedHandle<DownloadContext> downloadContext =
+    std::shared_ptr<DownloadContext> downloadContext =
       getDownloadEngine()->getBtRegistry()->getDownloadContext(infoHash);
     if(!downloadContext) {
       throw DL_ABORT_EX
         (fmt("Unknown info hash %s",
              util::toHex(infoHash).c_str()));
     }
-    const SharedHandle<BtObject>& btObject =
-      getDownloadEngine()->getBtRegistry()->get
+    auto btObject = getDownloadEngine()->getBtRegistry()->get
       (downloadContext->getOwnerRequestGroup()->getGID());
-    const SharedHandle<BtRuntime>& btRuntime = btObject->btRuntime;
-    const SharedHandle<PieceStorage>& pieceStorage = btObject->pieceStorage;
-    const SharedHandle<PeerStorage>& peerStorage = btObject->peerStorage;
+    const std::shared_ptr<BtRuntime>& btRuntime = btObject->btRuntime;
+    const std::shared_ptr<PieceStorage>& pieceStorage = btObject->pieceStorage;
+    const std::shared_ptr<PeerStorage>& peerStorage = btObject->peerStorage;
     if(!btRuntime->ready()) {
       throw DL_ABORT_EX
         (fmt("Unknown info hash %s",
@@ -138,10 +138,11 @@ bool PeerReceiveHandshakeCommand::executeInternal()
     if((!pieceStorage->downloadFinished() &&
         stat.calculateDownloadSpeed() < thresholdSpeed) ||
        btRuntime->lessThanMaxPeers()) {
-      if(peerStorage->addPeer(getPeer())) {
-        getPeer()->usedBy(getCuid());
-        PeerInteractionCommand* command =
-          new PeerInteractionCommand
+      // TODO addPeer and checkoutPeer must be "atomic", in a sense
+      // that the added peer must be checked out.
+      if(peerStorage->addPeer(getPeer()) &&
+         peerStorage->checkoutPeer(getCuid())) {
+        getDownloadEngine()->addCommand(make_unique<PeerInteractionCommand>
           (getCuid(),
            downloadContext->getOwnerRequestGroup(),
            getPeer(),
@@ -151,8 +152,7 @@ bool PeerReceiveHandshakeCommand::executeInternal()
            peerStorage,
            getSocket(),
            PeerInteractionCommand::RECEIVER_WAIT_HANDSHAKE,
-           peerConnection_);
-        getDownloadEngine()->addCommand(command);
+           std::move(peerConnection_)));
         A2_LOG_DEBUG(fmt(MSG_INCOMING_PEER_CONNECTION,
                          getCuid(),
                          getPeer()->usedBy()));
@@ -160,7 +160,7 @@ bool PeerReceiveHandshakeCommand::executeInternal()
     }
     return true;
   } else {
-    getDownloadEngine()->addCommand(this);
+    addCommandSelf();
     return false;
   }
 }
