@@ -41,19 +41,6 @@
 
 #include <iostream>
 
-#ifdef HAVE_WINSOCK2_H
-
-#ifndef _WIN32_WINNT
-# define _WIN32_WINNT 0x501u
-#endif // _WIN32_WINNT
-#include <winsock2.h>
-#undef ERROR
-#ifdef HAVE_WS2TCPIP_H
-# include <ws2tcpip.h>
-#endif // HAVE_WS2TCPIP_H
-
-#endif // HAVE_WINSOCK2_H
-
 #ifdef HAVE_OPENSSL
 # include <openssl/err.h>
 # include <openssl/ssl.h>
@@ -69,10 +56,13 @@
 # include <ares.h>
 #endif // ENABLE_ASYNC_DNS
 
+#include "a2netcompat.h"
 #include "DlAbortEx.h"
 #include "message.h"
 #include "fmt.h"
 #include "console.h"
+#include "OptionParser.h"
+#include "prefs.h"
 #ifdef HAVE_LIBGMP
 # include "a2gmp.h"
 #endif // HAVE_LIBGMP
@@ -113,6 +103,8 @@ bool Platform::setUp()
   // for SSL initialization
   SSL_load_error_strings();
   SSL_library_init();
+  // Need this to "decrypt" p12 files.
+  OpenSSL_add_all_algorithms();
 #endif // HAVE_OPENSSL
 #ifdef HAVE_LIBGCRYPT
   if(!gcry_check_version(A2_MIN_GCRYPT_VERSION)) {
@@ -172,7 +164,11 @@ bool Platform::tearDown()
 #ifdef HAVE_WINSOCK2_H
   WSACleanup();
 #endif // HAVE_WINSOCK2_H
-
+  // Deletes statically allocated resources. This is done to
+  // distinguish memory leak from them. This is handly to use
+  // valgrind.
+  OptionParser::deleteInstance();
+  option::deletePrefResource();
   return true;
 }
 
