@@ -124,10 +124,10 @@ void PortEventPoll::poll(const struct timeval& tv)
                              p->getEvents().events, p);
       int errNum = errno;
       if(r == -1) {
-        A2_LOG_ERROR(fmt("port_associate failed for file descriptor %d:"
-                         " cause %s",
-                         pev.portev_object,
-                         util::safeStrerror(errNum).c_str()));
+        A2_LOG_INFO(fmt("port_associate failed for file descriptor %d:"
+                        " cause %s",
+                        pev.portev_object,
+                        util::safeStrerror(errNum).c_str()));
       }
     }
   } else if(res == -1) {
@@ -174,7 +174,7 @@ int translateEvents(EventPoll::EventType events)
 bool PortEventPoll::addEvents(sock_t socket,
                               const PortEventPoll::KEvent& event)
 {
-  SharedHandle<KSocketEntry> socketEntry(new KSocketEntry(socket));
+  std::shared_ptr<KSocketEntry> socketEntry(new KSocketEntry(socket));
   KSocketEntrySet::iterator i = socketEntries_.lower_bound(socketEntry);
   int r = 0;
   int errNum = 0;
@@ -215,7 +215,7 @@ bool PortEventPoll::addEvents(sock_t socket, Command* command,
 
 #ifdef ENABLE_ASYNC_DNS
 bool PortEventPoll::addEvents(sock_t socket, Command* command, int events,
-                              const SharedHandle<AsyncNameResolver>& rs)
+                              const std::shared_ptr<AsyncNameResolver>& rs)
 {
   return addEvents(socket, KADNSEvent(rs, command, socket, events));
 }
@@ -224,7 +224,7 @@ bool PortEventPoll::addEvents(sock_t socket, Command* command, int events,
 bool PortEventPoll::deleteEvents(sock_t socket,
                                  const PortEventPoll::KEvent& event)
 {
-  SharedHandle<KSocketEntry> socketEntry(new KSocketEntry(socket));
+  std::shared_ptr<KSocketEntry> socketEntry(new KSocketEntry(socket));
   KSocketEntrySet::iterator i = socketEntries_.find(socketEntry);
   if(i == socketEntries_.end()) {
     A2_LOG_DEBUG(fmt("Socket %d is not found in SocketEntries.", socket));
@@ -255,7 +255,7 @@ bool PortEventPoll::deleteEvents(sock_t socket,
 
 #ifdef ENABLE_ASYNC_DNS
 bool PortEventPoll::deleteEvents(sock_t socket, Command* command,
-                                 const SharedHandle<AsyncNameResolver>& rs)
+                                 const std::shared_ptr<AsyncNameResolver>& rs)
 {
   return deleteEvents(socket, KADNSEvent(rs, command, socket, 0));
 }
@@ -270,9 +270,9 @@ bool PortEventPoll::deleteEvents(sock_t socket, Command* command,
 
 #ifdef ENABLE_ASYNC_DNS
 bool PortEventPoll::addNameResolver
-(const SharedHandle<AsyncNameResolver>& resolver, Command* command)
+(const std::shared_ptr<AsyncNameResolver>& resolver, Command* command)
 {
-  SharedHandle<KAsyncNameResolverEntry> entry
+  std::shared_ptr<KAsyncNameResolverEntry> entry
     (new KAsyncNameResolverEntry(resolver, command));
   KAsyncNameResolverEntrySet::iterator itr = nameResolverEntries_.find(entry);
   if(itr == nameResolverEntries_.end()) {
@@ -285,9 +285,9 @@ bool PortEventPoll::addNameResolver
 }
 
 bool PortEventPoll::deleteNameResolver
-(const SharedHandle<AsyncNameResolver>& resolver, Command* command)
+(const std::shared_ptr<AsyncNameResolver>& resolver, Command* command)
 {
-  SharedHandle<KAsyncNameResolverEntry> entry
+  std::shared_ptr<KAsyncNameResolverEntry> entry
     (new KAsyncNameResolverEntry(resolver, command));
   KAsyncNameResolverEntrySet::iterator itr = nameResolverEntries_.find(entry);
   if(itr == nameResolverEntries_.end()) {
