@@ -38,8 +38,7 @@
 #include "PieceSelector.h"
 
 #include <vector>
-
-#include "SharedHandle.h"
+#include <memory>
 
 namespace aria2 {
 
@@ -47,12 +46,13 @@ class PriorityPieceSelector:public PieceSelector {
 private:
   std::vector<size_t> prioritizedPieces_;
 
-  SharedHandle<PieceSelector> selector_;
+  std::shared_ptr<PieceSelector> selector_;
 public:
-  PriorityPieceSelector(const SharedHandle<PieceSelector>& selector);
+  PriorityPieceSelector(const std::shared_ptr<PieceSelector>& selector);
 
   virtual bool select
-  (size_t& index, const unsigned char* bitfield, size_t nbits) const;
+  (size_t& index, const unsigned char* bitfield, size_t nbits) const
+    CXX11_OVERRIDE;
 
   template<typename InputIterator>
   void setPriorityPiece(InputIterator first, InputIterator last)
