@@ -116,9 +116,8 @@ void toStringList(OutputIterator out, const List* src)
   if(!src) {
     return;
   }
-  for(List::ValueType::const_iterator i = src->begin(), eoi = src->end();
-      i != eoi; ++i) {
-    const String* s = downcast<String>(*i);
+  for(auto & elem : *src) {
+    const String* s = downcast<String>(elem);
     if(s) {
       *out++ = s->s();
     }
@@ -127,8 +126,8 @@ void toStringList(OutputIterator out, const List* src)
 
 class AddUriRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -138,8 +137,8 @@ public:
 
 class RemoveRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -149,8 +148,8 @@ public:
 
 class ForceRemoveRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -160,8 +159,8 @@ public:
 
 class PauseRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -171,8 +170,8 @@ public:
 
 class ForcePauseRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -182,8 +181,8 @@ public:
 
 class PauseAllRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -193,8 +192,8 @@ public:
 
 class ForcePauseAllRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -204,8 +203,8 @@ public:
 
 class UnpauseRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -215,8 +214,8 @@ public:
 
 class UnpauseAllRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -227,8 +226,8 @@ public:
 #ifdef ENABLE_BITTORRENT
 class AddTorrentRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -240,8 +239,8 @@ public:
 #ifdef ENABLE_METALINK
 class AddMetalinkRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -252,8 +251,8 @@ public:
 
 class PurgeDownloadResultRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -263,8 +262,8 @@ public:
 
 class RemoveDownloadResultRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -274,8 +273,8 @@ public:
 
 class GetUrisRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -285,8 +284,8 @@ public:
 
 class GetFilesRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -297,8 +296,8 @@ public:
 #ifdef ENABLE_BITTORRENT
 class GetPeersRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -309,8 +308,8 @@ public:
 
 class GetServersRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -320,8 +319,8 @@ public:
 
 class TellStatusRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -331,8 +330,8 @@ public:
 
 class TellActiveRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -374,10 +373,10 @@ private:
     return std::make_pair(first, last);
   }
 protected:
-  typedef IndexedList<a2_gid_t, SharedHandle<T> > ItemListType;
+  typedef IndexedList<a2_gid_t, std::shared_ptr<T> > ItemListType;
 
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e)
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE
   {
     const Integer* offsetParam = checkRequiredParam<Integer>(req, 0);
     const Integer* numParam = checkRequiredInteger(req, 1, IntegerGE(0));
@@ -388,26 +387,25 @@ protected:
     std::vector<std::string> keys;
     toStringList(std::back_inserter(keys), keysParam);
     const ItemListType& items = getItems(e);
-    std::pair<typename ItemListType::const_iterator,
-              typename ItemListType::const_iterator> range =
-      getPaginationRange(offset, num, items.begin(), items.end());
-    SharedHandle<List> list = List::g();
+    auto range = getPaginationRange(offset, num,
+                                    std::begin(items), std::end(items));
+    auto list = List::g();
     for(; range.first != range.second; ++range.first) {
-      SharedHandle<Dict> entryDict = Dict::g();
-      createEntry(entryDict, *range.first, e, keys);
-      list->append(entryDict);
+      auto entryDict = Dict::g();
+      createEntry(entryDict.get(), *range.first, e, keys);
+      list->append(std::move(entryDict));
     }
     if(offset < 0) {
       std::reverse(list->begin(), list->end());
     }
-    return list;
+    return std::move(list);
   }
 
   virtual const ItemListType& getItems(DownloadEngine* e) const = 0;
 
   virtual void createEntry
-  (const SharedHandle<Dict>& entryDict,
-   const SharedHandle<T>& item,
+  (Dict* entryDict,
+   const std::shared_ptr<T>& item,
    DownloadEngine* e,
    const std::vector<std::string>& keys) const = 0;
 };
@@ -415,13 +413,14 @@ protected:
 class TellWaitingRpcMethod:
     public AbstractPaginationRpcMethod<RequestGroup> {
 protected:
-  virtual const RequestGroupList& getItems(DownloadEngine* e) const;
+  virtual const RequestGroupList& getItems(DownloadEngine* e) const
+    CXX11_OVERRIDE;
 
   virtual void createEntry
-  (const SharedHandle<Dict>& entryDict,
-   const SharedHandle<RequestGroup>& item,
+  (Dict* entryDict,
+   const std::shared_ptr<RequestGroup>& item,
    DownloadEngine* e,
-   const std::vector<std::string>& keys) const;
+   const std::vector<std::string>& keys) const CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -432,13 +431,14 @@ public:
 class TellStoppedRpcMethod:
     public AbstractPaginationRpcMethod<DownloadResult> {
 protected:
-  virtual const DownloadResultList& getItems(DownloadEngine* e) const;
+  virtual const DownloadResultList& getItems(DownloadEngine* e) const
+    CXX11_OVERRIDE;
 
   virtual void createEntry
-  (const SharedHandle<Dict>& entryDict,
-   const SharedHandle<DownloadResult>& item,
+  (Dict* entryDict,
+   const std::shared_ptr<DownloadResult>& item,
    DownloadEngine* e,
-   const std::vector<std::string>& keys) const;
+   const std::vector<std::string>& keys) const CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -448,8 +448,8 @@ public:
 
 class ChangeOptionRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -459,8 +459,8 @@ public:
 
 class ChangeGlobalOptionRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -470,8 +470,8 @@ public:
 
 class GetVersionRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -481,8 +481,8 @@ public:
 
 class GetOptionRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -492,8 +492,8 @@ public:
 
 class GetGlobalOptionRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -503,8 +503,8 @@ public:
 
 class ChangePositionRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -514,8 +514,8 @@ public:
 
 class ChangeUriRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -525,8 +525,8 @@ public:
 
 class GetSessionInfoRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -536,8 +536,8 @@ public:
 
 class ShutdownRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -547,8 +547,8 @@ public:
 
 class GetGlobalStatRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -558,8 +558,8 @@ public:
 
 class ForceShutdownRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -569,8 +569,8 @@ public:
 
 class SystemMulticallRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 public:
   static const char* getMethodName()
   {
@@ -580,31 +580,39 @@ public:
 
 class NoSuchMethodRpcMethod:public RpcMethod {
 protected:
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e);
+  virtual std::unique_ptr<ValueBase> process
+  (const RpcRequest& req, DownloadEngine* e) CXX11_OVERRIDE;
 };
 
 // Helper function to store data to entryDict from ds. This function
 // is used by tellStatus method.
 void gatherStoppedDownload
-(const SharedHandle<Dict>& entryDict, const SharedHandle<DownloadResult>& ds,
+(Dict* entryDict, const std::shared_ptr<DownloadResult>& ds,
  const std::vector<std::string>& keys);
 
 // Helper function to store data to entryDict from group. This
 // function is used by tellStatus/tellActive/tellWaiting method
 void gatherProgressCommon
-(const SharedHandle<Dict>& entryDict, const SharedHandle<RequestGroup>& group,
+(Dict* entryDict, const std::shared_ptr<RequestGroup>& group,
  const std::vector<std::string>& keys);
 
 #ifdef ENABLE_BITTORRENT
 // Helper function to store BitTorrent metadata from torrentAttrs.
-void gatherBitTorrentMetadata
-(const SharedHandle<Dict>& btDict,
- const SharedHandle<TorrentAttribute>& torrentAttrs);
+void gatherBitTorrentMetadata(Dict* btDict, TorrentAttribute* torrentAttrs);
 #endif // ENABLE_BITTORRENT
 
 } // namespace rpc
 
+bool pauseRequestGroup
+(const std::shared_ptr<RequestGroup>& group, bool reserved,  bool forcePause);
+
+void changeOption
+(const std::shared_ptr<RequestGroup>& group,
+ const Option& option,
+ DownloadEngine* e);
+
+void changeGlobalOption(const Option& option, DownloadEngine* e);
+
 } // namespace aria2
 
 #endif // D_RPC_METHOD_IMPL_H
