@@ -49,11 +49,11 @@ SeedCheckCommand::SeedCheckCommand
 (cuid_t cuid,
  RequestGroup* requestGroup,
  DownloadEngine* e,
- const SharedHandle<SeedCriteria>& seedCriteria)
+ std::unique_ptr<SeedCriteria> seedCriteria)
   : Command(cuid),
     requestGroup_(requestGroup),
     e_(e),
-    seedCriteria_(seedCriteria),
+    seedCriteria_(std::move(seedCriteria)),
     checkStarted_(false)
 {
   setStatusRealtime();
@@ -84,23 +84,17 @@ bool SeedCheckCommand::execute() {
       btRuntime_->setHalt(true);
     }
   }
-  e_->addCommand(this);
+  e_->addCommand(std::unique_ptr<Command>(this));
   return false;
 }
 
-void SeedCheckCommand::setSeedCriteria
-(const SharedHandle<SeedCriteria>& seedCriteria)
-{
-  seedCriteria_ = seedCriteria;
-}
-
-void SeedCheckCommand::setBtRuntime(const SharedHandle<BtRuntime>& btRuntime)
+void SeedCheckCommand::setBtRuntime(const std::shared_ptr<BtRuntime>& btRuntime)
 {
   btRuntime_ = btRuntime;
 }
 
 void SeedCheckCommand::setPieceStorage
-(const SharedHandle<PieceStorage>& pieceStorage)
+(const std::shared_ptr<PieceStorage>& pieceStorage)
 {
   pieceStorage_ = pieceStorage;
 }
