@@ -40,8 +40,8 @@
 #include <deque>
 #include <vector>
 #include <map>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "TimerA2.h"
 #include "Command.h"
 #include "BitfieldMan.h"
@@ -58,9 +58,9 @@ class FileEntry;
 
 struct SegmentEntry {
   cuid_t cuid;
-  SharedHandle<Segment> segment;
+  std::shared_ptr<Segment> segment;
 
-  SegmentEntry(cuid_t cuid, const SharedHandle<Segment>& segment);
+  SegmentEntry(cuid_t cuid, const std::shared_ptr<Segment>& segment);
   ~SegmentEntry();
 
   // Don't allow copying
@@ -68,19 +68,16 @@ struct SegmentEntry {
   SegmentEntry& operator=(const SegmentEntry&);
 };
 
-typedef SharedHandle<SegmentEntry> SegmentEntryHandle;
-typedef std::deque<SegmentEntryHandle> SegmentEntries;
+typedef std::deque<std::shared_ptr<SegmentEntry> > SegmentEntries;
 
 /**
  * This class holds the download progress of the one download entry.
  */
 class SegmentMan {
 private:
-  const Option* option_;
+  std::shared_ptr<DownloadContext> downloadContext_;
 
-  SharedHandle<DownloadContext> downloadContext_;
-
-  SharedHandle<PieceStorage> pieceStorage_;
+  std::shared_ptr<PieceStorage> pieceStorage_;
 
   SegmentEntries usedSegmentEntries_;
 
@@ -89,28 +86,20 @@ private:
   std::map<size_t, int32_t> segmentWrittenLengthMemo_;
 
   // Used for calculating download speed.
-  std::vector<SharedHandle<PeerStat> > peerStats_;
+  std::vector<std::shared_ptr<PeerStat> > peerStats_;
 
   // Keep track of fastest PeerStat for each server
-  std::vector<SharedHandle<PeerStat> > fastestPeerStats_;
-
-  // key: PeerStat's cuid, value: its download speed
-  std::map<cuid_t, int> peerStatDlspdMap_;
-
-  Timer lastPeerStatDlspdMapUpdated_;
-
-  int cachedDlspd_;
+  std::vector<std::shared_ptr<PeerStat> > fastestPeerStats_;
 
   BitfieldMan ignoreBitfield_;
 
-  SharedHandle<Segment> checkoutSegment(cuid_t cuid,
-                                        const SharedHandle<Piece>& piece);
+  std::shared_ptr<Segment> checkoutSegment(cuid_t cuid,
+                                        const std::shared_ptr<Piece>& piece);
 
-  void cancelSegmentInternal(cuid_t cuid, const SharedHandle<Segment>& segment);
+  void cancelSegmentInternal(cuid_t cuid, const std::shared_ptr<Segment>& segment);
 public:
-  SegmentMan(const Option* option,
-             const SharedHandle<DownloadContext>& downloadContext,
-             const SharedHandle<PieceStorage>& pieceStorage);
+  SegmentMan(const std::shared_ptr<DownloadContext>& downloadContext,
+             const std::shared_ptr<PieceStorage>& pieceStorage);
 
   ~SegmentMan();
 
@@ -124,7 +113,7 @@ public:
    * If Transfer-Encoding is Chunked or Content-Length header is not provided,
    * then this value is set to be 0.
    */
-  off_t getTotalLength() const;
+  int64_t getTotalLength() const;
 
   /**
    * Returs true when the download has finished.
@@ -137,32 +126,32 @@ public:
    * Fill segments which are assigned to the command whose CUID is cuid.
    * This function doesn't clear passed segments.
    */
-  void getInFlightSegment(std::vector<SharedHandle<Segment> >& segments,
+  void getInFlightSegment(std::vector<std::shared_ptr<Segment> >& segments,
                           cuid_t cuid);
 
-  SharedHandle<Segment> getSegment(cuid_t cuid, size_t minSplitSize);
+  std::shared_ptr<Segment> getSegment(cuid_t cuid, size_t minSplitSize);
 
   // Checkouts segments in the range of fileEntry and push back to
   // segments until segments.size() < maxSegments holds false
-  void getSegment(std::vector<SharedHandle<Segment> >& segments,
+  void getSegment(std::vector<std::shared_ptr<Segment> >& segments,
                   cuid_t cuid,
                   size_t minSplitSize,
-                  const SharedHandle<FileEntry>& fileEntry,
+                  const std::shared_ptr<FileEntry>& fileEntry,
                   size_t maxSegments);
 
   /**
-   * Returns a segment whose index is index. 
+   * Returns a segment whose index is index.
    * If it has already assigned
    * to another cuid or has been downloaded, then returns a segment instance
    * whose isNull call is true.
    */
-  SharedHandle<Segment> getSegmentWithIndex(cuid_t cuid, size_t index);
+  std::shared_ptr<Segment> getSegmentWithIndex(cuid_t cuid, size_t index);
 
   // Returns a currently used segment whose index is index and written
   // length is 0.  The current owner(in idle state) of segment cancels
   // the segment and cuid command acquires the ownership of the
   // segment.  If no such segment exists, returns null.
-  SharedHandle<Segment> getCleanSegmentIfOwnerIsIdle(cuid_t cuid, size_t index);
+  std::shared_ptr<Segment> getCleanSegmentIfOwnerIsIdle(cuid_t cuid, size_t index);
 
   /**
    * Updates download status.
@@ -174,7 +163,7 @@ public:
    */
   void cancelSegment(cuid_t cuid);
 
-  void cancelSegment(cuid_t cuid, const SharedHandle<Segment>& segment);
+  void cancelSegment(cuid_t cuid, const std::shared_ptr<Segment>& segment);
 
   void cancelAllSegments();
 
@@ -183,17 +172,17 @@ public:
   /**
    * Tells SegmentMan that the segment has been downloaded successfully.
    */
-  bool completeSegment(cuid_t cuid, const SharedHandle<Segment>& segment);
+  bool completeSegment(cuid_t cuid, const std::shared_ptr<Segment>& segment);
 
   /**
    * Injects PieceStorage.
    */
-  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
+  void setPieceStorage(const std::shared_ptr<PieceStorage>& pieceStorage);
 
   /**
    * Injects DownloadContext.
    */
-  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);
+  void setDownloadContext(const std::shared_ptr<DownloadContext>& downloadContext);
 
   /**
    * Returns true if the segment whose index is index has been downloaded.
@@ -202,51 +191,39 @@ public:
   /**
    * Returns the length of bytes downloaded.
    */
-  off_t getDownloadLength() const;
+  int64_t getDownloadLength() const;
 
 
   // If there is inactive PeerStat in peerStats_, it is replaced with
   // given peerStat. If no such PeerStat exist, the given peerStat is
   // inserted.
-  void registerPeerStat(const SharedHandle<PeerStat>& peerStat);
+  void registerPeerStat(const std::shared_ptr<PeerStat>& peerStat);
 
-  const std::vector<SharedHandle<PeerStat> >& getPeerStats() const
+  const std::vector<std::shared_ptr<PeerStat> >& getPeerStats() const
   {
     return peerStats_;
   }
 
-  SharedHandle<PeerStat> getPeerStat(cuid_t cuid) const;
+  std::shared_ptr<PeerStat> getPeerStat(cuid_t cuid) const;
 
   // If there is slower PeerStat than given peerStat for the same
   // hostname and protocol in fastestPeerStats_, the former is
   // replaced with latter. If there are no PeerStat with same hostname
   // and protocol with given peerStat, given peerStat is inserted.
-  void updateFastestPeerStat(const SharedHandle<PeerStat>& peerStat);
+  void updateFastestPeerStat(const std::shared_ptr<PeerStat>& peerStat);
 
-  const std::vector<SharedHandle<PeerStat> >& getFastestPeerStats() const
+  const std::vector<std::shared_ptr<PeerStat> >& getFastestPeerStats() const
   {
     return fastestPeerStats_;
   }
 
-  /**
-   * Returns current download speed in bytes per sec. 
-   */
-  int calculateDownloadSpeed();
-
-  void updateDownloadSpeedFor(const SharedHandle<PeerStat>& pstat);
-
-  /**
-   * Returns the downloaded bytes in this session.
-   */
-  off_t calculateSessionDownloadLength() const;
-
   size_t countFreePieceFrom(size_t index) const;
 
   // Excludes segments that fileEntry covers from segment selection.
-  void ignoreSegmentFor(const SharedHandle<FileEntry>& fileEntry);
+  void ignoreSegmentFor(const std::shared_ptr<FileEntry>& fileEntry);
 
   // Includes segments that fileEntry covers in segment selection.
-  void recognizeSegmentFor(const SharedHandle<FileEntry>& fileEntry);
+  void recognizeSegmentFor(const std::shared_ptr<FileEntry>& fileEntry);
 
   bool allSegmentsIgnored() const;
 };
