@@ -56,21 +56,21 @@ ServerStatMan::ServerStatMan() {}
 
 ServerStatMan::~ServerStatMan() {}
 
-SharedHandle<ServerStat> ServerStatMan::find(const std::string& hostname,
+std::shared_ptr<ServerStat> ServerStatMan::find(const std::string& hostname,
                                              const std::string& protocol) const
 {
-  SharedHandle<ServerStat> ss(new ServerStat(hostname, protocol));
-  ServerStatSet::iterator i = serverStats_.find(ss);
+  std::shared_ptr<ServerStat> ss(new ServerStat(hostname, protocol));
+  auto i = serverStats_.find(ss);
   if(i == serverStats_.end()) {
-    return SharedHandle<ServerStat>();
+    return nullptr;
   } else {
     return *i;
   }
 }
 
-bool ServerStatMan::add(const SharedHandle<ServerStat>& serverStat)
+bool ServerStatMan::add(const std::shared_ptr<ServerStat>& serverStat)
 {
-  ServerStatSet::iterator i = serverStats_.lower_bound(serverStat);
+  auto i = serverStats_.lower_bound(serverStat);
   if(i != serverStats_.end() && *(*i) == *serverStat) {
     return false;
   } else {
@@ -90,9 +90,8 @@ bool ServerStatMan::save(const std::string& filename) const
                        filename.c_str()));
       return false;
     }
-    for(ServerStatSet::iterator i = serverStats_.begin(),
-          eoi = serverStats_.end(); i != eoi; ++i) {
-      std::string l = (*i)->toString();
+    for(auto& e: serverStats_) {
+      std::string l = e->toString();
       l += "\n";
       if(fp.write(l.data(), l.size()) != l.size()) {
         A2_LOG_ERROR(fmt(MSG_WRITING_SERVER_STAT_FILE_FAILED,
@@ -185,8 +184,7 @@ bool ServerStatMan::load(const std::string& filename)
     std::vector<std::string> m(MAX_FIELD);
     for(std::vector<Scip>::const_iterator i = items.begin(),
           eoi = items.end(); i != eoi; ++i) {
-      std::pair<Scip, Scip> p;
-      util::divide(p, (*i).first, (*i).second, '=');
+      auto p = util::divide((*i).first, (*i).second, '=');
       int id = idField(p.first.first, p.first.second);
       if(id != MAX_FIELD) {
         m[id].assign(p.second.first, p.second.second);
@@ -195,7 +193,7 @@ bool ServerStatMan::load(const std::string& filename)
     if(m[S_HOST].empty() || m[S_PROTOCOL].empty()) {
       continue;
     }
-    SharedHandle<ServerStat> sstat(new ServerStat(m[S_HOST], m[S_PROTOCOL]));
+    std::shared_ptr<ServerStat> sstat(new ServerStat(m[S_HOST], m[S_PROTOCOL]));
 
     uint32_t uintval;
     if(!util::parseUIntNoThrow(uintval, m[S_DL_SPEED])) {
@@ -243,7 +241,7 @@ private:
 public:
   FindStaleServerStat(time_t timeout):timeout_(timeout) {}
 
-  bool operator()(const SharedHandle<ServerStat>& ss) const
+  bool operator()(const std::shared_ptr<ServerStat>& ss) const
   {
     return ss->getLastUpdated().difference(time_) >= timeout_;
   }
@@ -253,8 +251,7 @@ public:
 void ServerStatMan::removeStaleServerStat(time_t timeout)
 {
   FindStaleServerStat finder(timeout);
-  for(ServerStatSet::iterator i = serverStats_.begin(),
-        eoi = serverStats_.end(); i != eoi;) {
+  for(auto i = serverStats_.begin(), eoi = serverStats_.end(); i != eoi;) {
     if(finder(*i)) {
       serverStats_.erase(i++);
     } else {
