@@ -39,25 +39,24 @@
 
 #include <string>
 #include <iosfwd>
-
-#include "SharedHandle.h"
+#include <memory>
 
 namespace aria2 {
 
 class RequestGroupMan;
+class IOFile;
 
 class SessionSerializer {
 private:
-  SharedHandle<RequestGroupMan> rgman_;
+  RequestGroupMan* rgman_;
   bool saveError_;
   bool saveInProgress_;
   bool saveWaiting_;
+  bool save(IOFile& fp) const;
 public:
-  SessionSerializer(const SharedHandle<RequestGroupMan>& requestGroupMan);
+  SessionSerializer(RequestGroupMan* requestGroupMan);
 
   bool save(const std::string& filename) const;
-
-  void save(std::ostream& out) const;
 };
 
 } // namespace aria2
