@@ -32,27 +32,26 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_STREAM_FILE_ALLOCATION_ENTRY_H_
-#define _D_STREAM_FILE_ALLOCATION_ENTRY_H_
+#ifndef D_STREAM_FILE_ALLOCATION_ENTRY_H
+#define D_STREAM_FILE_ALLOCATION_ENTRY_H
 
 #include "FileAllocationEntry.h"
-#include "TimeA2.h"
 
 namespace aria2 {
 
 class StreamFileAllocationEntry : public FileAllocationEntry {
-private:
-  Time _timer;
 public:
   StreamFileAllocationEntry(RequestGroup* requestGroup,
-                            Command* nextCommand = 0);
+                            std::unique_ptr<Command> nextCommand =
+                            std::unique_ptr<Command>());
 
   virtual ~StreamFileAllocationEntry();
 
-  virtual void prepareForNextAction(std::vector<Command*>& commands,
-                                    DownloadEngine* e);
+  virtual void prepareForNextAction
+  (std::vector<std::unique_ptr<Command>>& commands,
+   DownloadEngine* e) CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_STREAM_FILE_ALLOCATION_ENTRY_H_
+#endif // D_STREAM_FILE_ALLOCATION_ENTRY_H
