@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,38 +32,40 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_URI_RESULT_H_
-#define _D_URI_RESULT_H_
+#ifndef D_URI_RESULT_H
+#define D_URI_RESULT_H
 
 #include "common.h"
 
 #include <string>
 
-#include "DownloadResult.h"
+#include "error_code.h"
 
 namespace aria2 {
 
 // This class stores URI and its result code as a consequence of the download.
 class URIResult {
 private:
-  std::string _uri;
+  std::string uri_;
 
-  DownloadResult::RESULT _result;
+  error_code::Value result_;
 public:
-  URIResult(const std::string& uri, DownloadResult::RESULT result);
+  URIResult(const std::string& uri, error_code::Value result);
+
+  ~URIResult();
 
   const std::string& getURI() const
   {
-    return _uri;
+    return uri_;
   }
 
-  DownloadResult::RESULT getResult() const
+  error_code::Value getResult() const
   {
-    return _result;
+    return result_;
   }
 
 };
 
 } // namespace aria2
 
-#endif // _D_URI_RESULT_H_
+#endif // D_URI_RESULT_H
