@@ -56,11 +56,10 @@ namespace aria2 {
 bool UTMetadataPostDownloadHandler::Criteria::match
 (const RequestGroup* requestGroup) const
 {
-  const SharedHandle<DownloadContext>& dctx =
+  const std::shared_ptr<DownloadContext>& dctx =
     requestGroup->getDownloadContext();
-  if(dctx->hasAttribute(bittorrent::BITTORRENT)) {
-    SharedHandle<TorrentAttribute> attrs = bittorrent::getTorrentAttrs(dctx);
-    if(attrs->metadata.empty()) {
+  if(dctx->hasAttribute(CTX_ATTR_BT)) {
+    if(bittorrent::getTorrentAttrs(dctx)->metadata.empty()) {
       return true;
     }
   }
@@ -69,15 +68,15 @@ bool UTMetadataPostDownloadHandler::Criteria::match
 
 UTMetadataPostDownloadHandler::UTMetadataPostDownloadHandler()
 {
-  SharedHandle<Criteria> cri(new Criteria());
+  std::shared_ptr<Criteria> cri(new Criteria());
   setCriteria(cri);
 }
 
 void UTMetadataPostDownloadHandler::getNextRequestGroups
-(std::vector<SharedHandle<RequestGroup> >& groups, RequestGroup* requestGroup)
+(std::vector<std::shared_ptr<RequestGroup> >& groups, RequestGroup* requestGroup)
 {
-  const SharedHandle<DownloadContext>& dctx =requestGroup->getDownloadContext();
-  SharedHandle<TorrentAttribute> attrs = bittorrent::getTorrentAttrs(dctx);
+  const std::shared_ptr<DownloadContext>& dctx =requestGroup->getDownloadContext();
+  auto attrs = bittorrent::getTorrentAttrs(dctx);
   std::string metadata =
     util::toString(requestGroup->getPieceStorage()->getDiskAdaptor());
   std::string torrent = bittorrent::metadata2Torrent(metadata, attrs);
@@ -93,11 +92,12 @@ void UTMetadataPostDownloadHandler::getNextRequestGroups
     }
   }
   if(!requestGroup->getOption()->getAsBool(PREF_BT_METADATA_ONLY)) {
-    std::vector<SharedHandle<RequestGroup> > newRgs;
+    std::vector<std::shared_ptr<RequestGroup> > newRgs;
     // Don't adjust announce URI because it has been done when
     // RequestGroup is created with magnet URI.
     createRequestGroupForBitTorrent(newRgs, requestGroup->getOption(),
-                                    std::vector<std::string>(), torrent, false);
+                                    std::vector<std::string>(),
+                                    A2STR::NIL, torrent, false);
     requestGroup->followedBy(newRgs.begin(), newRgs.end());
     if(requestGroup->getMetadataInfo()) {
       setMetadataInfo(newRgs.begin(), newRgs.end(),
