@@ -43,13 +43,13 @@ namespace rpc {
 
 class WebSocketResponseCommand : public AbstractHttpServerResponseCommand {
 protected:
-  virtual void afterSend(const SharedHandle<HttpServer>& httpServer,
-                         DownloadEngine* e);
+  virtual void afterSend(const std::shared_ptr<HttpServer>& httpServer,
+                         DownloadEngine* e) CXX11_OVERRIDE;
 public:
   WebSocketResponseCommand(cuid_t cuid,
-                           const SharedHandle<HttpServer>& httpServer,
+                           const std::shared_ptr<HttpServer>& httpServer,
                            DownloadEngine* e,
-                           const SharedHandle<SocketCore>& socket);
+                           const std::shared_ptr<SocketCore>& socket);
 
   virtual ~WebSocketResponseCommand();
 };
