@@ -121,45 +121,45 @@ void mlCharacters(void* userData, const xmlChar* ch, int len)
 namespace {
 xmlSAXHandler mySAXHandler =
   {
-    0, // internalSubsetSAXFunc
-    0, // isStandaloneSAXFunc
-    0, // hasInternalSubsetSAXFunc
-    0, // hasExternalSubsetSAXFunc
-    0, // resolveEntitySAXFunc
-    0, // getEntitySAXFunc
-    0, // entityDeclSAXFunc
-    0, // notationDeclSAXFunc
-    0, // attributeDeclSAXFunc
-    0, // elementDeclSAXFunc
-    0, //   unparsedEntityDeclSAXFunc
-    0, //   setDocumentLocatorSAXFunc
-    0, //   startDocumentSAXFunc
-    0, //   endDocumentSAXFunc
-    0, //   startElementSAXFunc
-    0, //   endElementSAXFunc
-    0, //   referenceSAXFunc
+    nullptr, // internalSubsetSAXFunc
+    nullptr, // isStandaloneSAXFunc
+    nullptr, // hasInternalSubsetSAXFunc
+    nullptr, // hasExternalSubsetSAXFunc
+    nullptr, // resolveEntitySAXFunc
+    nullptr, // getEntitySAXFunc
+    nullptr, // entityDeclSAXFunc
+    nullptr, // notationDeclSAXFunc
+    nullptr, // attributeDeclSAXFunc
+    nullptr, // elementDeclSAXFunc
+    nullptr, //   unparsedEntityDeclSAXFunc
+    nullptr, //   setDocumentLocatorSAXFunc
+    nullptr, //   startDocumentSAXFunc
+    nullptr, //   endDocumentSAXFunc
+    nullptr, //   startElementSAXFunc
+    nullptr, //   endElementSAXFunc
+    nullptr, //   referenceSAXFunc
     &mlCharacters, //   charactersSAXFunc
-    0, //   ignorableWhitespaceSAXFunc
-    0, //   processingInstructionSAXFunc
-    0, //   commentSAXFunc
-    0, //   warningSAXFunc
-    0, //   errorSAXFunc
-    0, //   fatalErrorSAXFunc
-    0, //   getParameterEntitySAXFunc
-    0, //   cdataBlockSAXFunc
-    0, //   externalSubsetSAXFunc
+    nullptr, //   ignorableWhitespaceSAXFunc
+    nullptr, //   processingInstructionSAXFunc
+    nullptr, //   commentSAXFunc
+    nullptr, //   warningSAXFunc
+    nullptr, //   errorSAXFunc
+    nullptr, //   fatalErrorSAXFunc
+    nullptr, //   getParameterEntitySAXFunc
+    nullptr, //   cdataBlockSAXFunc
+    nullptr, //   externalSubsetSAXFunc
     XML_SAX2_MAGIC, //   unsigned int        initialized
-    0, //   void *      _private
+    nullptr, //   void *      _private
     &mlStartElement, //   startElementNsSAX2Func
     &mlEndElement, //   endElementNsSAX2Func
-    0, //   xmlStructuredErrorFunc
+    nullptr, //   xmlStructuredErrorFunc
   };
 } // namespace
 
 XmlParser::XmlParser(ParserStateMachine* psm)
   : psm_(psm),
     sessionData_(psm),
-    ctx_(xmlCreatePushParserCtxt(&mySAXHandler, &sessionData_, 0, 0, 0)),
+    ctx_(xmlCreatePushParserCtxt(&mySAXHandler, &sessionData_, nullptr, 0, nullptr)),
     lastError_(0)
 {}
 
@@ -198,7 +198,7 @@ int XmlParser::reset()
 {
   psm_->reset();
   sessionData_.reset();
-  int rv = xmlCtxtResetPush(ctx_, 0, 0, 0, 0);
+  int rv = xmlCtxtResetPush(ctx_, nullptr, 0, nullptr, nullptr);
   if(rv != 0) {
     return lastError_ = ERR_RESET;
   } else {
