@@ -141,7 +141,37 @@
 // For Windows, we share files for reading and writing.
 # define a2open(path, flags, mode) _wsopen(path, flags, _SH_DENYNO, mode)
 # define a2fopen(path, mode) _wfsopen(path, mode, _SH_DENYNO)
-#else // !__MINGW32__
+// # define a2ftruncate(fd, length): We don't use ftruncate in Mingw build
+# define a2_off_t off_t
+#elif defined(__ANDROID__) || defined(ANDROID)
+# define a2lseek(fd, offset, origin) lseek64(fd, offset, origin)
+// # define a2fseek(fp, offset, origin): No fseek64 and not used in aria2
+# define a2fstat(fd, buf) fstat64(fd, buf)
+// # define a2ftell(fd): No ftell64 and not used in aria2
+# define a2_struct_stat struct stat
+# define a2stat(path, buf) stat64(path, buf)
+# define a2mkdir(path, openMode) mkdir(path, openMode)
+# define a2utimbuf utimbuf
+# define a2utime(path, times) ::utime(path, times)
+# define a2unlink(path) unlink(path)
+# define a2rmdir(path) rmdir(path)
+# define a2rename(src, dest) rename(src, dest)
+# define a2open(path, flags, mode) open(path, flags, mode)
+# define a2fopen(path, mode) fopen(path, mode)
+// Android NDK R8e does not provide ftruncate64 prototype, so let's
+// define it here.
+#ifdef  __cplusplus
+extern "C" {
+#endif
+extern int ftruncate64(int fd, off64_t length);
+#ifdef __cplusplus
+}
+#endif
+# define a2ftruncate(fd, length) ftruncate64(fd, length)
+// Use off64_t directly since android does not offer transparent
+// switching between off_t and off64_t.
+# define a2_off_t off64_t
+#else // !__MINGW32__ && !(defined(__ANDROID__) || defined(ANDROID))
 # define a2lseek(fd, offset, origin) lseek(fd, offset, origin)
 # define a2fseek(fp, offset, origin) fseek(fp, offset, origin)
 # define a2fstat(fp, buf) fstat(fp, buf)
@@ -156,7 +186,9 @@
 # define a2rename(src, dest) rename(src, dest)
 # define a2open(path, flags, mode) open(path, flags, mode)
 # define a2fopen(path, mode) fopen(path, mode)
-#endif // !__MINGW32__
+# define a2ftruncate(fd, length) ftruncate(fd, length)
+# define a2_off_t off_t
+#endif
 
 #define OPEN_MODE S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH
 #define DIR_OPEN_MODE S_IRWXU|S_IRWXG|S_IRWXO
