@@ -34,7 +34,20 @@
 /* copyright --> */
 #include "util.h"
 
-#include <signal.h>
+#ifdef __sun
+// For opensolaris, just include signal.h which includes sys/signal.h
+#ifdef HAVE_SIGNAL_H
+#  include <signal.h>
+#endif // HAVE_SIGNAL_H
+#else // !__sun
+#ifdef HAVE_SYS_SIGNAL_H
+#  include <sys/signal.h>
+#endif // HAVE_SYS_SIGNAL_H
+#ifdef HAVE_SIGNAL_H
+#  include <signal.h>
+#endif // HAVE_SIGNAL_H
+#endif // !__sun
+
 #include <sys/types.h>
 #ifdef HAVE_PWD_H
 #  include <pwd.h>
@@ -70,7 +83,7 @@
 #include "DownloadContext.h"
 #include "BufferedFile.h"
 #include "SocketCore.h"
-#include "prefs.h"
+#include "Lock.h"
 
 #ifdef ENABLE_MESSAGE_DIGEST
 # include "MessageDigest.h"
@@ -116,16 +129,15 @@ int wCharToAnsi(char* out, size_t outLength, const wchar_t* src)
 std::wstring utf8ToWChar(const char* src)
 {
   int len = utf8ToWChar(0, 0, src);
-  if(len == 0) {
+  if(len <= 0) {
     abort();
   }
-  array_ptr<wchar_t> buf(new wchar_t[len]);
-  len = utf8ToWChar(buf, len, src);
-  if(len == 0) {
+  auto buf = make_unique<wchar_t[]>((size_t)len);
+  len = utf8ToWChar(buf.get(), len, src);
+  if(len <= 0) {
     abort();
   } else {
-    std::wstring dest(buf);
-    return dest;
+    return buf.get();
   }
 }
 
@@ -138,47 +150,45 @@ std::string utf8ToNative(const std::string& src)
 {
   std::wstring wsrc = utf8ToWChar(src);
   int len = wCharToAnsi(0, 0, wsrc.c_str());
-  if(len == 0) {
+  if(len <= 0) {
     abort();
   }
-  array_ptr<char> buf(new char[len]);
-  len = wCharToAnsi(buf, len, wsrc.c_str());
-  if(len == 0) {
+  auto buf = make_unique<char[]>((size_t)len);
+  len = wCharToAnsi(buf.get(), len, wsrc.c_str());
+  if(len <= 0) {
     abort();
   } else {
-    std::string dest(buf);
-    return dest;
+    return buf.get();
   }
 }
 
 std::string wCharToUtf8(const std::wstring& wsrc)
 {
   int len = wCharToUtf8(0, 0, wsrc.c_str());
-  if(len == 0) {
+  if(len <= 0) {
     abort();
   }
-  array_ptr<char> buf(new char[len]);
-  len = wCharToUtf8(buf, len, wsrc.c_str());
-  if(len == 0) {
+  auto buf = make_unique<char[]>((size_t)len);
+  len = wCharToUtf8(buf.get(), len, wsrc.c_str());
+  if(len <= 0) {
     abort();
   } else {
-    std::string dest(buf);
-    return dest;
+    return buf.get();
   }
 }
 
 std::string nativeToUtf8(const std::string& src)
 {
   int len = ansiToWChar(0, 0, src.c_str());
-  if(len == 0) {
+  if(len <= 0) {
     abort();
   }
-  array_ptr<wchar_t> buf(new wchar_t[len]);
-  len = ansiToWChar(buf, len, src.c_str());
-  if(len == 0) {
+  auto buf = make_unique<wchar_t[]>((size_t)len);
+  len = ansiToWChar(buf.get(), len, src.c_str());
+  if(len <= 0) {
     abort();
   } else {
-    return wCharToUtf8(std::wstring(buf));
+    return wCharToUtf8(std::wstring(buf.get()));
   }
 }
 #endif // __MINGW32__
@@ -268,8 +278,8 @@ bool isHexDigit(const char c)
 
 bool isHexDigit(const std::string& s)
 {
-  for(std::string::const_iterator i = s.begin(), eoi = s.end(); i != eoi; ++i) {
-    if(!isHexDigit(*i)) {
+  for (const auto& c : s) {
+    if(!isHexDigit(c)) {
       return false;
     }
   }
@@ -282,14 +292,16 @@ bool inRFC3986ReservedChars(const char c)
     ':' , '/' , '?' , '#' , '[' , ']' , '@',
     '!' , '$' , '&' , '\'' , '(' , ')',
     '*' , '+' , ',' , ';' , '=' };
-  return std::find(vbegin(reserved), vend(reserved), c) != vend(reserved);
+  return std::find(std::begin(reserved), std::end(reserved), c)
+    != std::end(reserved);
 }
 
 bool inRFC3986UnreservedChars(const char c)
 {
   static const char unreserved[] = { '-', '.', '_', '~' };
   return isAlpha(c) || isDigit(c) ||
-    std::find(vbegin(unreserved), vend(unreserved), c) != vend(unreserved);
+    std::find(std::begin(unreserved), std::end(unreserved), c)
+    != std::end(unreserved);
 }
 
 bool inRFC2978MIMECharset(const char c)
@@ -300,7 +312,7 @@ bool inRFC2978MIMECharset(const char c)
     '`', '{', '}', '~'
   };
   return isAlpha(c) || isDigit(c) ||
-    std::find(vbegin(chars), vend(chars), c) != vend(chars);
+    std::find(std::begin(chars), std::end(chars), c) != std::end(chars);
 }
 
 bool inRFC2616HttpToken(const char c)
@@ -310,7 +322,7 @@ bool inRFC2616HttpToken(const char c)
     '^', '_', '`', '|', '~'
   };
   return isAlpha(c) || isDigit(c) ||
-    std::find(vbegin(chars), vend(chars), c) != vend(chars);
+    std::find(std::begin(chars), std::end(chars), c) != std::end(chars);
 }
 
 bool inRFC5987AttrChar(const char c)
@@ -334,10 +346,19 @@ bool isCRLF(const char c)
 }
 
 namespace {
+
 bool isUtf8Tail(unsigned char ch)
 {
   return in(ch, 0x80u, 0xbfu);
 }
+
+bool inPercentEncodeMini(const unsigned char c)
+{
+  return c > 0x20 && c < 0x7fu &&
+    // Chromium escapes following characters. Firefox4 escapes more.
+    c != '"' && c != '<' && c != '>';
+}
+
 } // namespace
 
 bool isUtf8(const std::string& str)
@@ -420,22 +441,24 @@ std::string percentEncode(const unsigned char* target, size_t len)
 
 std::string percentEncode(const std::string& target)
 {
+  if (std::find_if_not(target.begin(), target.end(),
+                       inRFC3986UnreservedChars) == target.end()) {
+    return target;
+  }
   return percentEncode(reinterpret_cast<const unsigned char*>(target.c_str()),
                        target.size());
 }
 
 std::string percentEncodeMini(const std::string& src)
 {
+  if (std::find_if_not(src.begin(), src.end(), inPercentEncodeMini) ==
+      src.end()) {
+    return src;
+  }
   std::string result;
-  for(std::string::const_iterator i = src.begin(), eoi = src.end(); i != eoi;
-      ++i) {
-    // Non-Printable ASCII and non-ASCII chars + some ASCII chars.
-    unsigned char c = *i;
-    if(in(c, 0x00u, 0x20u) || c >= 0x7fu ||
-       // Chromium escapes following characters. Firefox4 escapes
-       // more.
-       c == '"' || c == '<' || c == '>') {
-      result += fmt("%%%02X", c);
+  for (auto c: src) {
+    if(!inPercentEncodeMini(c)) {
+      result += fmt("%%%02X", static_cast<unsigned char>(c));
     } else {
       result += c;
     }
@@ -643,23 +666,22 @@ void parseIntSegments(SegList<int>& sgl, const std::string& src)
 namespace {
 void computeHeadPieces
 (std::vector<size_t>& indexes,
- const std::vector<SharedHandle<FileEntry> >& fileEntries,
+ const std::vector<std::shared_ptr<FileEntry> >& fileEntries,
  size_t pieceLength,
  int64_t head)
 {
   if(head == 0) {
     return;
   }
-  for(std::vector<SharedHandle<FileEntry> >::const_iterator fi =
-        fileEntries.begin(), eoi = fileEntries.end(); fi != eoi; ++fi) {
-    if((*fi)->getLength() == 0) {
+  for (const auto& fi: fileEntries) {
+    if(fi->getLength() == 0) {
       continue;
     }
-    size_t lastIndex =
-      ((*fi)->getOffset()+std::min(head, (*fi)->getLength())-1)/pieceLength;
-    for(size_t index = (*fi)->getOffset()/pieceLength;
-        index <= lastIndex; ++index) {
-      indexes.push_back(index);
+    const size_t lastIndex = (fi->getOffset() +
+        std::min(head, fi->getLength()) - 1
+        ) / pieceLength;
+    for(size_t idx = fi->getOffset() / pieceLength; idx <= lastIndex; ++idx) {
+      indexes.push_back(idx);
     }
   }
 }
@@ -668,24 +690,23 @@ void computeHeadPieces
 namespace {
 void computeTailPieces
 (std::vector<size_t>& indexes,
- const std::vector<SharedHandle<FileEntry> >& fileEntries,
+ const std::vector<std::shared_ptr<FileEntry> >& fileEntries,
  size_t pieceLength,
  int64_t tail)
 {
   if(tail == 0) {
     return;
   }
-  for(std::vector<SharedHandle<FileEntry> >::const_iterator fi =
-        fileEntries.begin(), eoi = fileEntries.end(); fi != eoi; ++fi) {
-    if((*fi)->getLength() == 0) {
+  for (const auto& fi: fileEntries) {
+    if(fi->getLength() == 0) {
       continue;
     }
-    int64_t endOffset = (*fi)->getLastOffset();
-    size_t fromIndex =
-      (endOffset-1-(std::min(tail, (*fi)->getLength())-1))/pieceLength;
-    for(size_t index = fromIndex; index <= (endOffset-1)/pieceLength;
-        ++index) {
-      indexes.push_back(index);
+    int64_t endOffset = fi->getLastOffset();
+    size_t fromIndex = (endOffset - 1 - (std::min(tail, fi->getLength()) - 1)) /
+      pieceLength;
+    const size_t toIndex = (endOffset - 1) / pieceLength;
+    while (fromIndex <= toIndex) {
+      indexes.push_back(fromIndex++);
     }
   }
 }
@@ -693,30 +714,33 @@ void computeTailPieces
 
 void parsePrioritizePieceRange
 (std::vector<size_t>& result, const std::string& src,
- const std::vector<SharedHandle<FileEntry> >& fileEntries,
+ const std::vector<std::shared_ptr<FileEntry> >& fileEntries,
  size_t pieceLength,
  int64_t defaultSize)
 {
   std::vector<size_t> indexes;
   std::vector<Scip> parts;
   splitIter(src.begin(), src.end(), std::back_inserter(parts), ',', true);
-  for(std::vector<Scip>::const_iterator i = parts.begin(),
-        eoi = parts.end(); i != eoi; ++i) {
-    if(util::streq((*i).first, (*i).second, "head")) {
+  for (const auto& i: parts) {
+    if(util::streq(i.first, i.second, "head")) {
       computeHeadPieces(indexes, fileEntries, pieceLength, defaultSize);
-    } else if(util::startsWith((*i).first, (*i).second, "head=")) {
-      std::string sizestr((*i).first+5, (*i).second);
+    }
+    else if(util::startsWith(i.first, i.second, "head=")) {
+      std::string sizestr(i.first + 5, i.second);
       computeHeadPieces(indexes, fileEntries, pieceLength,
                         std::max((int64_t)0, getRealSize(sizestr)));
-    } else if(util::streq((*i).first, (*i).second, "tail")) {
+    }
+    else if(util::streq(i.first, i.second, "tail")) {
       computeTailPieces(indexes, fileEntries, pieceLength, defaultSize);
-    } else if(util::startsWith((*i).first, (*i).second, "tail=")) {
-      std::string sizestr((*i).first+5, (*i).second);
+    }
+    else if(util::startsWith(i.first, i.second, "tail=")) {
+      std::string sizestr(i.first + 5, i.second);
       computeTailPieces(indexes, fileEntries, pieceLength,
                         std::max((int64_t)0, getRealSize(sizestr)));
-    } else {
+    }
+    else {
       throw DL_ABORT_EX(fmt("Unrecognized token %s",
-                            std::string((*i).first, (*i).second).c_str()));
+                            std::string(i.first, i.second).c_str()));
     }
   }
   std::sort(indexes.begin(), indexes.end());
@@ -854,7 +878,7 @@ ssize_t parse_content_disposition(char *dest, size_t destlen,
                                   const char **charsetp, size_t *charsetlenp,
                                   const char *in, size_t len)
 {
-  const char *p = in, *eop = in + len, *mark_first = NULL, *mark_last = NULL;
+  const char *p = in, *eop = in + len, *mark_first = nullptr, *mark_last = nullptr;
   int state = CD_BEFORE_DISPOSITION_TYPE;
   int in_file_parm = 0;
   int flags = 0;
@@ -867,7 +891,7 @@ ssize_t parse_content_disposition(char *dest, size_t destlen,
   uint32_t dfa_code = 0;
   uint8_t pctval = 0;
 
-  *charsetp = NULL;
+  *charsetp = nullptr;
   *charsetlenp = 0;
 
   for(; p != eop; ++p) {
@@ -1153,32 +1177,30 @@ std::string getContentDispositionFilename(const std::string& header)
                                          header.c_str(), header.size());
   if(rv == -1) {
     return "";
-  } else {
-    std::string res;
-    if(!charset || strieq(charset, charset+charsetlen, "iso-8859-1")) {
-      res = iso8859p1ToUtf8(cdval, rv);
-    } else {
-      res.assign(cdval, rv);
-    }
-    if(!detectDirTraversal(res) &&
-       res.find_first_of("/\\") == std::string::npos) {
-      return res;
-    } else {
-      return "";
-    }
   }
+
+  std::string res;
+  if(!charset || strieq(charset, charset+charsetlen, "iso-8859-1")) {
+    res = iso8859p1ToUtf8(cdval, rv);
+  } else {
+    res.assign(cdval, rv);
+  }
+  if(!detectDirTraversal(res) &&
+      res.find_first_of("/\\") == std::string::npos) {
+    return res;
+  }
+  return "";
 }
 
-std::string toUpper(const std::string& src) {
-  std::string temp = src;
-  uppercase(temp);
-  return temp;
+std::string toUpper(std::string src)
+{
+  uppercase(src);
+  return src;
 }
 
-std::string toLower(const std::string& src) {
-  std::string temp = src;
-  lowercase(temp);
-  return temp;
+std::string toLower(std::string src) {
+  lowercase(src);
+  return src;
 }
 
 void uppercase(std::string& s)
@@ -1214,20 +1236,96 @@ bool isNumericHost(const std::string& name)
   memset(&hints, 0, sizeof(hints));
   hints.ai_family = AF_UNSPEC;
   hints.ai_flags = AI_NUMERICHOST;
-  if(getaddrinfo(name.c_str(), 0, &hints, &res)) {
+  if(getaddrinfo(name.c_str(), nullptr, &hints, &res)) {
     return false;
   }
   freeaddrinfo(res);
   return true;
 }
 
-void setGlobalSignalHandler(int sig, void (*handler)(int), int flags) {
+#if _WIN32
+namespace {
+  static Lock win_signal_lock;
+
+  static signal_handler_t win_int_handler = nullptr;
+  static signal_handler_t win_term_handler = nullptr;
+
+  static void win_ign_handler(int) {}
+
+  static BOOL WINAPI HandlerRoutine(DWORD ctrlType)
+  {
+    void(*handler)(int) = nullptr;
+    switch (ctrlType) {
+      case CTRL_C_EVENT:
+      case CTRL_BREAK_EVENT:
+        {
+          // Handler will be called on a new/different thread.
+          LockGuard lg(win_signal_lock);
+          handler = win_int_handler;
+        }
+
+        if (handler) {
+          handler(SIGINT);
+          return TRUE;
+        }
+        return FALSE;
+
+      case CTRL_LOGOFF_EVENT:
+      case CTRL_CLOSE_EVENT:
+      case CTRL_SHUTDOWN_EVENT:
+        {
+          // Handler will be called on a new/different thread.
+          LockGuard lg(win_signal_lock);
+          handler = win_term_handler;;
+        }
+        if (handler) {
+          handler(SIGTERM);
+          return TRUE;
+        }
+        return FALSE;
+    }
+    return FALSE;
+  }
+}
+#endif
+
+void setGlobalSignalHandler(int sig, sigset_t* mask, signal_handler_t handler,
+                            int flags) {
+#if _WIN32
+  if (sig == SIGINT || sig == SIGTERM) {
+    // Handler will be called on a new/different thread.
+    LockGuard lg(win_signal_lock);
+
+    if (handler == SIG_DFL) {
+      handler = nullptr;
+    }
+    else if (handler == SIG_IGN) {
+      handler = win_ign_handler;
+    }
+    // Not yet in use: add console handler.
+    if (handler && !win_int_handler && !win_term_handler) {
+      ::SetConsoleCtrlHandler(HandlerRoutine, TRUE);
+    }
+    if (sig == SIGINT) {
+      win_int_handler = handler;
+    }
+    else {
+      win_term_handler = handler;
+    }
+    // No handlers set: remove.
+    if (!win_int_handler && !win_term_handler) {
+      ::SetConsoleCtrlHandler(HandlerRoutine, FALSE);
+    }
+    return;
+  }
+#endif
+
 #ifdef HAVE_SIGACTION
   struct sigaction sigact;
   sigact.sa_handler = handler;
   sigact.sa_flags = flags;
-  sigemptyset(&sigact.sa_mask);
-  sigaction(sig, &sigact, NULL);
+  sigact.sa_mask = *mask;
+  sigaction(sig, &sigact, nullptr);
 #else
   signal(sig, handler);
 #endif // HAVE_SIGACTION
@@ -1236,32 +1334,30 @@ void setGlobalSignalHandler(int sig, void (*handler)(int), int flags) {
 std::string getHomeDir()
 {
   const char* p = getenv("HOME");
-  if(p) {
+  if (p) {
     return p;
-  } else {
-#ifdef __MINGW32__
-    p = getenv("USERPROFILE");
-    if(p) {
-      return p;
-    } else {
-      p = getenv("HOMEDRIVE");
-      if(p) {
-        std::string homeDir = p;
-        p = getenv("HOMEPATH");
-        if(p) {
-          homeDir += p;
-          return homeDir;
-        }
-      }
-    }
-#elif HAVE_PWD_H
-    passwd* pw = getpwuid(geteuid());
-    if(pw && pw->pw_dir) {
-      return pw->pw_dir;
-    }
-#endif // HAVE_PWD_H
-    return A2STR::NIL;
   }
+#ifdef __MINGW32__
+  p = getenv("USERPROFILE");
+  if (p) {
+    return p;
+  }
+  p = getenv("HOMEDRIVE");
+  if (p) {
+    std::string homeDir = p;
+    p = getenv("HOMEPATH");
+    if (p) {
+      homeDir += p;
+      return homeDir;
+    }
+  }
+#elif HAVE_PWD_H
+  passwd* pw = getpwuid(geteuid());
+  if(pw && pw->pw_dir) {
+    return pw->pw_dir;
+  }
+#endif // HAVE_PWD_H
+  return A2STR::NIL;
 }
 
 int64_t getRealSize(const std::string& sizeWithUnit)
@@ -1288,7 +1384,8 @@ int64_t getRealSize(const std::string& sizeWithUnit)
   if(!parseLLIntNoThrow(v, size) || v < 0) {
     throw DL_ABORT_EX(fmt("Bad or negative value detected: %s",
                           sizeWithUnit.c_str()));
-  } else if(INT64_MAX/mult < v) {
+  }
+  if(INT64_MAX/mult < v) {
     throw DL_ABORT_EX(fmt(MSG_STRING_INTEGER_CONVERSION_FAILURE,
                           "overflow/underflow"));
   }
@@ -1375,11 +1472,9 @@ void mkdirs(const std::string& dirpath)
   if(!dir.mkdirs()) {
     int errNum = errno;
     if(!dir.isDir()) {
-      throw DL_ABORT_EX3
-        (errNum,
-         fmt(EX_MAKE_DIR, dir.getPath().c_str(),
-             safeStrerror(errNum).c_str()),
-         error_code::DIR_CREATE_ERROR);
+      throw DL_ABORT_EX3(errNum, fmt(EX_MAKE_DIR, dir.getPath().c_str(),
+                                     safeStrerror(errNum).c_str()),
+                         error_code::DIR_CREATE_ERROR);
     }
   }
 }
@@ -1395,7 +1490,7 @@ void convertBitfield(BitfieldMan* dest, const BitfieldMan* src)
   }
 }
 
-std::string toString(const SharedHandle<BinaryStream>& binaryStream)
+std::string toString(const std::shared_ptr<BinaryStream>& binaryStream)
 {
   std::stringstream strm;
   char data[2048];
@@ -1419,9 +1514,8 @@ void* allocateAlignedMemory(size_t alignment, size_t size)
   void* buffer;
   int res;
   if((res = posix_memalign(&buffer, alignment, size)) != 0) {
-    throw FATAL_EXCEPTION
-      (fmt("Error in posix_memalign: %s",
-           util::safeStrerror(res).c_str()));
+    throw FATAL_EXCEPTION(fmt("Error in posix_memalign: %s",
+                              util::safeStrerror(res).c_str()));
   }
   return buffer;
 }
@@ -1444,31 +1538,36 @@ getNumericNameInfo(const struct sockaddr* sockaddr, socklen_t len)
 std::string htmlEscape(const std::string& src)
 {
   std::string dest;
-  for(std::string::const_iterator i = src.begin(), eoi = src.end();
-      i != eoi; ++i) {
+  dest.reserve(src.size());
+  auto j = std::begin(src);
+  for(auto i = std::begin(src); i != std::end(src); ++i) {
     char ch = *i;
+    const char *repl;
     if(ch == '<') {
-      dest += "&lt;";
+      repl = "&lt;";
     } else if(ch == '>') {
-      dest += "&gt;";
+      repl = "&gt;";
     } else if(ch == '&') {
-      dest += "&amp;";
+      repl = "&amp;";
     } else if(ch == '\'') {
-      dest += "&#39;";
+      repl = "&#39;";
     } else if(ch == '"') {
-      dest += "&quot;";
+      repl = "&quot;";
     } else {
-      dest += ch;
+      continue;
     }
+    dest.append(j, i);
+    j = i + 1;
+    dest += repl;
   }
+  dest.append(j, std::end(src));
   return dest;
 }
 
 std::pair<size_t, std::string>
 parseIndexPath(const std::string& line)
 {
-  std::pair<Scip, Scip> p;
-  divide(p, line.begin(), line.end(), '=');
+  auto p = divide(std::begin(line), std::end(line), '=');
   uint32_t index;
   if(!parseUIntNoThrow(index, std::string(p.first.first, p.first.second))) {
     throw DL_ABORT_EX("Bad path index");
@@ -1492,10 +1591,8 @@ std::vector<std::pair<size_t, std::string> > createIndexPaths(std::istream& i)
 namespace {
 void generateRandomDataRandom(unsigned char* data, size_t length)
 {
-  const SharedHandle<SimpleRandomizer>& rd = SimpleRandomizer::getInstance();
-  for(size_t i = 0; i < length; ++i) {
-    data[i] = static_cast<unsigned long>(rd->getRandomNumber(256));
-  }
+  const auto& rd = SimpleRandomizer::getInstance();
+  rd->getRandomBytes(data, length);
 }
 } // namespace
 
@@ -1559,11 +1656,13 @@ std::string applyDir(const std::string& dir, const std::string& relPath)
   if(dir.empty()) {
     s = "./";
     s += relPath;
-  } else {
+  }
+  else {
     s = dir;
     if(dir == "/") {
       s += relPath;
-    } else {
+    }
+    else {
       s += "/";
       s += relPath;
     }
@@ -1588,7 +1687,8 @@ void generateRandomKey(unsigned char* key)
 #ifdef ENABLE_MESSAGE_DIGEST
   unsigned char bytes[40];
   generateRandomData(bytes, sizeof(bytes));
-  message_digest::digest(key, 20, MessageDigest::sha1(), bytes, sizeof(bytes));
+  message_digest::digest(key, 20, MessageDigest::sha1().get(), bytes,
+                         sizeof(bytes));
 #else // !ENABLE_MESSAGE_DIGEST
   generateRandomData(key, 20);
 #endif // !ENABLE_MESSAGE_DIGEST
@@ -1623,18 +1723,20 @@ bool detectDirTraversal(const std::string& s)
   if(s.empty()) {
     return false;
   }
-  for(std::string::const_iterator i = s.begin(), eoi = s.end(); i != eoi; ++i) {
-    unsigned char c = *i;
-    if(in(c, 0x00u, 0x1fu) || c == 0x7fu) {
+  for (auto c : s) {
+    unsigned char ch = c;
+    if (in(ch, 0x00u, 0x1fu) || ch == 0x7fu) {
       return true;
     }
   }
   return s == "." || s == ".." || s[0] == '/' ||
-    util::startsWith(s, "./") || util::startsWith(s, "../") ||
+    util::startsWith(s, "./") ||
+    util::startsWith(s, "../") ||
     s.find("/../") != std::string::npos ||
     s.find("/./") != std::string::npos ||
     s[s.size()-1] == '/' ||
-    util::endsWith(s, "/.") || util::endsWith(s, "/..");
+    util::endsWith(s, "/.") ||
+    util::endsWith(s, "/..");
 }
 
 std::string escapePath(const std::string& s)
@@ -1645,18 +1747,18 @@ std::string escapePath(const std::string& s)
     { '"', '*', ':', '<', '>', '?', '\\', '|' };
 #endif // __MINGW32__
   std::string d;
-  for(std::string::const_iterator i = s.begin(), eoi = s.end(); i != eoi; ++i) {
-    unsigned char c = *i;
+  for(auto cc: s) {
+    unsigned char c = cc;
     if(in(c, 0x00u, 0x1fu) || c == 0x7fu
 #ifdef __MINGW32__
-       || std::find(vbegin(WIN_INVALID_PATH_CHARS),
-                    vend(WIN_INVALID_PATH_CHARS),
-                    c) != vend(WIN_INVALID_PATH_CHARS)
+       || std::find(std::begin(WIN_INVALID_PATH_CHARS),
+                    std::end(WIN_INVALID_PATH_CHARS),
+                    c) != std::end(WIN_INVALID_PATH_CHARS)
 #endif // __MINGW32__
        ){
       d += fmt("%%%02X", c);
     } else {
-      d += *i;
+      d += c;
     }
   }
   return d;
@@ -1705,9 +1807,8 @@ void executeHook
                   numFilesStr.c_str(),
                   firstFilename.c_str()));
   pid_t cpid = fork();
-  if(cpid == -1) {
-    A2_LOG_ERROR("fork() failed. Cannot execute user command.");
-  } else if(cpid == 0) {
+  if (cpid > 0) {
+    // child!
     execlp(command.c_str(),
            command.c_str(),
            gidStr.c_str(),
@@ -1715,9 +1816,16 @@ void executeHook
            firstFilename.c_str(),
            reinterpret_cast<char*>(0));
     perror(("Could not execute user command: "+command).c_str());
-    exit(EXIT_FAILURE);
+    _exit(EXIT_FAILURE);
+    return;
   }
-#else
+
+  if(cpid == -1) {
+    A2_LOG_ERROR("fork() failed. Cannot execute user command.");
+  }
+  return;
+
+#else // __MINGW32__
   PROCESS_INFORMATION pi;
   STARTUPINFOW si;
 
@@ -1727,6 +1835,8 @@ void executeHook
   bool batch = util::iendsWith(command, ".bat");
   std::string cmdline;
   std::string cmdexe;
+
+  // XXX batch handling, in particular quoting, correct?
   if(batch) {
     const char* p = getenv("windir");
     if(p) {
@@ -1755,17 +1865,17 @@ void executeHook
   }
   int cmdlineLen = utf8ToWChar(0, 0, cmdline.c_str());
   assert(cmdlineLen > 0);
-  array_ptr<wchar_t> wcharCmdline(new wchar_t[cmdlineLen]);
-  cmdlineLen = utf8ToWChar(wcharCmdline, cmdlineLen, cmdline.c_str());
+  auto wcharCmdline = std::unique_ptr<wchar_t[]>(new wchar_t[cmdlineLen]);
+  cmdlineLen = utf8ToWChar(wcharCmdline.get(), cmdlineLen, cmdline.c_str());
   assert(cmdlineLen > 0);
   A2_LOG_INFO(fmt("Executing user command: %s", cmdline.c_str()));
-  DWORD rc = CreateProcessW(batch ? utf8ToWChar(cmdexe).c_str() : NULL,
-                            wcharCmdline,
-                            NULL,
-                            NULL,
+  DWORD rc = CreateProcessW(batch ? utf8ToWChar(cmdexe).c_str() : nullptr,
+                            wcharCmdline.get(),
+                            nullptr,
+                            nullptr,
                             true,
                             0,
-                            NULL,
+                            nullptr,
                             0,
                             &si,
                             &pi);
@@ -1773,28 +1883,30 @@ void executeHook
   if(!rc) {
     A2_LOG_ERROR("CreateProcess() failed. Cannot execute user command.");
   }
+  return;
+
 #endif
 }
 
 } // namespace
 
 void executeHookByOptName
-(const SharedHandle<RequestGroup>& group, const Option* option,
- const Pref* pref)
+(const std::shared_ptr<RequestGroup>& group, const Option* option,
+ PrefPtr pref)
 {
   executeHookByOptName(group.get(), option, pref);
 }
 
 void executeHookByOptName
-(const RequestGroup* group, const Option* option, const Pref* pref)
+(const RequestGroup* group, const Option* option, PrefPtr pref)
 {
   const std::string& cmd = option->get(pref);
   if(!cmd.empty()) {
-    const SharedHandle<DownloadContext> dctx = group->getDownloadContext();
+    const std::shared_ptr<DownloadContext> dctx = group->getDownloadContext();
     std::string firstFilename;
     size_t numFiles = 0;
     if(!group->inMemoryDownload()) {
-      SharedHandle<FileEntry> file = dctx->getFirstRequestedFileEntry();
+      std::shared_ptr<FileEntry> file = dctx->getFirstRequestedFileEntry();
       if(file) {
         firstFilename = file->getPath();
       }
@@ -1807,11 +1919,10 @@ void executeHookByOptName
 std::string createSafePath
 (const std::string& dir, const std::string& filename)
 {
-  return util::applyDir
-    (dir,
-     util::isUtf8(filename)?
-     util::fixTaintedBasename(filename):
-     util::escapePath(util::percentEncode(filename)));
+  return util::applyDir(dir, util::isUtf8(filename) ?
+                             util::fixTaintedBasename(filename) :
+                             util::escapePath(util::percentEncode(filename))
+                        );
 }
 
 std::string encodeNonUtf8(const std::string& s)
@@ -1821,11 +1932,10 @@ std::string encodeNonUtf8(const std::string& s)
 
 std::string makeString(const char* str)
 {
-  if(str) {
-    return str;
-  } else {
+  if(!str) {
     return A2STR::NIL;
   }
+  return str;
 }
 
 std::string safeStrerror(int errNum)
@@ -1839,9 +1949,8 @@ bool noProxyDomainMatch
 {
   if(!domain.empty() && domain[0] == '.' && !util::isNumericHost(hostname)) {
     return util::endsWith(hostname, domain);
-  } else {
-    return hostname == domain;
   }
+  return hostname == domain;
 }
 
 bool tlsHostnameMatch(const std::string& pattern, const std::string& hostname)
@@ -1882,11 +1991,10 @@ bool tlsHostnameMatch(const std::string& pattern, const std::string& hostname)
   if(hnLeftLabelEnd - hostname.begin() < ptLeftLabelEnd - pattern.begin()) {
     return false;
   }
-  return
-    istartsWith(hostname.begin(), hnLeftLabelEnd,
-                pattern.begin(), ptWildcard) &&
-    iendsWith(hostname.begin(), hnLeftLabelEnd,
-              ptWildcard+1, ptLeftLabelEnd);
+  return istartsWith(hostname.begin(), hnLeftLabelEnd, pattern.begin(),
+                     ptWildcard) &&
+         iendsWith(hostname.begin(), hnLeftLabelEnd, ptWildcard + 1,
+                   ptLeftLabelEnd);
 }
 
 bool strieq(const std::string& a, const char* b)
