@@ -75,7 +75,7 @@ class BittorrentHelperTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testAdjustAnnounceUri);
   CPPUNIT_TEST_SUITE_END();
 public:
-  SharedHandle<Option> option_;
+  std::shared_ptr<Option> option_;
 
   void setUp()
   {
@@ -136,7 +136,7 @@ public:
 CPPUNIT_TEST_SUITE_REGISTRATION(BittorrentHelperTest);
 
 void BittorrentHelperTest::testGetInfoHash() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
 
   std::string correctHash = "248d0a1cd08284299de78d5c1ed359bb46717d8c";
@@ -145,7 +145,7 @@ void BittorrentHelperTest::testGetInfoHash() {
 }
 
 void BittorrentHelperTest::testGetPieceHash() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
 
   CPPUNIT_ASSERT_EQUAL(std::string("AAAAAAAAAAAAAAAAAAAA"),
@@ -161,39 +161,39 @@ void BittorrentHelperTest::testGetPieceHash() {
 }
 
 void BittorrentHelperTest::testGetFileEntries() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   option_->put(PREF_MAX_CONNECTION_PER_SERVER, "10");
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
   // This is multi-file torrent.
-  std::vector<SharedHandle<FileEntry> > fileEntries = dctx->getFileEntries();
+  std::vector<std::shared_ptr<FileEntry> > fileEntries = dctx->getFileEntries();
   // There are 2 file entries.
   CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntries.size());
-  std::vector<SharedHandle<FileEntry> >::iterator itr = fileEntries.begin();
+  std::vector<std::shared_ptr<FileEntry> >::iterator itr = fileEntries.begin();
 
-  SharedHandle<FileEntry> fileEntry1 = *itr;
+  std::shared_ptr<FileEntry> fileEntry1 = *itr;
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-test/aria2/src/aria2c"),
                        fileEntry1->getPath());
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-test/aria2/src/aria2c"),
                        fileEntry1->getOriginalName());
   CPPUNIT_ASSERT_EQUAL(10, fileEntry1->getMaxConnectionPerServer());
   itr++;
-  SharedHandle<FileEntry> fileEntry2 = *itr;
+  std::shared_ptr<FileEntry> fileEntry2 = *itr;
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-test/aria2-0.2.2.tar.bz2"),
                        fileEntry2->getPath());
   CPPUNIT_ASSERT_EQUAL(10, fileEntry2->getMaxConnectionPerServer());
 }
 
 void BittorrentHelperTest::testGetFileEntriesSingle() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   option_->put(PREF_MAX_CONNECTION_PER_SERVER, "10");
   load(A2_TEST_DIR"/single.torrent", dctx, option_);
   // This is multi-file torrent.
-  std::vector<SharedHandle<FileEntry> > fileEntries = dctx->getFileEntries();
+  std::vector<std::shared_ptr<FileEntry> > fileEntries = dctx->getFileEntries();
   // There is 1 file entry.
   CPPUNIT_ASSERT_EQUAL((size_t)1, fileEntries.size());
-  std::vector<SharedHandle<FileEntry> >::iterator itr = fileEntries.begin();
+  std::vector<std::shared_ptr<FileEntry> >::iterator itr = fileEntries.begin();
 
-  SharedHandle<FileEntry> fileEntry1 = *itr;
+  std::shared_ptr<FileEntry> fileEntry1 = *itr;
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-0.8.2.tar.bz2"),
                        fileEntry1->getPath());
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-0.8.2.tar.bz2"),
@@ -202,42 +202,42 @@ void BittorrentHelperTest::testGetFileEntriesSingle() {
 }
 
 void BittorrentHelperTest::testGetTotalLength() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
 
-  CPPUNIT_ASSERT_EQUAL((off_t)384LL, dctx->getTotalLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)384LL, dctx->getTotalLength());
 }
 
 void BittorrentHelperTest::testGetTotalLengthSingle() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/single.torrent", dctx, option_);
 
-  CPPUNIT_ASSERT_EQUAL((off_t)384LL, dctx->getTotalLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)384LL, dctx->getTotalLength());
 }
 
 void BittorrentHelperTest::testGetFileModeMulti() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
 
-  CPPUNIT_ASSERT_EQUAL(MULTI, getTorrentAttrs(dctx)->mode);
+  CPPUNIT_ASSERT_EQUAL(BT_FILE_MODE_MULTI, getTorrentAttrs(dctx)->mode);
 }
 
 void BittorrentHelperTest::testGetFileModeSingle() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/single.torrent", dctx, option_);
 
-  CPPUNIT_ASSERT_EQUAL(SINGLE, getTorrentAttrs(dctx)->mode);
+  CPPUNIT_ASSERT_EQUAL(BT_FILE_MODE_SINGLE, getTorrentAttrs(dctx)->mode);
 }
 
 void BittorrentHelperTest::testGetNameMulti() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
 
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-test"), getTorrentAttrs(dctx)->name);
 }
 
 void BittorrentHelperTest::testGetNameSingle() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/single.torrent", dctx, option_);
 
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-0.8.2.tar.bz2"),
@@ -248,7 +248,7 @@ void BittorrentHelperTest::testGetNameSingle() {
 
 void BittorrentHelperTest::testOverrideName()
 {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_, "aria2-override.name");
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-override.name"),
                        dctx->getBasePath());
@@ -258,9 +258,9 @@ void BittorrentHelperTest::testOverrideName()
 
 
 void BittorrentHelperTest::testGetAnnounceTier() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/single.torrent", dctx, option_);
-  SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+  auto attrs = getTorrentAttrs(dctx);
   // There is 1 tier.
   CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList.size());
 
@@ -270,9 +270,9 @@ void BittorrentHelperTest::testGetAnnounceTier() {
 }
 
 void BittorrentHelperTest::testGetAnnounceTierAnnounceList() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
-  SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+  auto attrs = getTorrentAttrs(dctx);
   // There are 3 tiers.
   CPPUNIT_ASSERT_EQUAL((size_t)3, attrs->announceList.size());
 
@@ -290,14 +290,14 @@ void BittorrentHelperTest::testGetAnnounceTierAnnounceList() {
 }
 
 void BittorrentHelperTest::testGetPieceLength() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
 
   CPPUNIT_ASSERT_EQUAL(128, dctx->getPieceLength());
 }
 
 void BittorrentHelperTest::testGetInfoHashAsString() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
 
   CPPUNIT_ASSERT_EQUAL(std::string("248d0a1cd08284299de78d5c1ed359bb46717d8c"),
@@ -322,16 +322,14 @@ void BittorrentHelperTest::testComputeFastSet()
     std::vector<size_t> fastSet;
     computeFastSet(fastSet, ipaddr, numPieces, infoHash, fastSetSize);
     size_t ans[] = { 686, 459, 278, 200, 404, 834, 64, 203, 760, 950 };
-    std::vector<size_t> ansSet(vbegin(ans), vend(ans));
-    CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), ansSet.begin()));
+    CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), std::begin(ans)));
   }
   ipaddr = "10.0.0.1";
   {
     std::vector<size_t> fastSet;
     computeFastSet(fastSet, ipaddr, numPieces, infoHash, fastSetSize);
     size_t ans[] = { 568, 188, 466, 452, 550, 662, 109, 226, 398, 11 };
-    std::vector<size_t> ansSet(vbegin(ans), vend(ans));
-    CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), ansSet.begin()));
+    CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), std::begin(ans)));
   }
   // See when pieces < fastSetSize
   numPieces = 9;
@@ -339,23 +337,22 @@ void BittorrentHelperTest::testComputeFastSet()
     std::vector<size_t> fastSet;
     computeFastSet(fastSet, ipaddr, numPieces, infoHash, fastSetSize);
     size_t ans[] = { 8, 6, 7, 5, 1, 4, 0, 2, 3 };
-    std::vector<size_t> ansSet(vbegin(ans), vend(ans));
-    CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), ansSet.begin()));
+    CPPUNIT_ASSERT(std::equal(fastSet.begin(), fastSet.end(), std::begin(ans)));
   }
 }
 
 void BittorrentHelperTest::testGetFileEntries_multiFileUrlList() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/url-list-multiFile.torrent", dctx, option_);
   // This is multi-file torrent.
-  const std::vector<SharedHandle<FileEntry> >& fileEntries =
+  const std::vector<std::shared_ptr<FileEntry> >& fileEntries =
     dctx->getFileEntries();
   // There are 2 file entries.
   CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntries.size());
-  std::vector<SharedHandle<FileEntry> >::const_iterator itr =
+  std::vector<std::shared_ptr<FileEntry> >::const_iterator itr =
     fileEntries.begin();
 
-  const SharedHandle<FileEntry>& fileEntry1 = *itr;
+  const std::shared_ptr<FileEntry>& fileEntry1 = *itr;
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-test@/aria2@/src@/aria2c@"),
                        fileEntry1->getPath());
   const std::deque<std::string>& uris1 = fileEntry1->getRemainingUris();
@@ -366,7 +363,7 @@ void BittorrentHelperTest::testGetFileEntries_multiFileUrlList() {
                        uris1[1]);
 
   ++itr;
-  const SharedHandle<FileEntry>& fileEntry2 = *itr;
+  const std::shared_ptr<FileEntry>& fileEntry2 = *itr;
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2-test@/aria2-0.2.2.tar.bz2"),
                        fileEntry2->getPath());
   const std::deque<std::string>& uris2 = fileEntry2->getRemainingUris();
@@ -378,15 +375,15 @@ void BittorrentHelperTest::testGetFileEntries_multiFileUrlList() {
 }
 
 void BittorrentHelperTest::testGetFileEntries_singleFileUrlList() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/url-list-singleFile.torrent", dctx, option_);
   // This is single-file torrent.
-  const std::vector<SharedHandle<FileEntry> >& fileEntries =
+  const std::vector<std::shared_ptr<FileEntry> >& fileEntries =
     dctx->getFileEntries();
   // There are 1 file entries.
   CPPUNIT_ASSERT_EQUAL((size_t)1, fileEntries.size());
 
-  const SharedHandle<FileEntry>& fileEntry1 = fileEntries.front();
+  const std::shared_ptr<FileEntry>& fileEntry1 = fileEntries.front();
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2.tar.bz2"),
                        fileEntry1->getPath());
   const std::deque<std::string>& uris1 = fileEntry1->getRemainingUris();
@@ -396,15 +393,15 @@ void BittorrentHelperTest::testGetFileEntries_singleFileUrlList() {
 }
 
 void BittorrentHelperTest::testGetFileEntries_singleFileUrlListEndsWithSlash() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/url-list-singleFileEndsWithSlash.torrent", dctx, option_);
   // This is single-file torrent.
-  const std::vector<SharedHandle<FileEntry> >& fileEntries =
+  const std::vector<std::shared_ptr<FileEntry> >& fileEntries =
     dctx->getFileEntries();
   // There are 1 file entries.
   CPPUNIT_ASSERT_EQUAL((size_t)1, fileEntries.size());
 
-  const SharedHandle<FileEntry>& fileEntry1 = fileEntries.front();
+  const std::shared_ptr<FileEntry>& fileEntry1 = fileEntries.front();
   CPPUNIT_ASSERT_EQUAL(std::string("./aria2@.tar.bz2"),
                        fileEntry1->getPath());
   const std::deque<std::string>& uris1 = fileEntry1->getRemainingUris();
@@ -415,25 +412,25 @@ void BittorrentHelperTest::testGetFileEntries_singleFileUrlListEndsWithSlash() {
 
 void BittorrentHelperTest::testLoadFromMemory_multiFileNonUtf8Path()
 {
-  SharedHandle<List> path = List::g();
+  auto path = List::g();
   path->append("path");
   path->append(fromHex("90a28a")+"E");
-  SharedHandle<Dict> file = Dict::g();
+  auto file = Dict::g();
   file->put("length", Integer::g(1024));
-  file->put("path", path);
-  SharedHandle<List> files = List::g();
-  files->append(file);
-  SharedHandle<Dict> info = Dict::g();
-  info->put("files", files);
+  file->put("path", std::move(path));
+  auto files = List::g();
+  files->append(std::move(file));
+  auto info = Dict::g();
+  info->put("files", std::move(files));
   info->put("piece length", Integer::g(1024));
   info->put("pieces", "01234567890123456789");
   info->put("name", fromHex("1b")+"$B%O%m!<"+fromHex("1b")+"(B");
   Dict dict;
-  dict.put("info", info);
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  dict.put("info", std::move(info));
+  auto dctx = std::make_shared<DownloadContext>();
   loadFromMemory(bencode2::encode(&dict), dctx, option_, "default");
 
-  const SharedHandle<FileEntry>& fe = dctx->getFirstFileEntry();
+  auto& fe = dctx->getFirstFileEntry();
   CPPUNIT_ASSERT_EQUAL
     (std::string("./%1B%24B%25O%25m%21%3C%1B%28B/path/%90%A2%8AE"),
      fe->getPath());
@@ -443,17 +440,17 @@ void BittorrentHelperTest::testLoadFromMemory_multiFileNonUtf8Path()
 
 void BittorrentHelperTest::testLoadFromMemory_singleFileNonUtf8Path()
 {
-  SharedHandle<Dict> info = Dict::g();
+  auto info = Dict::g();
   info->put("piece length", Integer::g(1024));
   info->put("pieces", "01234567890123456789");
   info->put("name", fromHex("90a28a")+"E");
   info->put("length", Integer::g(1024));
   Dict dict;
-  dict.put("info", info);
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  dict.put("info", std::move(info));
+  auto dctx = std::make_shared<DownloadContext>();
   loadFromMemory(bencode2::encode(&dict), dctx, option_, "default");
 
-  const SharedHandle<FileEntry>& fe = dctx->getFirstFileEntry();
+  const std::shared_ptr<FileEntry>& fe = dctx->getFirstFileEntry();
   CPPUNIT_ASSERT_EQUAL(std::string("./%90%A2%8AE"), fe->getPath());
 }
 
@@ -461,7 +458,7 @@ void BittorrentHelperTest::testLoadFromMemory()
 {
   std::string memory = "d8:announce36:http://aria.rednoah.com/announce.php13:announce-listll16:http://tracker1 el15:http://tracker2el15:http://tracker3ee7:comment17:REDNOAH.COM RULES13:creation datei1123456789e4:infod5:filesld6:lengthi284e4:pathl5:aria23:src6:aria2ceed6:lengthi100e4:pathl19:aria2-0.2.2.tar.bz2eee4:name10:aria2-test12:piece lengthi128e6:pieces60:AAAAAAAAAAAAAAAAAAAABBBBBBBBBBBBBBBBBBBBCCCCCCCCCCCCCCCCCCCCee";
 
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   loadFromMemory(memory, dctx, option_, "default");
 
   std::string correctHash = "248d0a1cd08284299de78d5c1ed359bb46717d8c";
@@ -474,7 +471,7 @@ void BittorrentHelperTest::testLoadFromMemory_somethingMissing()
   // pieces missing
   try {
     std::string memory = "d8:announce36:http://aria.rednoah.com/announce.php4:infod4:name13:aria2.tar.bz26:lengthi262144eee";
-    SharedHandle<DownloadContext> dctx(new DownloadContext());
+    std::shared_ptr<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, option_, "default");
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(Exception& e) {
@@ -486,7 +483,7 @@ void BittorrentHelperTest::testLoadFromMemory_overrideName()
 {
   std::string memory = "d8:announce36:http://aria.rednoah.com/announce.php13:announce-listll16:http://tracker1 el15:http://tracker2el15:http://tracker3ee7:comment17:REDNOAH.COM RULES13:creation datei1123456789e4:infod5:filesld6:lengthi284e4:pathl5:aria23:src6:aria2ceed6:lengthi100e4:pathl19:aria2-0.2.2.tar.bz2eee4:name10:aria2-test12:piece lengthi128e6:pieces60:AAAAAAAAAAAAAAAAAAAABBBBBBBBBBBBBBBBBBBBCCCCCCCCCCCCCCCCCCCCee";
 
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   loadFromMemory(memory, dctx, option_, "default", "aria2-override.name");
 
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-override.name"),
@@ -498,7 +495,7 @@ void BittorrentHelperTest::testLoadFromMemory_multiFileDirTraversal()
   std::string memory =
     "d8:announce27:http://example.com/announce4:infod5:filesld6:lengthi262144e4:pathl7:../dir14:dir28:file.imgeee4:name14:../name1/name212:piece lengthi262144e6:pieces20:00000000000000000000ee";
 
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   try {
     loadFromMemory(memory, dctx, option_, "default");
     CPPUNIT_FAIL("Exception must be thrown.");
@@ -512,7 +509,7 @@ void BittorrentHelperTest::testLoadFromMemory_singleFileDirTraversal()
   std::string memory =
     "d8:announce27:http://example.com/announce4:infod4:name14:../name1/name26:lengthi262144e12:piece lengthi262144e6:pieces20:00000000000000000000ee";
 
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   try {
     loadFromMemory(memory, dctx, option_, "default");
   } catch(RecoverableException& e) {
@@ -531,10 +528,10 @@ void BittorrentHelperTest::testGetNodes()
       "12:piece lengthi262144e"
       "6:pieces20:AAAAAAAAAAAAAAAAAAAA"
       "ee";
-    SharedHandle<DownloadContext> dctx(new DownloadContext());
+    std::shared_ptr<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, option_, "default");
 
-    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    auto attrs = getTorrentAttrs(dctx);
     CPPUNIT_ASSERT_EQUAL((size_t)2, attrs->nodes.size());
     CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), attrs->nodes[0].first);
     CPPUNIT_ASSERT_EQUAL((uint16_t)6881, attrs->nodes[0].second);
@@ -551,16 +548,16 @@ void BittorrentHelperTest::testGetNodes()
       "12:piece lengthi262144e"
       "6:pieces20:AAAAAAAAAAAAAAAAAAAA"
       "ee";
-    SharedHandle<DownloadContext> dctx(new DownloadContext());
+    std::shared_ptr<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, option_, "default");
 
-    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    auto attrs = getTorrentAttrs(dctx);
     CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->nodes.size());
     CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[0].first);
     CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[0].second);
   }
   {
-    // bad port 
+    // bad port
     std::string memory =
       "d5:nodesl"
       "l11:192.168.0.11:xe"
@@ -569,10 +566,10 @@ void BittorrentHelperTest::testGetNodes()
       "12:piece lengthi262144e"
       "6:pieces20:AAAAAAAAAAAAAAAAAAAA"
       "ee";
-    SharedHandle<DownloadContext> dctx(new DownloadContext());
+    std::shared_ptr<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, option_, "default");
 
-    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    auto attrs = getTorrentAttrs(dctx);
     CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->nodes.size());
     CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[0].first);
     CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[0].second);
@@ -587,10 +584,10 @@ void BittorrentHelperTest::testGetNodes()
       "12:piece lengthi262144e"
       "6:pieces20:AAAAAAAAAAAAAAAAAAAA"
       "ee";
-    SharedHandle<DownloadContext> dctx(new DownloadContext());
+    std::shared_ptr<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, option_, "default");
 
-    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    auto attrs = getTorrentAttrs(dctx);
     CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->nodes.size());
     CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[0].first);
     CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[0].second);
@@ -604,10 +601,10 @@ void BittorrentHelperTest::testGetNodes()
       "12:piece lengthi262144e"
       "6:pieces20:AAAAAAAAAAAAAAAAAAAA"
       "ee";
-    SharedHandle<DownloadContext> dctx(new DownloadContext());
+    std::shared_ptr<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, option_, "default");
 
-    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    auto attrs = getTorrentAttrs(dctx);
     CPPUNIT_ASSERT_EQUAL((size_t)0, attrs->nodes.size());
   }
   {
@@ -620,10 +617,10 @@ void BittorrentHelperTest::testGetNodes()
       "12:piece lengthi262144e"
       "6:pieces20:AAAAAAAAAAAAAAAAAAAA"
       "ee";
-    SharedHandle<DownloadContext> dctx(new DownloadContext());
+    std::shared_ptr<DownloadContext> dctx(new DownloadContext());
     loadFromMemory(memory, dctx, option_, "default");
 
-    SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+    auto attrs = getTorrentAttrs(dctx);
     CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->nodes.size());
     CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), attrs->nodes[0].first);
     CPPUNIT_ASSERT_EQUAL((uint16_t)6882, attrs->nodes[0].second);
@@ -632,13 +629,13 @@ void BittorrentHelperTest::testGetNodes()
 
 void BittorrentHelperTest::testGetBasePath()
 {
-  SharedHandle<DownloadContext> singleCtx(new DownloadContext());
+  std::shared_ptr<DownloadContext> singleCtx(new DownloadContext());
   load(A2_TEST_DIR"/single.torrent", singleCtx, option_);
   singleCtx->setFilePathWithIndex(1, "new-path");
   CPPUNIT_ASSERT_EQUAL(std::string("new-path"), singleCtx->getBasePath());
 
   option_->put(PREF_DIR, "downloads");
-  SharedHandle<DownloadContext> multiCtx(new DownloadContext());
+  std::shared_ptr<DownloadContext> multiCtx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", multiCtx, option_);
   CPPUNIT_ASSERT_EQUAL(std::string("downloads/aria2-test"),
                        multiCtx->getBasePath());
@@ -646,7 +643,7 @@ void BittorrentHelperTest::testGetBasePath()
 
 void BittorrentHelperTest::testSetFileFilter_single()
 {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/single.torrent", dctx, option_);
 
   CPPUNIT_ASSERT(dctx->getFirstFileEntry()->isRequested());
@@ -669,7 +666,7 @@ void BittorrentHelperTest::testSetFileFilter_single()
 
 void BittorrentHelperTest::testSetFileFilter_multi()
 {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
 
   CPPUNIT_ASSERT(dctx->getFileEntries()[0]->isRequested());
@@ -700,7 +697,7 @@ void BittorrentHelperTest::testSetFileFilter_multi()
 
 void BittorrentHelperTest::testUTF8Torrent()
 {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/utf8.torrent", dctx, option_);
   CPPUNIT_ASSERT_EQUAL(std::string("name in utf-8"),
                        getTorrentAttrs(dctx)->name);
@@ -712,7 +709,7 @@ void BittorrentHelperTest::testUTF8Torrent()
 
 void BittorrentHelperTest::testEtc()
 {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
   CPPUNIT_ASSERT_EQUAL(std::string("REDNOAH.COM RULES"),
                        getTorrentAttrs(dctx)->comment);
@@ -743,14 +740,13 @@ void BittorrentHelperTest::testCheckBitfield()
 }
 
 void BittorrentHelperTest::testMetadata() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  auto dctx = std::make_shared<DownloadContext>();
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
   std::string torrentData = readFile(A2_TEST_DIR"/test.torrent");
-  SharedHandle<ValueBase> tr =
-    bencode2::decode(torrentData.begin(), torrentData.end());
-  SharedHandle<ValueBase> infoDic = downcast<Dict>(tr)->get("info");
+  auto tr = bencode2::decode(torrentData);
+  auto infoDic = downcast<Dict>(tr)->get("info");
   std::string metadata = bencode2::encode(infoDic);
-  SharedHandle<TorrentAttribute> attrs = getTorrentAttrs(dctx);
+  auto attrs = getTorrentAttrs(dctx);
   CPPUNIT_ASSERT(metadata == attrs->metadata);
   CPPUNIT_ASSERT_EQUAL(metadata.size(), attrs->metadataSize);
 }
@@ -760,7 +756,7 @@ void BittorrentHelperTest::testParseMagnet()
   std::string magnet =
     "magnet:?xt=urn:btih:248d0a1cd08284299de78d5c1ed359bb46717d8c&dn=aria2"
     "&tr=http://tracker1&tr=http://tracker2";
-  SharedHandle<TorrentAttribute> attrs = bittorrent::parseMagnet(magnet);
+  auto attrs = bittorrent::parseMagnet(magnet);
   CPPUNIT_ASSERT_EQUAL(std::string("248d0a1cd08284299de78d5c1ed359bb46717d8c"),
                        util::toHex(attrs->infoHash));
   CPPUNIT_ASSERT_EQUAL(std::string("[METADATA]aria2"), attrs->name);
@@ -789,7 +785,7 @@ void BittorrentHelperTest::testParseMagnet_base32()
   std::string infoHash = "248d0a1cd08284299de78d5c1ed359bb46717d8c";
   std::string base32InfoHash = base32::encode(fromHex(infoHash));
   std::string magnet = "magnet:?xt=urn:btih:"+base32InfoHash+"&dn=aria2";
-  SharedHandle<TorrentAttribute> attrs = bittorrent::parseMagnet(magnet);
+  auto attrs = bittorrent::parseMagnet(magnet);
   CPPUNIT_ASSERT_EQUAL
     (std::string("248d0a1cd08284299de78d5c1ed359bb46717d8c"),
      util::toHex(attrs->infoHash));
@@ -797,26 +793,26 @@ void BittorrentHelperTest::testParseMagnet_base32()
 
 void BittorrentHelperTest::testMetadata2Torrent()
 {
+  TorrentAttribute attrs;
   std::string metadata = "METADATA";
-  SharedHandle<TorrentAttribute> attrs(new TorrentAttribute());
   CPPUNIT_ASSERT_EQUAL
-    (std::string("d4:infoMETADATAe"), metadata2Torrent(metadata, attrs));
-  attrs->announceList.push_back(std::vector<std::string>());
-  attrs->announceList[0].push_back("http://localhost/announce");
+    (std::string("d4:infoMETADATAe"), metadata2Torrent(metadata, &attrs));
+  attrs.announceList.push_back(std::vector<std::string>());
+  attrs.announceList[0].push_back("http://localhost/announce");
   CPPUNIT_ASSERT_EQUAL
     (std::string("d"
                  "13:announce-list"
                  "ll25:http://localhost/announceee"
                  "4:infoMETADATA"
                  "e"),
-     metadata2Torrent(metadata, attrs));
+     metadata2Torrent(metadata, &attrs));
 }
 
 void BittorrentHelperTest::testTorrent2Magnet()
 {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  std::shared_ptr<DownloadContext> dctx(new DownloadContext());
   load(A2_TEST_DIR"/test.torrent", dctx, option_);
-  
+
   CPPUNIT_ASSERT_EQUAL
     (std::string("magnet:?xt=urn:btih:248D0A1CD08284299DE78D5C1ED359BB46717D8C"
                  "&dn=aria2-test"
@@ -831,10 +827,9 @@ void BittorrentHelperTest::testExtractPeerFromString()
   std::string hextext = "100210354527354678541237324732171ae1";
   hextext += "20010db8bd0501d2288a1fc0000110ee1ae2";
   std::string peersstr = "36:"+fromHex(hextext);
-  SharedHandle<ValueBase> str =
-    bencode2::decode(peersstr.begin(), peersstr.end());
-  std::deque<SharedHandle<Peer> > peers;
-  extractPeer(str, AF_INET6, std::back_inserter(peers));
+  auto str = bencode2::decode(peersstr);
+  std::deque<std::shared_ptr<Peer>> peers;
+  extractPeer(str.get(), AF_INET6, std::back_inserter(peers));
   CPPUNIT_ASSERT_EQUAL((size_t)2, peers.size());
   CPPUNIT_ASSERT_EQUAL(std::string("1002:1035:4527:3546:7854:1237:3247:3217"),
                        peers[0]->getIPAddress());
@@ -846,14 +841,14 @@ void BittorrentHelperTest::testExtractPeerFromString()
   hextext = "c0a800011ae1";
   hextext += "c0a800021ae2";
   peersstr = "12:"+fromHex(hextext);
-  str = bencode2::decode(peersstr.begin(), peersstr.end());
+  str = bencode2::decode(peersstr);
   peers.clear();
-  extractPeer(str, AF_INET, std::back_inserter(peers));
+  extractPeer(str.get(), AF_INET, std::back_inserter(peers));
   CPPUNIT_ASSERT_EQUAL((size_t)2, peers.size());
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), peers[0]->getIPAddress());
   CPPUNIT_ASSERT_EQUAL((uint16_t)6881, peers[0]->getPort());
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.2"), peers[1]->getIPAddress());
-  CPPUNIT_ASSERT_EQUAL((uint16_t)6882, peers[1]->getPort()); 
+  CPPUNIT_ASSERT_EQUAL((uint16_t)6882, peers[1]->getPort());
 }
 
 void BittorrentHelperTest::testExtractPeerFromList()
@@ -862,13 +857,12 @@ void BittorrentHelperTest::testExtractPeerFromList()
     "d5:peersld2:ip11:192.168.0.17:peer id20:aria2-00000000000000"
     "4:porti2006eeee";
 
-  SharedHandle<ValueBase> dict =
-    bencode2::decode(peersString.begin(), peersString.end());
-  
-  std::deque<SharedHandle<Peer> > peers;
+  auto dict = bencode2::decode(peersString);
+
+  std::deque<std::shared_ptr<Peer>> peers;
   extractPeer(downcast<Dict>(dict)->get("peers"), AF_INET, std::back_inserter(peers));
   CPPUNIT_ASSERT_EQUAL((size_t)1, peers.size());
-  SharedHandle<Peer> peer = *peers.begin();
+  auto& peer = *peers.begin();
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), peer->getIPAddress());
   CPPUNIT_ASSERT_EQUAL((uint16_t)2006, peer->getPort());
 }
@@ -880,13 +874,12 @@ void BittorrentHelperTest::testExtract2PeersFromList()
     "4:porti65535eed2:ip11:192.168.0.27:peer id20:aria2-00000000000000"
     "4:porti2007eeee";
 
-  SharedHandle<ValueBase> dict =
-    bencode2::decode(peersString.begin(), peersString.end());
+  auto dict = bencode2::decode(peersString);
 
-  std::deque<SharedHandle<Peer> > peers;
+  std::deque<std::shared_ptr<Peer>> peers;
   extractPeer(downcast<Dict>(dict)->get("peers"), AF_INET, std::back_inserter(peers));
   CPPUNIT_ASSERT_EQUAL((size_t)2, peers.size());
-  SharedHandle<Peer> peer = *peers.begin();
+  auto& peer = *peers.begin();
   CPPUNIT_ASSERT_EQUAL(std::string("192.168.0.1"), peer->getIPAddress());
   CPPUNIT_ASSERT_EQUAL((uint16_t)65535, peer->getPort());
 
@@ -931,78 +924,78 @@ void BittorrentHelperTest::testUnpackcompact()
 
 void BittorrentHelperTest::testRemoveAnnounceUri()
 {
-  SharedHandle<TorrentAttribute> attrs(new TorrentAttribute());
+  TorrentAttribute attrs;
   std::vector<std::string> tier1;
   tier1.push_back("http://host1/announce");
   std::vector<std::string> tier2;
   tier2.push_back("http://host2/announce");
   tier2.push_back("http://host3/announce");
-  attrs->announceList.push_back(tier1);
-  attrs->announceList.push_back(tier2);
-  
+  attrs.announceList.push_back(tier1);
+  attrs.announceList.push_back(tier2);
+
   std::vector<std::string> removeUris;
   removeUris.push_back(tier1[0]);
   removeUris.push_back(tier2[0]);
-  removeAnnounceUri(attrs, removeUris);
-  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList.size());
+  removeAnnounceUri(&attrs, removeUris);
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs.announceList.size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://host3/announce"),
-                       attrs->announceList[0][0]);
+                       attrs.announceList[0][0]);
 
   removeUris.clear();
   removeUris.push_back("*");
 
-  removeAnnounceUri(attrs, removeUris);
-  CPPUNIT_ASSERT(attrs->announceList.empty());
+  removeAnnounceUri(&attrs, removeUris);
+  CPPUNIT_ASSERT(attrs.announceList.empty());
 }
 
 void BittorrentHelperTest::testAddAnnounceUri()
 {
-  SharedHandle<TorrentAttribute> attrs(new TorrentAttribute());
+  TorrentAttribute attrs;
   std::vector<std::string> addUris;
   addUris.push_back("http://host1/announce");
   addUris.push_back("http://host2/announce");
-  addAnnounceUri(attrs, addUris);
-  CPPUNIT_ASSERT_EQUAL((size_t)2, attrs->announceList.size());
+  addAnnounceUri(&attrs, addUris);
+  CPPUNIT_ASSERT_EQUAL((size_t)2, attrs.announceList.size());
 
-  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[0].size());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs.announceList[0].size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://host1/announce"),
-                       attrs->announceList[0][0]);
+                       attrs.announceList[0][0]);
 
-  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[1].size());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs.announceList[1].size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://host2/announce"),
-                       attrs->announceList[1][0]);
+                       attrs.announceList[1][0]);
 }
 
 void BittorrentHelperTest::testAdjustAnnounceUri()
 {
-  SharedHandle<TorrentAttribute> attrs(new TorrentAttribute());
+  TorrentAttribute attrs;
   std::vector<std::string> tier1;
   tier1.push_back("http://host1/announce");
   std::vector<std::string> tier2;
   tier2.push_back("http://host2/announce");
   tier2.push_back("http://host3/announce");
-  attrs->announceList.push_back(tier1);
-  attrs->announceList.push_back(tier2);
+  attrs.announceList.push_back(tier1);
+  attrs.announceList.push_back(tier2);
 
-  SharedHandle<Option> option(new Option());
+  std::shared_ptr<Option> option(new Option());
   option->put(PREF_BT_TRACKER, "http://host1/announce,http://host4/announce");
   option->put(PREF_BT_EXCLUDE_TRACKER,
               "http://host1/announce,http://host2/announce");
-  adjustAnnounceUri(attrs, option);
+  adjustAnnounceUri(&attrs, option);
 
-  CPPUNIT_ASSERT_EQUAL((size_t)3, attrs->announceList.size());
+  CPPUNIT_ASSERT_EQUAL((size_t)3, attrs.announceList.size());
 
-  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[0].size());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs.announceList[0].size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://host3/announce"),
-                       attrs->announceList[0][0]);
+                       attrs.announceList[0][0]);
 
-  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[1].size());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs.announceList[1].size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://host1/announce"),
-                       attrs->announceList[1][0]);
+                       attrs.announceList[1][0]);
 
-  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs->announceList[2].size());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, attrs.announceList[2].size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://host4/announce"),
-                       attrs->announceList[2][0]);
+                       attrs.announceList[2][0]);
 }
 
 } // namespace bittorrent
