@@ -41,24 +41,24 @@ void BtRegistryTest::testGetDownloadContext()
 {
   BtRegistry btRegistry;
   CPPUNIT_ASSERT(!btRegistry.getDownloadContext(1));
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
-  SharedHandle<BtObject> btObject(new BtObject());
+  auto dctx = std::make_shared<DownloadContext>();
+  auto btObject = make_unique<BtObject>();
   btObject->downloadContext = dctx;
-  btRegistry.put(1, btObject);
+  btRegistry.put(1, std::move(btObject));
   CPPUNIT_ASSERT_EQUAL(dctx.get(), btRegistry.getDownloadContext(1).get());
 }
 
 namespace {
 void addTwoDownloadContext(BtRegistry& btRegistry)
 {
-  SharedHandle<DownloadContext> dctx1(new DownloadContext());
-  SharedHandle<DownloadContext> dctx2(new DownloadContext());
-  SharedHandle<BtObject> btObject1(new BtObject());
+  auto dctx1 = std::make_shared<DownloadContext>();
+  auto dctx2 = std::make_shared<DownloadContext>();
+  auto btObject1 = make_unique<BtObject>();
   btObject1->downloadContext = dctx1;
-  SharedHandle<BtObject> btObject2(new BtObject());
+  auto btObject2 = make_unique<BtObject>();
   btObject2->downloadContext = dctx2;
-  btRegistry.put(1, btObject1);
-  btRegistry.put(2, btObject2);
+  btRegistry.put(1, std::move(btObject1));
+  btRegistry.put(2, std::move(btObject2));
 }
 } // namespace
 
@@ -66,13 +66,16 @@ void BtRegistryTest::testGetDownloadContext_infoHash()
 {
   BtRegistry btRegistry;
   addTwoDownloadContext(btRegistry);
-  SharedHandle<TorrentAttribute> attrs1(new TorrentAttribute());
-  attrs1->infoHash = "hash1";
-  SharedHandle<TorrentAttribute> attrs2(new TorrentAttribute());
-  attrs2->infoHash = "hash2";
-  btRegistry.getDownloadContext(1)->setAttribute(CTX_ATTR_BT, attrs1);
-  btRegistry.getDownloadContext(2)->setAttribute(CTX_ATTR_BT, attrs2);
-
+  {
+    auto attrs1 = make_unique<TorrentAttribute>();
+    attrs1->infoHash = "hash1";
+    auto attrs2 = make_unique<TorrentAttribute>();
+    attrs2->infoHash = "hash2";
+    btRegistry.getDownloadContext(1)->setAttribute(CTX_ATTR_BT,
+                                                   std::move(attrs1));
+    btRegistry.getDownloadContext(2)->setAttribute(CTX_ATTR_BT,
+                                                   std::move(attrs2));
+  }
   CPPUNIT_ASSERT(btRegistry.getDownloadContext("hash1"));
   CPPUNIT_ASSERT(btRegistry.getDownloadContext("hash1").get() ==
                  btRegistry.getDownloadContext(1).get());
@@ -84,7 +87,7 @@ void BtRegistryTest::testGetAllDownloadContext()
   BtRegistry btRegistry;
   addTwoDownloadContext(btRegistry);
 
-  std::vector<SharedHandle<DownloadContext> > result;
+  std::vector<std::shared_ptr<DownloadContext> > result;
   btRegistry.getAllDownloadContext(std::back_inserter(result));
   CPPUNIT_ASSERT_EQUAL((size_t)2, result.size());
 }
