@@ -31,7 +31,6 @@ class BtRequestMessageTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testHandleAbortRequestEvent);
   CPPUNIT_TEST(testHandleAbortRequestEvent_indexNoMatch);
   CPPUNIT_TEST(testHandleAbortRequestEvent_alreadyInvalidated);
-  CPPUNIT_TEST(testHandleAbortRequestEvent_sendingInProgress);
   CPPUNIT_TEST(testToString);
   CPPUNIT_TEST(testValidate);
   CPPUNIT_TEST(testValidate_lengthTooLong);
@@ -49,69 +48,52 @@ public:
   void testHandleAbortRequestEvent();
   void testHandleAbortRequestEvent_indexNoMatch();
   void testHandleAbortRequestEvent_alreadyInvalidated();
-  void testHandleAbortRequestEvent_sendingInProgress();
   void testToString();
   void testValidate();
   void testValidate_lengthTooLong();
 
   class MockPieceStorage2 : public MockPieceStorage {
   public:
-    virtual bool hasPiece(size_t index) {
+    virtual bool hasPiece(size_t index) CXX11_OVERRIDE
+    {
       return index == 1;
     }
   };
 
-  class MockBtMessage2 : public MockBtMessage {
-  public:
-    std::string type;
-    size_t index;
-    uint32_t begin;
-    size_t length;
-  public:
-    MockBtMessage2(std::string type, size_t index, uint32_t begin,
-                   size_t length)
-      :
-      type(type), index(index), begin(begin), length(length) {}
-  };
-
-  typedef SharedHandle<MockBtMessage2> MockBtMessage2Handle;
-
   class MockBtMessageFactory2 : public MockBtMessageFactory {
   public:
-    virtual SharedHandle<BtMessage>
-    createPieceMessage(size_t index, int32_t begin, int32_t length) {
-      SharedHandle<MockBtMessage2> btMsg
-        (new MockBtMessage2("piece", index, begin, length));
-      return btMsg;
+    virtual std::unique_ptr<BtPieceMessage>
+    createPieceMessage(size_t index, int32_t begin, int32_t length)
+      CXX11_OVERRIDE
+    {
+      return make_unique<BtPieceMessage>(index, begin, length);
     }
 
-    virtual SharedHandle<BtMessage>
-    createRejectMessage(size_t index, int32_t begin, int32_t length) {
-      SharedHandle<MockBtMessage2> btMsg
-        (new MockBtMessage2("reject", index, begin, length));
-      return btMsg;
+    virtual std::unique_ptr<BtRejectMessage>
+    createRejectMessage(size_t index, int32_t begin, int32_t length)
+      CXX11_OVERRIDE
+    {
+      return make_unique<BtRejectMessage>(index, begin, length);
     }
   };
 
-  typedef SharedHandle<MockBtMessageFactory2> MockBtMessageFactory2Handle;
-
-  SharedHandle<MockPieceStorage> pieceStorage_;
-  SharedHandle<Peer> peer_;
-  SharedHandle<MockBtMessageDispatcher> dispatcher_;
-  SharedHandle<MockBtMessageFactory> messageFactory_;
-  SharedHandle<BtRequestMessage> msg;
+  std::unique_ptr<MockPieceStorage> pieceStorage_;
+  std::shared_ptr<Peer> peer_;
+  std::unique_ptr<MockBtMessageDispatcher> dispatcher_;
+  std::unique_ptr<MockBtMessageFactory> messageFactory_;
+  std::unique_ptr<BtRequestMessage> msg;
 
   void setUp() {
-    pieceStorage_.reset(new MockPieceStorage2());
+    pieceStorage_ = make_unique<MockPieceStorage2>();
 
-    peer_.reset(new Peer("host", 6969));
+    peer_ = std::make_shared<Peer>("host", 6969);
     peer_->allocateSessionResource(16*1024, 256*1024);
 
-    dispatcher_.reset(new MockBtMessageDispatcher());
+    dispatcher_ = make_unique<MockBtMessageDispatcher>();
 
-    messageFactory_.reset(new MockBtMessageFactory2());
+    messageFactory_ = make_unique<MockBtMessageFactory2>();
 
-    msg.reset(new BtRequestMessage());
+    msg = make_unique<BtRequestMessage>();
     msg->setPeer(peer_);
     msg->setIndex(1);
     msg->setBegin(16);
@@ -119,7 +101,7 @@ public:
     msg->setBlockIndex(2);
     msg->setBtMessageDispatcher(dispatcher_.get());
     msg->setBtMessageFactory(messageFactory_.get());
-    msg->setPieceStorage(pieceStorage_);
+    msg->setPieceStorage(pieceStorage_.get());
   }
 };
 
@@ -132,7 +114,7 @@ void BtRequestMessageTest::testCreate() {
   bittorrent::setIntParam(&msg[5], 12345);
   bittorrent::setIntParam(&msg[9], 256);
   bittorrent::setIntParam(&msg[13], 1024);
-  SharedHandle<BtRequestMessage> pm(BtRequestMessage::create(&msg[4], 13));
+  auto pm = BtRequestMessage::create(&msg[4], 13);
   CPPUNIT_ASSERT_EQUAL((uint8_t)6, pm->getId());
   CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
   CPPUNIT_ASSERT_EQUAL(256, pm->getBegin());
@@ -176,12 +158,13 @@ void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmNotChoking() {
   msg->doReceivedAction();
 
   CPPUNIT_ASSERT_EQUAL((size_t)1, dispatcher_->messageQueue.size());
-  SharedHandle<MockBtMessage2> pieceMsg =
-    dynamic_pointer_cast<MockBtMessage2>(dispatcher_->messageQueue.front());
-  CPPUNIT_ASSERT_EQUAL(std::string("piece"), pieceMsg->type);
-  CPPUNIT_ASSERT_EQUAL((size_t)1, pieceMsg->index);
-  CPPUNIT_ASSERT_EQUAL((uint32_t)16, pieceMsg->begin);
-  CPPUNIT_ASSERT_EQUAL((size_t)32, pieceMsg->length);
+  CPPUNIT_ASSERT(BtPieceMessage::ID ==
+                 dispatcher_->messageQueue.front()->getId());
+  auto pieceMsg = static_cast<const BtPieceMessage*>
+    (dispatcher_->messageQueue.front().get());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, pieceMsg->getIndex());
+  CPPUNIT_ASSERT_EQUAL((int32_t)16, pieceMsg->getBegin());
+  CPPUNIT_ASSERT_EQUAL((int32_t)32, pieceMsg->getBlockLength());
 }
 
 void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmChokingAndFastExtensionEnabled() {
@@ -190,12 +173,13 @@ void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmChokingAndFastExten
   msg->doReceivedAction();
 
   CPPUNIT_ASSERT_EQUAL((size_t)1, dispatcher_->messageQueue.size());
-  SharedHandle<MockBtMessage2> pieceMsg =
-    dynamic_pointer_cast<MockBtMessage2>(dispatcher_->messageQueue.front());
-  CPPUNIT_ASSERT_EQUAL(std::string("reject"), pieceMsg->type);
-  CPPUNIT_ASSERT_EQUAL((size_t)1, pieceMsg->index);
-  CPPUNIT_ASSERT_EQUAL((uint32_t)16, pieceMsg->begin);
-  CPPUNIT_ASSERT_EQUAL((size_t)32, pieceMsg->length);
+  CPPUNIT_ASSERT(BtRejectMessage::ID ==
+                 dispatcher_->messageQueue.front()->getId());
+  auto rejectMsg = static_cast<const BtRejectMessage*>
+    (dispatcher_->messageQueue.front().get());
+  CPPUNIT_ASSERT_EQUAL((size_t)1, rejectMsg->getIndex());
+  CPPUNIT_ASSERT_EQUAL((int32_t)16, rejectMsg->getBegin());
+  CPPUNIT_ASSERT_EQUAL((int32_t)32, rejectMsg->getLength());
 }
 
 void BtRequestMessageTest::testDoReceivedAction_hasPieceAndAmChokingAndFastExtensionDisabled() {
@@ -212,12 +196,13 @@ void BtRequestMessageTest::testDoReceivedAction_doesntHavePieceAndFastExtensionE
   msg->doReceivedAction();
 
   CPPUNIT_ASSERT_EQUAL((size_t)1, dispatcher_->messageQueue.size());
-  SharedHandle<MockBtMessage2> pieceMsg =
-    dynamic_pointer_cast<MockBtMessage2>(dispatcher_->messageQueue.front());
-  CPPUNIT_ASSERT_EQUAL(std::string("reject"), pieceMsg->type);
-  CPPUNIT_ASSERT_EQUAL((size_t)2, pieceMsg->index);
-  CPPUNIT_ASSERT_EQUAL((uint32_t)16, pieceMsg->begin);
-  CPPUNIT_ASSERT_EQUAL((size_t)32, pieceMsg->length);
+  CPPUNIT_ASSERT(BtRejectMessage::ID ==
+                 dispatcher_->messageQueue.front()->getId());
+  auto rejectMsg = static_cast<const BtRejectMessage*>
+    (dispatcher_->messageQueue.front().get());
+  CPPUNIT_ASSERT_EQUAL((size_t)2, rejectMsg->getIndex());
+  CPPUNIT_ASSERT_EQUAL((int32_t)16, rejectMsg->getBegin());
+  CPPUNIT_ASSERT_EQUAL((int32_t)32, rejectMsg->getLength());
 }
 
 void BtRequestMessageTest::testDoReceivedAction_doesntHavePieceAndFastExtensionDisabled() {
@@ -229,38 +214,27 @@ void BtRequestMessageTest::testDoReceivedAction_doesntHavePieceAndFastExtensionD
 }
 
 void BtRequestMessageTest::testHandleAbortRequestEvent() {
-  SharedHandle<Piece> piece(new Piece(1, 16*1024));
+  auto piece = std::make_shared<Piece>(1, 16*1024);
   CPPUNIT_ASSERT(!msg->isInvalidate());
   msg->onAbortOutstandingRequestEvent(BtAbortOutstandingRequestEvent(piece));
   CPPUNIT_ASSERT(msg->isInvalidate());
 }
 
 void BtRequestMessageTest::testHandleAbortRequestEvent_indexNoMatch() {
-  SharedHandle<Piece> piece(new Piece(2, 16*1024));
+  auto piece = std::make_shared<Piece>(2, 16*1024);
   CPPUNIT_ASSERT(!msg->isInvalidate());
-  CPPUNIT_ASSERT(!msg->isSendingInProgress());
   msg->onAbortOutstandingRequestEvent(BtAbortOutstandingRequestEvent(piece));
   CPPUNIT_ASSERT(!msg->isInvalidate());
 }
 
 void BtRequestMessageTest::testHandleAbortRequestEvent_alreadyInvalidated() {
-  SharedHandle<Piece> piece(new Piece(1, 16*1024));
+  auto piece = std::make_shared<Piece>(1, 16*1024);
   msg->setInvalidate(true);
   CPPUNIT_ASSERT(msg->isInvalidate());
-  CPPUNIT_ASSERT(!msg->isSendingInProgress());
   msg->onAbortOutstandingRequestEvent(BtAbortOutstandingRequestEvent(piece));
   CPPUNIT_ASSERT(msg->isInvalidate());
 }
 
-void BtRequestMessageTest::testHandleAbortRequestEvent_sendingInProgress() {
-  SharedHandle<Piece> piece(new Piece(1, 16*1024));
-  msg->setSendingInProgress(true);
-  CPPUNIT_ASSERT(!msg->isInvalidate());
-  CPPUNIT_ASSERT(msg->isSendingInProgress());
-  msg->onAbortOutstandingRequestEvent(BtAbortOutstandingRequestEvent(piece));
-  CPPUNIT_ASSERT(!msg->isInvalidate());
-}
-
 void BtRequestMessageTest::testToString() {
   CPPUNIT_ASSERT_EQUAL(std::string("request index=1, begin=16, length=32"),
                        msg->toString());
@@ -269,16 +243,14 @@ void BtRequestMessageTest::testToString() {
 void BtRequestMessageTest::testValidate() {
   BtRequestMessage msg(0, 0, 16*1024);
   msg.setBtMessageValidator
-    (SharedHandle<BtMessageValidator>
-     (new RangeBtMessageValidator(&msg, 1024, 256*1024)));
+    (make_unique<RangeBtMessageValidator>(&msg, 1024, 256*1024));
   msg.validate();
 }
 
 void BtRequestMessageTest::testValidate_lengthTooLong() {
   BtRequestMessage msg(0, 0, 16*1024+1);
   msg.setBtMessageValidator
-    (SharedHandle<BtMessageValidator>
-     (new RangeBtMessageValidator(&msg, 1024, 256*1024)));
+    (make_unique<RangeBtMessageValidator>(&msg, 1024, 256*1024));
   try {
     msg.validate();
     CPPUNIT_FAIL("exception must be thrown.");
