@@ -41,20 +41,20 @@ class DefaultPieceStorageTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testGetNextUsedIndex);
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<DownloadContext> dctx_;
-  SharedHandle<Peer> peer;
-  SharedHandle<Option> option_;
-  SharedHandle<PieceSelector> pieceSelector_;
+  std::shared_ptr<DownloadContext> dctx_;
+  std::shared_ptr<Peer> peer;
+  std::shared_ptr<Option> option_;
+  std::unique_ptr<PieceSelector> pieceSelector_;
 public:
   void setUp() {
-    option_.reset(new Option());
+    option_ = std::make_shared<Option>();
     option_->put(PREF_DIR, ".");
-    dctx_.reset(new DownloadContext());
+    dctx_ = std::make_shared<DownloadContext>();
     bittorrent::load(A2_TEST_DIR"/test.torrent", dctx_, option_);
-    peer.reset(new Peer("192.168.0.1", 6889));
+    peer = std::make_shared<Peer>("192.168.0.1", 6889);
     peer->allocateSessionResource(dctx_->getPieceLength(),
                                   dctx_->getTotalLength());
-    pieceSelector_.reset(new InorderPieceSelector());
+    pieceSelector_ = make_unique<InorderPieceSelector>();
   }
 
   void testGetTotalLength();
@@ -87,10 +87,10 @@ void DefaultPieceStorageTest::testGetTotalLength() {
 
 void DefaultPieceStorageTest::testGetMissingPiece() {
   DefaultPieceStorage pss(dctx_, option_.get());
-  pss.setPieceSelector(pieceSelector_);
+  pss.setPieceSelector(std::move(pieceSelector_));
   peer->setAllBitfield();
 
-  SharedHandle<Piece> piece = pss.getMissingPiece(peer, 1);
+  auto piece = pss.getMissingPiece(peer, 1);
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=0, length=128"),
                        piece->toString());
   CPPUNIT_ASSERT(piece->usedBy(1));
@@ -106,9 +106,9 @@ void DefaultPieceStorageTest::testGetMissingPiece() {
 
 void DefaultPieceStorageTest::testGetMissingPiece_many() {
   DefaultPieceStorage pss(dctx_, option_.get());
-  pss.setPieceSelector(pieceSelector_);
+  pss.setPieceSelector(std::move(pieceSelector_));
   peer->setAllBitfield();
-  std::vector<SharedHandle<Piece> > pieces;
+  std::vector<std::shared_ptr<Piece>> pieces;
   pss.getMissingPiece(pieces, 2, peer, 1);
   CPPUNIT_ASSERT_EQUAL((size_t)2, pieces.size());
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=0, length=128"),
@@ -126,7 +126,7 @@ void DefaultPieceStorageTest::testGetMissingPiece_many() {
 void DefaultPieceStorageTest::testGetMissingPiece_excludedIndexes()
 {
   DefaultPieceStorage pss(dctx_, option_.get());
-  pss.setPieceSelector(pieceSelector_);
+  pss.setPieceSelector(std::move(pieceSelector_));
   pss.setEndGamePieceNum(0);
 
   peer->setAllBitfield();
@@ -134,7 +134,7 @@ void DefaultPieceStorageTest::testGetMissingPiece_excludedIndexes()
   std::vector<size_t> excludedIndexes;
   excludedIndexes.push_back(1);
 
-  SharedHandle<Piece> piece = pss.getMissingPiece(peer, excludedIndexes, 1);
+  auto piece = pss.getMissingPiece(peer, excludedIndexes, 1);
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=0, length=128"),
                        piece->toString());
 
@@ -148,11 +148,11 @@ void DefaultPieceStorageTest::testGetMissingPiece_excludedIndexes()
 
 void DefaultPieceStorageTest::testGetMissingPiece_manyWithExcludedIndexes() {
   DefaultPieceStorage pss(dctx_, option_.get());
-  pss.setPieceSelector(pieceSelector_);
+  pss.setPieceSelector(std::move(pieceSelector_));
   peer->setAllBitfield();
   std::vector<size_t> excludedIndexes;
   excludedIndexes.push_back(1);
-  std::vector<SharedHandle<Piece> > pieces;
+  std::vector<std::shared_ptr<Piece>> pieces;
   pss.getMissingPiece(pieces, 2, peer, excludedIndexes, 1);
   CPPUNIT_ASSERT_EQUAL((size_t)2, pieces.size());
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=0, length=128"),
@@ -166,14 +166,14 @@ void DefaultPieceStorageTest::testGetMissingPiece_manyWithExcludedIndexes() {
 
 void DefaultPieceStorageTest::testGetMissingFastPiece() {
   DefaultPieceStorage pss(dctx_, option_.get());
-  pss.setPieceSelector(pieceSelector_);
+  pss.setPieceSelector(std::move(pieceSelector_));
   pss.setEndGamePieceNum(0);
 
   peer->setAllBitfield();
   peer->setFastExtensionEnabled(true);
   peer->addPeerAllowedIndex(2);
 
-  SharedHandle<Piece> piece = pss.getMissingFastPiece(peer, 1);
+  auto piece = pss.getMissingFastPiece(peer, 1);
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=2, length=128"),
                        piece->toString());
 
@@ -183,7 +183,7 @@ void DefaultPieceStorageTest::testGetMissingFastPiece() {
 void DefaultPieceStorageTest::testGetMissingFastPiece_excludedIndexes()
 {
   DefaultPieceStorage pss(dctx_, option_.get());
-  pss.setPieceSelector(pieceSelector_);
+  pss.setPieceSelector(std::move(pieceSelector_));
   pss.setEndGamePieceNum(0);
 
   peer->setAllBitfield();
@@ -194,7 +194,7 @@ void DefaultPieceStorageTest::testGetMissingFastPiece_excludedIndexes()
   std::vector<size_t> excludedIndexes;
   excludedIndexes.push_back(2);
 
-  SharedHandle<Piece> piece = pss.getMissingFastPiece(peer, excludedIndexes, 1);
+  auto piece = pss.getMissingFastPiece(peer, excludedIndexes, 1);
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=1, length=128"),
                        piece->toString());
 
@@ -213,12 +213,12 @@ void DefaultPieceStorageTest::testHasMissingPiece() {
 
 void DefaultPieceStorageTest::testCompletePiece() {
   DefaultPieceStorage pss(dctx_, option_.get());
-  pss.setPieceSelector(pieceSelector_);
+  pss.setPieceSelector(std::move(pieceSelector_));
   pss.setEndGamePieceNum(0);
 
   peer->setAllBitfield();
 
-  SharedHandle<Piece> piece = pss.getMissingPiece(peer, 1);
+  auto piece = pss.getMissingPiece(peer, 1);
   CPPUNIT_ASSERT_EQUAL(std::string("piece: index=0, length=128"),
                        piece->toString());
 
@@ -228,7 +228,7 @@ void DefaultPieceStorageTest::testCompletePiece() {
 
   CPPUNIT_ASSERT_EQUAL((int64_t)128LL, pss.getCompletedLength());
 
-  SharedHandle<Piece> incompletePiece = pss.getMissingPiece(peer, 1);
+  auto incompletePiece = pss.getMissingPiece(peer, 1);
   incompletePiece->completeBlock(0);
   CPPUNIT_ASSERT_EQUAL((int64_t)256LL, pss.getCompletedLength());
 }
@@ -236,7 +236,7 @@ void DefaultPieceStorageTest::testCompletePiece() {
 void DefaultPieceStorageTest::testGetPiece() {
   DefaultPieceStorage pss(dctx_, option_.get());
 
-  SharedHandle<Piece> pieceGot = pss.getPiece(0);
+  auto pieceGot = pss.getPiece(0);
   CPPUNIT_ASSERT_EQUAL((size_t)0, pieceGot->getIndex());
   CPPUNIT_ASSERT_EQUAL(128, pieceGot->getLength());
   CPPUNIT_ASSERT_EQUAL(false, pieceGot->pieceComplete());
@@ -244,10 +244,10 @@ void DefaultPieceStorageTest::testGetPiece() {
 
 void DefaultPieceStorageTest::testGetPieceInUsedPieces() {
   DefaultPieceStorage pss(dctx_, option_.get());
-  SharedHandle<Piece> piece = SharedHandle<Piece>(new Piece(0, 128));
+  auto piece = std::make_shared<Piece>(0, 128);
   piece->completeBlock(0);
   pss.addUsedPiece(piece);
-  SharedHandle<Piece> pieceGot = pss.getPiece(0);
+  auto  pieceGot = pss.getPiece(0);
   CPPUNIT_ASSERT_EQUAL((size_t)0, pieceGot->getIndex());
   CPPUNIT_ASSERT_EQUAL(128, pieceGot->getLength());
   CPPUNIT_ASSERT_EQUAL((size_t)1, pieceGot->countCompleteBlock());
@@ -255,9 +255,9 @@ void DefaultPieceStorageTest::testGetPieceInUsedPieces() {
 
 void DefaultPieceStorageTest::testGetPieceCompletedPiece() {
   DefaultPieceStorage pss(dctx_, option_.get());
-  SharedHandle<Piece> piece = SharedHandle<Piece>(new Piece(0, 128));
+  auto piece = std::make_shared<Piece>(0, 128);
   pss.completePiece(piece);
-  SharedHandle<Piece> pieceGot = pss.getPiece(0);
+  auto pieceGot = pss.getPiece(0);
   CPPUNIT_ASSERT_EQUAL((size_t)0, pieceGot->getIndex());
   CPPUNIT_ASSERT_EQUAL(128, pieceGot->getLength());
   CPPUNIT_ASSERT_EQUAL(true, pieceGot->pieceComplete());
@@ -269,19 +269,20 @@ void DefaultPieceStorageTest::testCancelPiece()
   int64_t totalLength = 32*pieceLength; // <-- make the number of piece greater than END_GAME_PIECE_NUM
   std::deque<std::string> uris1;
   uris1.push_back("http://localhost/src/file1.txt");
-  SharedHandle<FileEntry> file1(new FileEntry("src/file1.txt", totalLength, 0 /*, uris1*/));
+  auto file1 = std::make_shared<FileEntry>("src/file1.txt", totalLength,
+                                           0 /*, uris1*/);
 
-  SharedHandle<DownloadContext> dctx
-    (new DownloadContext(pieceLength, totalLength, "src/file1.txt"));
+  auto dctx = std::make_shared<DownloadContext>(pieceLength, totalLength,
+                                                "src/file1.txt");
 
-  SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, option_.get()));
+  DefaultPieceStorage ps{dctx, option_.get()};
 
-  SharedHandle<Piece> p = ps->getMissingPiece(0, 1);
+  auto p = ps.getMissingPiece(0, 1);
   p->completeBlock(0);
 
-  ps->cancelPiece(p, 1);
+  ps.cancelPiece(p, 1);
 
-  SharedHandle<Piece> p2 = ps->getMissingPiece(0, 2);
+  auto p2 = ps.getMissingPiece(0, 2);
 
   CPPUNIT_ASSERT(p2->hasBlock(0));
   CPPUNIT_ASSERT(p2->usedBy(2));
@@ -292,8 +293,7 @@ void DefaultPieceStorageTest::testMarkPiecesDone()
 {
   size_t pieceLength = 256*1024;
   int64_t totalLength = 4*1024*1024;
-  SharedHandle<DownloadContext> dctx
-    (new DownloadContext(pieceLength, totalLength));
+  auto dctx =std::make_shared<DownloadContext>(pieceLength, totalLength);
 
   DefaultPieceStorage ps(dctx, option_.get());
 
@@ -305,7 +305,8 @@ void DefaultPieceStorageTest::testMarkPiecesDone()
   for(size_t i = 10; i < (totalLength+pieceLength-1)/pieceLength; ++i) {
     CPPUNIT_ASSERT(!ps.hasPiece(i));
   }
-  CPPUNIT_ASSERT_EQUAL((int64_t)pieceLength*10+16*1024*2, ps.getCompletedLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)pieceLength*10+16*1024*2,
+                       ps.getCompletedLength());
 
   ps.markPiecesDone(totalLength);
 
@@ -319,8 +320,7 @@ void DefaultPieceStorageTest::testMarkPiecesDone()
 
 void DefaultPieceStorageTest::testGetCompletedLength()
 {
-  SharedHandle<DownloadContext> dctx
-    (new DownloadContext(1024*1024, 256*1024*1024));
+  auto dctx = std::make_shared<DownloadContext>(1024*1024, 256*1024*1024);
 
   DefaultPieceStorage ps(dctx, option_.get());
 
@@ -329,9 +329,9 @@ void DefaultPieceStorageTest::testGetCompletedLength()
   ps.markPiecesDone(250*1024*1024);
   CPPUNIT_ASSERT_EQUAL((int64_t)250*1024*1024, ps.getCompletedLength());
 
-  std::vector<SharedHandle<Piece> > inFlightPieces;
+  std::vector<std::shared_ptr<Piece>> inFlightPieces;
   for(int i = 0; i < 2; ++i) {
-    SharedHandle<Piece> p(new Piece(250+i, 1024*1024));
+    auto p = std::make_shared<Piece>(250+i, 1024*1024);
     for(int j = 0; j < 32; ++j) {
       p->completeBlock(j);
     }
@@ -350,27 +350,27 @@ void DefaultPieceStorageTest::testGetCompletedLength()
 void DefaultPieceStorageTest::testGetFilteredCompletedLength()
 {
   const size_t pieceLength = 1024*1024;
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
+  auto dctx = std::make_shared<DownloadContext>();
   dctx->setPieceLength(pieceLength);
-  SharedHandle<FileEntry> files[] = {
-    SharedHandle<FileEntry>(new FileEntry("foo", 2*pieceLength, 0)),
-    SharedHandle<FileEntry>(new FileEntry("bar", 4*pieceLength, 2*pieceLength))
+  auto files = std::vector<std::shared_ptr<FileEntry>>{
+    std::make_shared<FileEntry>("foo", 2*pieceLength, 0),
+    std::make_shared<FileEntry>("bar", 4*pieceLength, 2*pieceLength)
   };
   files[1]->setRequested(false);
-  dctx->setFileEntries(&files[0], &files[2]);
+  dctx->setFileEntries(std::begin(files), std::end(files));
 
   DefaultPieceStorage ps(dctx, option_.get());
-  std::vector<SharedHandle<Piece> > inflightPieces(2);
-  inflightPieces[0] = SharedHandle<Piece>(new Piece(1, pieceLength));
+  std::vector<std::shared_ptr<Piece>> inflightPieces(2);
+  inflightPieces[0] = std::make_shared<Piece>(1, pieceLength);
   inflightPieces[0]->completeBlock(0);
-  inflightPieces[1] = SharedHandle<Piece>(new Piece(2, pieceLength));
+  inflightPieces[1] = std::make_shared<Piece>(2, pieceLength);
   inflightPieces[1]->completeBlock(1);
   inflightPieces[1]->completeBlock(2);
 
   ps.addInFlightPiece(inflightPieces);
   ps.setupFileFilter();
 
-  SharedHandle<Piece> piece = ps.getMissingPiece(0, 1);
+  auto piece = ps.getMissingPiece(0, 1);
   ps.completePiece(piece);
 
   CPPUNIT_ASSERT_EQUAL((int64_t)pieceLength+16*1024,
@@ -381,7 +381,7 @@ void DefaultPieceStorageTest::testGetNextUsedIndex()
 {
   DefaultPieceStorage pss(dctx_, option_.get());
   CPPUNIT_ASSERT_EQUAL((size_t)3, pss.getNextUsedIndex(0));
-  SharedHandle<Piece> piece = pss.getMissingPiece(2, 1);
+  auto piece = pss.getMissingPiece(2, 1);
   CPPUNIT_ASSERT_EQUAL((size_t)2, pss.getNextUsedIndex(0));
   pss.completePiece(piece);
   CPPUNIT_ASSERT_EQUAL((size_t)2, pss.getNextUsedIndex(0));
