@@ -35,13 +35,13 @@ class FtpConnectionTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testReceiveEpsvResponse);
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<SocketCore> serverSocket_;
+  std::shared_ptr<SocketCore> serverSocket_;
   uint16_t listenPort_;
-  SharedHandle<SocketCore> clientSocket_;
-  SharedHandle<FtpConnection> ftp_;
-  SharedHandle<Option> option_;
-  SharedHandle<AuthConfigFactory> authConfigFactory_;
-  SharedHandle<Request> req_;
+  std::shared_ptr<SocketCore> clientSocket_;
+  std::shared_ptr<FtpConnection> ftp_;
+  std::shared_ptr<Option> option_;
+  std::shared_ptr<AuthConfigFactory> authConfigFactory_;
+  std::shared_ptr<Request> req_;
 public:
   void setUp()
   {
@@ -49,9 +49,10 @@ public:
     authConfigFactory_.reset(new AuthConfigFactory());
 
     //_ftpServerSocket.reset(new SocketCore());
-    SharedHandle<SocketCore> listenSocket(new SocketCore());
+    std::shared_ptr<SocketCore> listenSocket(new SocketCore());
     listenSocket->bind(0);
     listenSocket->beginListen();
+    listenSocket->setBlockingMode();
     std::pair<std::string, uint16_t> addrinfo;
     listenSocket->getAddrInfo(addrinfo);
     listenPort_ = addrinfo.second;
@@ -64,7 +65,8 @@ public:
 
     while(!clientSocket_->isWritable(0));
 
-    serverSocket_.reset(listenSocket->acceptConnection());
+    serverSocket_ = listenSocket->acceptConnection();
+    serverSocket_->setBlockingMode();
     ftp_.reset(new FtpConnection(1, clientSocket_, req_,
                                  authConfigFactory_->createAuthConfig
                                  (req_, option_.get()),
@@ -92,7 +94,7 @@ public:
 CPPUNIT_TEST_SUITE_REGISTRATION(FtpConnectionTest);
 
 namespace {
-void waitRead(const SharedHandle<SocketCore>& socket)
+void waitRead(const std::shared_ptr<SocketCore>& socket)
 {
   while(!socket->isReadable(0));
 }
