@@ -4,6 +4,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
+#include "TestUtil.h"
 #include "prefs.h"
 #include "PiecedSegment.h"
 #include "Piece.h"
@@ -106,10 +107,10 @@ void HttpResponseTest::testGetContentLength_contentLength()
 {
   HttpResponse httpResponse;
 
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
+  auto httpHeader = make_unique<HttpHeader>();
   httpHeader->put(HttpHeader::CONTENT_LENGTH, "4294967296");
 
-  httpResponse.setHttpHeader(httpHeader);
+  httpResponse.setHttpHeader(std::move(httpHeader));
 
   CPPUNIT_ASSERT_EQUAL((int64_t)4294967296LL, httpResponse.getContentLength());
 }
@@ -118,15 +119,14 @@ void HttpResponseTest::testGetEntityLength()
 {
   HttpResponse httpResponse;
 
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
+  auto httpHeader = make_unique<HttpHeader>();
   httpHeader->put(HttpHeader::CONTENT_LENGTH, "4294967296");
 
-  httpResponse.setHttpHeader(httpHeader);
-
+  httpResponse.setHttpHeader(std::move(httpHeader));
   CPPUNIT_ASSERT_EQUAL((int64_t)4294967296LL, httpResponse.getEntityLength());
 
-  httpHeader->put(HttpHeader::CONTENT_RANGE, "bytes 1-4294967296/4294967297");
-
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_RANGE,
+                                    "bytes 1-4294967296/4294967297");
   CPPUNIT_ASSERT_EQUAL((int64_t)4294967297LL, httpResponse.getEntityLength());
 
 }
@@ -134,10 +134,10 @@ void HttpResponseTest::testGetEntityLength()
 void HttpResponseTest::testGetContentType()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
+  auto httpHeader = make_unique<HttpHeader>();
   httpHeader->put(HttpHeader::CONTENT_TYPE,
                   "application/metalink+xml; charset=UTF-8");
-  httpResponse.setHttpHeader(httpHeader);
+  httpResponse.setHttpHeader(std::move(httpHeader));
   // See paramter is ignored.
   CPPUNIT_ASSERT_EQUAL(std::string("application/metalink+xml"),
                        httpResponse.getContentType());
@@ -146,14 +146,13 @@ void HttpResponseTest::testGetContentType()
 void HttpResponseTest::testDeterminFilename_without_ContentDisposition()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  SharedHandle<Request> request(new Request());
+  auto httpRequest = make_unique<HttpRequest>();
+  auto request = std::make_shared<Request>();
   request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
 
-  httpResponse.setHttpHeader(httpHeader);
-  httpResponse.setHttpRequest(httpRequest);
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+  httpResponse.setHttpRequest(std::move(httpRequest));
 
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-1.0.0.tar.bz2"),
                        httpResponse.determinFilename());
@@ -163,15 +162,15 @@ void HttpResponseTest::testDeterminFilename_with_ContentDisposition_zero_length
 ()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
+  auto httpHeader = make_unique<HttpHeader>();
   httpHeader->put(HttpHeader::CONTENT_DISPOSITION, "attachment; filename=\"\"");
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  SharedHandle<Request> request(new Request());
+  auto httpRequest = make_unique<HttpRequest>();
+  auto request = std::make_shared<Request>();
   request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
 
-  httpResponse.setHttpHeader(httpHeader);
-  httpResponse.setHttpRequest(httpRequest);
+  httpResponse.setHttpHeader(std::move(httpHeader));
+  httpResponse.setHttpRequest(std::move(httpRequest));
 
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-1.0.0.tar.bz2"),
                        httpResponse.determinFilename());
@@ -180,16 +179,16 @@ void HttpResponseTest::testDeterminFilename_with_ContentDisposition_zero_length
 void HttpResponseTest::testDeterminFilename_with_ContentDisposition()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
+  auto httpHeader = make_unique<HttpHeader>();
   httpHeader->put(HttpHeader::CONTENT_DISPOSITION,
                   "attachment; filename=\"aria2-current.tar.bz2\"");
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  SharedHandle<Request> request(new Request());
+  auto httpRequest = make_unique<HttpRequest>();
+  auto request = std::make_shared<Request>();
   request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
 
-  httpResponse.setHttpHeader(httpHeader);
-  httpResponse.setHttpRequest(httpRequest);
+  httpResponse.setHttpHeader(std::move(httpHeader));
+  httpResponse.setHttpRequest(std::move(httpRequest));
 
   CPPUNIT_ASSERT_EQUAL(std::string("aria2-current.tar.bz2"),
                        httpResponse.determinFilename());
@@ -198,9 +197,8 @@ void HttpResponseTest::testDeterminFilename_with_ContentDisposition()
 void HttpResponseTest::testGetRedirectURI_without_Location()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
 
-  httpResponse.setHttpHeader(httpHeader);
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
 
   CPPUNIT_ASSERT_EQUAL(std::string(""),
                        httpResponse.getRedirectURI());
@@ -209,9 +207,10 @@ void HttpResponseTest::testGetRedirectURI_without_Location()
 void HttpResponseTest::testGetRedirectURI_with_Location()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpHeader->put(HttpHeader::LOCATION, "http://localhost/download/aria2-1.0.0.tar.bz2");
-  httpResponse.setHttpHeader(httpHeader);
+  auto httpHeader = make_unique<HttpHeader>();
+  httpHeader->put(HttpHeader::LOCATION,
+                  "http://localhost/download/aria2-1.0.0.tar.bz2");
+  httpResponse.setHttpHeader(std::move(httpHeader));
 
   CPPUNIT_ASSERT_EQUAL
     (std::string("http://localhost/download/aria2-1.0.0.tar.bz2"),
@@ -221,45 +220,37 @@ void HttpResponseTest::testGetRedirectURI_with_Location()
 void HttpResponseTest::testIsRedirect()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
+  auto httpHeader = make_unique<HttpHeader>();
   httpHeader->setStatusCode(200);
   httpHeader->put(HttpHeader::LOCATION,
                   "http://localhost/download/aria2-1.0.0.tar.bz2");
 
-  httpResponse.setHttpHeader(httpHeader);
-
+  httpResponse.setHttpHeader(std::move(httpHeader));
   CPPUNIT_ASSERT(!httpResponse.isRedirect());
 
-  httpHeader->setStatusCode(301);
-
+  httpResponse.getHttpHeader()->setStatusCode(301);
   CPPUNIT_ASSERT(httpResponse.isRedirect());
 }
 
 void HttpResponseTest::testIsTransferEncodingSpecified()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-
-  httpResponse.setHttpHeader(httpHeader);
 
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
   CPPUNIT_ASSERT(!httpResponse.isTransferEncodingSpecified());
 
-  httpHeader->put(HttpHeader::TRANSFER_ENCODING, "chunked");
-
+  httpResponse.getHttpHeader()->put(HttpHeader::TRANSFER_ENCODING, "chunked");
   CPPUNIT_ASSERT(httpResponse.isTransferEncodingSpecified());
 }
 
 void HttpResponseTest::testGetTransferEncoding()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-
-  httpResponse.setHttpHeader(httpHeader);
 
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
   CPPUNIT_ASSERT_EQUAL(std::string(""), httpResponse.getTransferEncoding());
 
-  httpHeader->put(HttpHeader::TRANSFER_ENCODING, "chunked");
-
+  httpResponse.getHttpHeader()->put(HttpHeader::TRANSFER_ENCODING, "chunked");
   CPPUNIT_ASSERT_EQUAL(std::string("chunked"),
                        httpResponse.getTransferEncoding());
 }
@@ -267,79 +258,66 @@ void HttpResponseTest::testGetTransferEncoding()
 void HttpResponseTest::testGetTransferEncodingStreamFilter()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-
-  httpResponse.setHttpHeader(httpHeader);
 
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
   CPPUNIT_ASSERT(!httpResponse.getTransferEncodingStreamFilter());
 
-  httpHeader->put(HttpHeader::TRANSFER_ENCODING, "chunked");
-
+  httpResponse.getHttpHeader()->put(HttpHeader::TRANSFER_ENCODING, "chunked");
   CPPUNIT_ASSERT(httpResponse.getTransferEncodingStreamFilter());
 }
 
 void HttpResponseTest::testIsContentEncodingSpecified()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-
-  httpResponse.setHttpHeader(httpHeader);
 
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
   CPPUNIT_ASSERT(!httpResponse.isContentEncodingSpecified());
 
-  httpHeader->put(HttpHeader::CONTENT_ENCODING, "gzip");
-
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_ENCODING, "gzip");
   CPPUNIT_ASSERT(httpResponse.isContentEncodingSpecified());
 }
 
 void HttpResponseTest::testGetContentEncoding()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-
-  httpResponse.setHttpHeader(httpHeader);
 
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
   CPPUNIT_ASSERT_EQUAL(A2STR::NIL, httpResponse.getContentEncoding());
 
-  httpHeader->put(HttpHeader::CONTENT_ENCODING, "gzip");
-
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_ENCODING, "gzip");
   CPPUNIT_ASSERT_EQUAL(std::string("gzip"), httpResponse.getContentEncoding());
 }
 
 void HttpResponseTest::testGetContentEncodingStreamFilter()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-
-  httpResponse.setHttpHeader(httpHeader);
 
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
   CPPUNIT_ASSERT(!httpResponse.getContentEncodingStreamFilter());
 
 #ifdef HAVE_ZLIB
-  httpHeader->put(HttpHeader::CONTENT_ENCODING, "gzip");
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_ENCODING, "gzip");
   {
-    SharedHandle<StreamFilter> filter =
+    std::shared_ptr<StreamFilter> filter =
       httpResponse.getContentEncodingStreamFilter();
     CPPUNIT_ASSERT(filter);
     CPPUNIT_ASSERT_EQUAL(std::string("GZipDecodingStreamFilter"),
                          filter->getName());
   }
-  httpHeader.reset(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
-  httpHeader->put(HttpHeader::CONTENT_ENCODING, "deflate");
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_ENCODING, "deflate");
   {
-    SharedHandle<StreamFilter> filter =
+    std::shared_ptr<StreamFilter> filter =
       httpResponse.getContentEncodingStreamFilter();
     CPPUNIT_ASSERT(filter);
     CPPUNIT_ASSERT_EQUAL(std::string("GZipDecodingStreamFilter"),
                          filter->getName());
   }
 #endif // HAVE_ZLIB
-  httpHeader.reset(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
-  httpHeader->put(HttpHeader::CONTENT_ENCODING, "bzip2");
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_ENCODING, "bzip2");
   {
-    SharedHandle<StreamFilter> filter =
+    std::shared_ptr<StreamFilter> filter =
       httpResponse.getContentEncodingStreamFilter();
     CPPUNIT_ASSERT(!filter);
   }
@@ -348,10 +326,8 @@ void HttpResponseTest::testGetContentEncodingStreamFilter()
 void HttpResponseTest::testValidateResponse()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
-
-  httpHeader->setStatusCode(301);
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+  httpResponse.getHttpHeader()->setStatusCode(301);
 
   try {
     httpResponse.validateResponse();
@@ -359,8 +335,9 @@ void HttpResponseTest::testValidateResponse()
   } catch(Exception& e) {
   }
 
-  httpHeader->put(HttpHeader::LOCATION,
-                  "http://localhost/archives/aria2-1.0.0.tar.bz2");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LOCATION,
+     "http://localhost/archives/aria2-1.0.0.tar.bz2");
   try {
     httpResponse.validateResponse();
   } catch(Exception& e) {
@@ -371,21 +348,22 @@ void HttpResponseTest::testValidateResponse()
 void HttpResponseTest::testValidateResponse_good_range()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
 
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  SharedHandle<Piece> p(new Piece(1, 1024*1024));
-  SharedHandle<Segment> segment(new PiecedSegment(1024*1024, p));
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+
+  auto httpRequest = make_unique<HttpRequest>();
+  auto p = std::make_shared<Piece>(1, 1024*1024);
+  auto segment = std::make_shared<PiecedSegment>(1024*1024, p);
   httpRequest->setSegment(segment);
-  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
+  auto fileEntry = std::make_shared<FileEntry>("file", 1024*1024*10, 0);
   httpRequest->setFileEntry(fileEntry);
-  SharedHandle<Request> request(new Request());
+  auto request = std::make_shared<Request>();
   request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
-  httpResponse.setHttpRequest(httpRequest);
-  httpHeader->setStatusCode(206);
-  httpHeader->put(HttpHeader::CONTENT_RANGE, "bytes 1048576-10485760/10485760");
+  httpResponse.setHttpRequest(std::move(httpRequest));
+  httpResponse.getHttpHeader()->setStatusCode(206);
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_RANGE,
+                                    "bytes 1048576-10485760/10485760");
 
   try {
     httpResponse.validateResponse();
@@ -398,21 +376,22 @@ void HttpResponseTest::testValidateResponse_good_range()
 void HttpResponseTest::testValidateResponse_bad_range()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
 
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  SharedHandle<Piece> p(new Piece(1, 1024*1024));
-  SharedHandle<Segment> segment(new PiecedSegment(1024*1024, p));
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+
+  auto httpRequest = make_unique<HttpRequest>();
+  auto p = std::make_shared<Piece>(1, 1024*1024);
+  auto segment = std::make_shared<PiecedSegment>(1024*1024, p);
   httpRequest->setSegment(segment);
-  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
+  auto fileEntry = std::make_shared<FileEntry>("file", 1024*1024*10, 0);
   httpRequest->setFileEntry(fileEntry);
-  SharedHandle<Request> request(new Request());
+  auto request = std::make_shared<Request>();
   request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
-  httpResponse.setHttpRequest(httpRequest);
-  httpHeader->setStatusCode(206);
-  httpHeader->put(HttpHeader::CONTENT_RANGE, "bytes 0-10485760/10485761");
+  httpResponse.setHttpRequest(std::move(httpRequest));
+  httpResponse.getHttpHeader()->setStatusCode(206);
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_RANGE,
+                                    "bytes 0-10485760/10485761");
 
   try {
     httpResponse.validateResponse();
@@ -424,22 +403,22 @@ void HttpResponseTest::testValidateResponse_bad_range()
 void HttpResponseTest::testValidateResponse_chunked()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
 
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  SharedHandle<Piece> p(new Piece(1, 1024*1024));
-  SharedHandle<Segment> segment(new PiecedSegment(1024*1024, p));
+  auto httpRequest = make_unique<HttpRequest>();
+  auto p = std::make_shared<Piece>(1, 1024*1024);
+  auto segment = std::make_shared<PiecedSegment>(1024*1024, p);
   httpRequest->setSegment(segment);
-  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
+  auto fileEntry = std::make_shared<FileEntry>("file", 1024*1024*10, 0);
   httpRequest->setFileEntry(fileEntry);
-  SharedHandle<Request> request(new Request());
+  auto request = std::make_shared<Request>();
   request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
-  httpResponse.setHttpRequest(httpRequest);
-  httpHeader->setStatusCode(206);
-  httpHeader->put(HttpHeader::CONTENT_RANGE, "bytes 0-10485760/10485761");
-  httpHeader->put(HttpHeader::TRANSFER_ENCODING, "chunked");
+  httpResponse.setHttpRequest(std::move(httpRequest));
+  httpResponse.getHttpHeader()->setStatusCode(206);
+  httpResponse.getHttpHeader()->put(HttpHeader::CONTENT_RANGE,
+                                    "bytes 0-10485760/10485761");
+  httpResponse.getHttpHeader()->put(HttpHeader::TRANSFER_ENCODING, "chunked");
 
   // if transfer-encoding is specified, then range validation is skipped.
   try {
@@ -452,48 +431,51 @@ void HttpResponseTest::testValidateResponse_chunked()
 void HttpResponseTest::testValidateResponse_withIfModifiedSince()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
-  httpHeader->setStatusCode(304);
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  httpResponse.setHttpRequest(httpRequest);
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+  httpResponse.getHttpHeader()->setStatusCode(304);
+  auto httpRequest = make_unique<HttpRequest>();
+  httpResponse.setHttpRequest(std::move(httpRequest));
   try {
     httpResponse.validateResponse();
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(Exception& e) {
   }
+  httpRequest = make_unique<HttpRequest>();
   httpRequest->setIfModifiedSinceHeader("Fri, 16 Jul 2010 12:56:59 GMT");
+  httpResponse.setHttpRequest(std::move(httpRequest));
   httpResponse.validateResponse();
 }
 
 void HttpResponseTest::testProcessRedirect()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
 
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  SharedHandle<Request> request(new Request());
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+
+  auto httpRequest = make_unique<HttpRequest>();
+  auto request = std::make_shared<Request>();
   request->setUri("http://localhost/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
-  httpResponse.setHttpRequest(httpRequest);
+  httpResponse.setHttpRequest(std::move(httpRequest));
 
-  httpHeader->put(HttpHeader::LOCATION, "http://mirror/aria2-1.0.0.tar.bz2");
+  httpResponse.getHttpHeader()->put(HttpHeader::LOCATION,
+                                    "http://mirror/aria2-1.0.0.tar.bz2");
   httpResponse.processRedirect();
 
-  httpHeader->clearField();
+  httpResponse.getHttpHeader()->clearField();
 
   // Test for percent-encode
-  httpHeader->put(HttpHeader::LOCATION, "http://example.org/white space#aria2");
+  httpResponse.getHttpHeader()->put(HttpHeader::LOCATION,
+                                    "http://example.org/white space#aria2");
   httpResponse.processRedirect();
   CPPUNIT_ASSERT_EQUAL(std::string("http://example.org/white%20space"),
                        request->getCurrentUri());
 
-  httpHeader->clearField();
+  httpResponse.getHttpHeader()->clearField();
 
   // Give unsupported scheme
-  httpHeader->put(HttpHeader::LOCATION,
-                  "unsupported://mirror/aria2-1.0.0.tar.bz2");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LOCATION, "unsupported://mirror/aria2-1.0.0.tar.bz2");
   try {
     httpResponse.processRedirect();
     CPPUNIT_FAIL("DlRetryEx exception must be thrown.");
@@ -507,101 +489,113 @@ void HttpResponseTest::testProcessRedirect()
 void HttpResponseTest::testRetrieveCookie()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
 
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  SharedHandle<Request> request(new Request());
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+
+  auto httpRequest = make_unique<HttpRequest>();
+  auto request = std::make_shared<Request>();
   request->setUri("http://www.aria2.org/archives/aria2-1.0.0.tar.bz2");
   httpRequest->setRequest(request);
-  SharedHandle<CookieStorage> st(new CookieStorage());
-  httpRequest->setCookieStorage(st);
-  httpResponse.setHttpRequest(httpRequest);
+  CookieStorage  st;
+  httpRequest->setCookieStorage(&st);
+  httpResponse.setHttpRequest(std::move(httpRequest));
 
-  httpHeader->put(HttpHeader::SET_COOKIE,
-                  "k1=v1; expires=Sun, 10-Jun-2007 11:00:00 GMT;"
-                  "path=/; domain=.aria2.org;");
-  httpHeader->put(HttpHeader::SET_COOKIE,
-                  "k2=v2; expires=Sun, 01-Jan-38 00:00:00 GMT;"
-                  "path=/; domain=.aria2.org;");
-  httpHeader->put(HttpHeader::SET_COOKIE, "k3=v3;");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::SET_COOKIE,
+     "k1=v1; expires=Sun, 10-Jun-2007 11:00:00 GMT;"
+     "path=/; domain=.aria2.org;");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::SET_COOKIE,
+     "k2=v2; expires=Sun, 01-Jan-38 00:00:00 GMT;"
+     "path=/; domain=.aria2.org;");
+  httpResponse.getHttpHeader()->put(HttpHeader::SET_COOKIE, "k3=v3;");
 
   httpResponse.retrieveCookie();
 
-  CPPUNIT_ASSERT_EQUAL((size_t)2, st->size());
+  CPPUNIT_ASSERT_EQUAL((size_t)2, st.size());
 
-  std::vector<Cookie> cookies;
-  st->dumpCookie(std::back_inserter(cookies));
-  CPPUNIT_ASSERT_EQUAL(std::string("k2=v2"), cookies[0].toString());
-  CPPUNIT_ASSERT_EQUAL(std::string("k3=v3"), cookies[1].toString());
+  auto cookies = std::vector<const Cookie*>{};
+  st.dumpCookie(std::back_inserter(cookies));
+  std::sort(std::begin(cookies), std::end(cookies), CookieSorter());
+  CPPUNIT_ASSERT_EQUAL(std::string("k2=v2"), cookies[0]->toString());
+  CPPUNIT_ASSERT_EQUAL(std::string("k3=v3"), cookies[1]->toString());
 }
 
 void HttpResponseTest::testSupportsPersistentConnection()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
-  SharedHandle<HttpRequest> httpRequest(new HttpRequest());
-  httpResponse.setHttpRequest(httpRequest);
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+  httpResponse.setHttpRequest(make_unique<HttpRequest>());
 
-  httpHeader->setVersion("HTTP/1.1");
+  httpResponse.getHttpHeader()->setVersion("HTTP/1.1");
   CPPUNIT_ASSERT(httpResponse.supportsPersistentConnection());
-  httpHeader->put(HttpHeader::CONNECTION, "close");
+  httpResponse.getHttpHeader()->put(HttpHeader::CONNECTION, "close");
   CPPUNIT_ASSERT(!httpResponse.supportsPersistentConnection());
-  httpHeader->clearField();
-  httpHeader->put(HttpHeader::CONNECTION, "keep-alive");
+  httpResponse.getHttpHeader()->clearField();
+  httpResponse.getHttpHeader()->put(HttpHeader::CONNECTION, "keep-alive");
   CPPUNIT_ASSERT(httpResponse.supportsPersistentConnection());
-  httpHeader->clearField();
+  httpResponse.getHttpHeader()->clearField();
 
-  httpHeader->setVersion("HTTP/1.0");
+  httpResponse.getHttpHeader()->setVersion("HTTP/1.0");
   CPPUNIT_ASSERT(!httpResponse.supportsPersistentConnection());
-  httpHeader->put(HttpHeader::CONNECTION, "close");
+  httpResponse.getHttpHeader()->put(HttpHeader::CONNECTION, "close");
   CPPUNIT_ASSERT(!httpResponse.supportsPersistentConnection());
-  httpHeader->clearField();
-  httpHeader->put(HttpHeader::CONNECTION, "keep-alive");
+  httpResponse.getHttpHeader()->clearField();
+  httpResponse.getHttpHeader()->put(HttpHeader::CONNECTION, "keep-alive");
   CPPUNIT_ASSERT(httpResponse.supportsPersistentConnection());
-  httpHeader->clearField();
+  httpResponse.getHttpHeader()->clearField();
 
   // test proxy connection
-  SharedHandle<Request> proxyRequest(new Request());
-  httpRequest->setProxyRequest(proxyRequest);
+  auto httpRequest = make_unique<HttpRequest>();
+  httpRequest->setProxyRequest(std::make_shared<Request>());
+  httpResponse.setHttpRequest(std::move(httpRequest));
 
-  httpHeader->setVersion("HTTP/1.1");
+  httpResponse.getHttpHeader()->setVersion("HTTP/1.1");
   CPPUNIT_ASSERT(httpResponse.supportsPersistentConnection());
-  httpHeader->put(HttpHeader::CONNECTION, "close");
+  httpResponse.getHttpHeader()->put(HttpHeader::CONNECTION, "close");
   CPPUNIT_ASSERT(!httpResponse.supportsPersistentConnection());
-  httpHeader->clearField();
-  httpHeader->put(HttpHeader::CONNECTION, "keep-alive");
+  httpResponse.getHttpHeader()->clearField();
+  httpResponse.getHttpHeader()->put(HttpHeader::CONNECTION, "keep-alive");
   CPPUNIT_ASSERT(httpResponse.supportsPersistentConnection());
-  httpHeader->clearField();
+  httpResponse.getHttpHeader()->clearField();
 
-  httpHeader->setVersion("HTTP/1.0");
+  httpResponse.getHttpHeader()->setVersion("HTTP/1.0");
   CPPUNIT_ASSERT(!httpResponse.supportsPersistentConnection());
-  httpHeader->put(HttpHeader::CONNECTION, "close");
+  httpResponse.getHttpHeader()->put(HttpHeader::CONNECTION, "close");
   CPPUNIT_ASSERT(!httpResponse.supportsPersistentConnection());
-  httpHeader->clearField();
-  httpHeader->put(HttpHeader::CONNECTION, "keep-alive");
+  httpResponse.getHttpHeader()->clearField();
+  httpResponse.getHttpHeader()->put(HttpHeader::CONNECTION, "keep-alive");
   CPPUNIT_ASSERT(httpResponse.supportsPersistentConnection());
-  httpHeader->clearField();
+  httpResponse.getHttpHeader()->clearField();
 }
 
 void HttpResponseTest::testGetMetalinKHttpEntries()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
-  SharedHandle<Option> option(new Option());
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+  std::shared_ptr<Option> option(new Option());
 
-  httpHeader->put(HttpHeader::LINK,
-                  "<http://uri1/>; rel=duplicate; pri=1; pref; geo=JP");
-  httpHeader->put(HttpHeader::LINK,
-                  "<http://uri2/>; rel=duplicate");
-  httpHeader->put(HttpHeader::LINK,
-                  "<http://uri3/>;;;;;;;;rel=duplicate;;;;;pri=2;;;;;");
-  httpHeader->put(HttpHeader::LINK, "<http://uri4/>;rel=duplicate;=pri=1;pref");
-  httpHeader->put(HttpHeader::LINK, "<http://describedby>; rel=describedby");
-  httpHeader->put(HttpHeader::LINK, "<http://norel/>");
-  httpHeader->put(HttpHeader::LINK, "<baduri>; rel=duplicate; pri=-1;");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LINK,
+     "<http://uri1/>; rel=duplicate; pri=1; pref; geo=JP");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LINK,
+     "<http://uri2/>; rel=duplicate");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LINK,
+     "<http://uri3/>;;;;;;;;rel=duplicate;;;;;pri=2;;;;;");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LINK,
+     "<http://uri4/>;rel=duplicate;=pri=1;pref");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LINK,
+     "<http://describedby>; rel=describedby");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LINK,
+     "<http://norel/>");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::LINK,
+     "<baduri>; rel=duplicate; pri=-1;");
   std::vector<MetalinkHttpEntry> result;
   httpResponse.getMetalinKHttpEntries(result, option);
   CPPUNIT_ASSERT_EQUAL((size_t)5, result.size());
@@ -641,30 +635,39 @@ void HttpResponseTest::testGetMetalinKHttpEntries()
 void HttpResponseTest::testGetDigest()
 {
   HttpResponse httpResponse;
-  SharedHandle<HttpHeader> httpHeader(new HttpHeader());
-  httpResponse.setHttpHeader(httpHeader);
-  SharedHandle<Option> option(new Option());
+  httpResponse.setHttpHeader(make_unique<HttpHeader>());
+  std::shared_ptr<Option> option(new Option());
   // Python binascii.hexlify(base64.b64decode(B64ED_HASH)) is handy to
   // retrieve ascii hex hash string.
-  httpHeader->put(HttpHeader::DIGEST, "SHA-1=82AD8itGL/oYQ5BTPFANiYnp9oE=");
-  httpHeader->put(HttpHeader::DIGEST, "NOT_SUPPORTED");
-  httpHeader->put(HttpHeader::DIGEST,
-                  "SHA-224=rQdowoLHQJTMVZ3rF7vmYOIzUXlu7F+FcMbPnA==");
-  httpHeader->put(HttpHeader::DIGEST,
-                  "SHA-224=6Ik6LNZ1iPy6cbmlKO4NHfvxzaiurmHilMyhGA==");
-  httpHeader->put(HttpHeader::DIGEST,
-                  "SHA-256=+D8nGudz3G/kpkVKQeDrI3xD57v0UeQmzGCZOk03nsU=,"
-                  "MD5=LJDK2+9ClF8Nz/K5WZd/+A==");
+  httpResponse.getHttpHeader()->put(HttpHeader::DIGEST,
+                                    "SHA-1=82AD8itGL/oYQ5BTPFANiYnp9oE=");
+  httpResponse.getHttpHeader()->put(HttpHeader::DIGEST, "NOT_SUPPORTED");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::DIGEST,
+     "SHA-224=rQdowoLHQJTMVZ3rF7vmYOIzUXlu7F+FcMbPnA==");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::DIGEST,
+     "SHA-224=6Ik6LNZ1iPy6cbmlKO4NHfvxzaiurmHilMyhGA==");
+  httpResponse.getHttpHeader()->put
+    (HttpHeader::DIGEST,
+     "SHA-256=+D8nGudz3G/kpkVKQeDrI3xD57v0UeQmzGCZOk03nsU=,"
+     "MD5=LJDK2+9ClF8Nz/K5WZd/+A==");
   std::vector<Checksum> result;
   httpResponse.getDigest(result);
+#ifdef USE_INTERNAL_MD
+  CPPUNIT_ASSERT_EQUAL((size_t)2, result.size());
+#else
   CPPUNIT_ASSERT_EQUAL((size_t)3, result.size());
+#endif
 
   Checksum c = result[0];
+#ifndef USE_INTERNAL_MD
   CPPUNIT_ASSERT_EQUAL(std::string("sha-256"), c.getHashType());
   CPPUNIT_ASSERT_EQUAL(std::string("f83f271ae773dc6fe4a6454a41e0eb237c43e7bbf451e426cc60993a4d379ec5"),
                        util::toHex(c.getDigest()));
 
   c = result[1];
+#endif
   CPPUNIT_ASSERT_EQUAL(std::string("sha-1"), c.getHashType());
   CPPUNIT_ASSERT_EQUAL(std::string("f36003f22b462ffa184390533c500d8989e9f681"),
                        util::toHex(c.getDigest()));
