@@ -3,6 +3,7 @@
 #include <cppunit/extensions/HelperMacros.h>
 
 #include "array_fun.h"
+#include "BitfieldMan.h"
 
 namespace aria2 {
 
@@ -25,19 +26,23 @@ CPPUNIT_TEST_SUITE_REGISTRATION(LongestSequencePieceSelectorTest);
 void LongestSequencePieceSelectorTest::testSelect()
 {
   size_t A[] = { 1,2,3,4,7,10,11,12,13,14,15,100,112,113,114 };
-  std::deque<size_t> indexes(&A[0], &A[arrayLength(A)]);
+  BitfieldMan bf(1024, 1024*256);
+  for(size_t i = 0; i < A2_ARRAY_LEN(A); ++i) {
+    bf.setBit(A[i]);
+  }
 
   LongestSequencePieceSelector selector;
   size_t index;
 
-  CPPUNIT_ASSERT(selector.select(index, indexes));
+  CPPUNIT_ASSERT(selector.select(index, bf.getBitfield(), bf.countBlock()));
   CPPUNIT_ASSERT_EQUAL((size_t)15, index);
 
-  std::deque<size_t> zeroindexes;
-  CPPUNIT_ASSERT(!selector.select(index, zeroindexes));
+  bf.clearAllBit();
+  CPPUNIT_ASSERT(!selector.select(index, bf.getBitfield(), bf.countBlock()));
 
-  std::deque<size_t> oneseq(&A[0], &A[4]);
-  CPPUNIT_ASSERT(selector.select(index, oneseq));
+  // See it works in just one range
+  bf.setBitRange(1, 4);
+  CPPUNIT_ASSERT(selector.select(index, bf.getBitfield(), bf.countBlock()));
   CPPUNIT_ASSERT_EQUAL((size_t)4, index);
 }
 
