@@ -1,8 +1,8 @@
 #include "common.h"
 
 #include <string>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "Cookie.h"
 #include "WrDiskCacheEntry.h"
 #include "GroupId.h"
@@ -21,17 +21,17 @@ std::string readFile(const std::string& path);
 
 class CookieSorter {
 public:
-  bool operator()(const Cookie& lhs, const Cookie& rhs) const
+  bool operator()(const Cookie* lhs, const Cookie* rhs) const
   {
-    if(lhs.getDomain() == rhs.getDomain()) {
-      return lhs.getName() < rhs.getName();
+    if(lhs->getDomain() == rhs->getDomain()) {
+      return lhs->getName() < rhs->getName();
     } else {
-      return lhs.getDomain() < rhs.getDomain();
+      return lhs->getDomain() < rhs->getDomain();
     }
   }
 };
 
-Cookie createCookie
+std::unique_ptr<Cookie> createCookie
 (const std::string& name,
  const std::string& value,
  const std::string& domain,
@@ -39,7 +39,7 @@ Cookie createCookie
  const std::string& path,
  bool secure);
 
-Cookie createCookie
+std::unique_ptr<Cookie> createCookie
 (const std::string& name,
  const std::string& value,
  time_t expiryTime,
@@ -52,27 +52,39 @@ std::string fromHex(const std::string& s);
 
 #ifdef ENABLE_MESSAGE_DIGEST
 // Returns hex digest of contents of file denoted by filename.
-std::string fileHexDigest
-(const SharedHandle<MessageDigest>& ctx, const std::string& filename);
+std::string fileHexDigest(MessageDigest* ctx, const std::string& filename);
 #endif // ENABLE_MESSAGE_DIGEST
 
 WrDiskCacheEntry::DataCell* createDataCell(int64_t goff,
                                            const char* data,
                                            size_t offset = 0);
 
-SharedHandle<RequestGroup> findReservedGroup
-(const SharedHandle<RequestGroupMan>& rgman, a2_gid_t gid);
+std::shared_ptr<RequestGroup> findReservedGroup
+(RequestGroupMan* rgman, a2_gid_t gid);
 
-SharedHandle<RequestGroup> getReservedGroup
-(const SharedHandle<RequestGroupMan>& rgman, size_t index);
+std::shared_ptr<RequestGroup> getReservedGroup
+(RequestGroupMan* rgman, size_t index);
 
-SharedHandle<RequestGroup> createRequestGroup(int32_t pieceLength,
+std::shared_ptr<RequestGroup> createRequestGroup(int32_t pieceLength,
                                               int64_t totalLength,
                                               const std::string& path,
                                               const std::string& uri,
-                                              const SharedHandle<Option>& opt);
+                                              const std::shared_ptr<Option>& opt);
 
-SharedHandle<DownloadResult> createDownloadResult
+std::shared_ptr<DownloadResult> createDownloadResult
 (error_code::Value result, const std::string& uri);
 
+namespace {
+template<typename V, typename T>
+bool derefFind(const V& v, const T& t)
+{
+  for(auto i : v) {
+    if(*i == *t) {
+      return true;
+    }
+  }
+  return false;
+}
+} // namespace
+
 } // namespace aria2
