@@ -64,6 +64,7 @@ class UtilTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testUitos);
   CPPUNIT_TEST(testNtoh64);
   CPPUNIT_TEST(testPercentEncode);
+  CPPUNIT_TEST(testPercentEncodeMini);
   CPPUNIT_TEST(testHtmlEscape);
   CPPUNIT_TEST(testJoinPath);
   CPPUNIT_TEST(testParseIndexPath);
@@ -132,6 +133,7 @@ public:
   void testUitos();
   void testNtoh64();
   void testPercentEncode();
+  void testPercentEncodeMini();
   void testHtmlEscape();
   void testJoinPath();
   void testParseIndexPath();
@@ -266,33 +268,32 @@ void UtilTest::testLstripIter_char()
 }
 
 void UtilTest::testDivide() {
-  std::pair<Sip, Sip> p1;
   std::string s = "name=value";
-  util::divide(p1, s.begin(), s.end(), '=');
+  auto p1 = util::divide(std::begin(s), std::end(s), '=');
   CPPUNIT_ASSERT_EQUAL(std::string("name"),
                        std::string(p1.first.first, p1.first.second));
   CPPUNIT_ASSERT_EQUAL(std::string("value"),
                        std::string(p1.second.first, p1.second.second));
   s = " name = value ";
-  util::divide(p1, s.begin(), s.end(), '=');
+  p1 = util::divide(std::begin(s), std::end(s), '=');
   CPPUNIT_ASSERT_EQUAL(std::string("name"),
                        std::string(p1.first.first, p1.first.second));
   CPPUNIT_ASSERT_EQUAL(std::string("value"),
                        std::string(p1.second.first, p1.second.second));
   s = "=value";
-  util::divide(p1, s.begin(), s.end(), '=');
+  p1 = util::divide(std::begin(s), std::end(s), '=');
   CPPUNIT_ASSERT_EQUAL(std::string(""),
                        std::string(p1.first.first, p1.first.second));
   CPPUNIT_ASSERT_EQUAL(std::string("value"),
                        std::string(p1.second.first, p1.second.second));
   s = "name=";
-  util::divide(p1, s.begin(), s.end(), '=');
+  p1 = util::divide(std::begin(s), std::end(s), '=');
   CPPUNIT_ASSERT_EQUAL(std::string("name"),
                        std::string(p1.first.first, p1.first.second));
   CPPUNIT_ASSERT_EQUAL(std::string(""),
                        std::string(p1.second.first, p1.second.second));
   s = "name";
-  util::divide(p1, s.begin(), s.end(), '=');
+  p1 = util::divide(std::begin(s), std::end(s), '=');
   CPPUNIT_ASSERT_EQUAL(std::string("name"),
                        std::string(p1.first.first, p1.first.second));
   CPPUNIT_ASSERT_EQUAL(std::string(""),
@@ -1566,9 +1567,9 @@ void UtilTest::testAbbrevSize()
 void UtilTest::testToStream()
 {
   std::ostringstream os;
-  SharedHandle<FileEntry> f1(new FileEntry("aria2.tar.bz2", 12300, 0));
-  SharedHandle<FileEntry> f2(new FileEntry("aria2.txt", 556, 0));
-  std::deque<SharedHandle<FileEntry> > entries;
+  std::shared_ptr<FileEntry> f1(new FileEntry("aria2.tar.bz2", 12300, 0));
+  std::shared_ptr<FileEntry> f2(new FileEntry("aria2.txt", 556, 0));
+  std::deque<std::shared_ptr<FileEntry> > entries;
   entries.push_back(f1);
   entries.push_back(f2);
   const char* filename = A2_TEST_OUT_DIR"/aria2_UtilTest_testToStream";
@@ -1791,7 +1792,7 @@ void UtilTest::testParseLLIntNoThrow()
 
 void UtilTest::testToString_binaryStream()
 {
-  SharedHandle<DiskWriter> dw(new ByteArrayDiskWriter());
+  std::shared_ptr<DiskWriter> dw(new ByteArrayDiskWriter());
   std::string data(16*1024+256, 'a');
   dw->initAndOpenFile();
   dw->writeData((const unsigned char*)data.c_str(), data.size(), 0);
@@ -1880,6 +1881,12 @@ void UtilTest::testPercentEncode()
   CPPUNIT_ASSERT_EQUAL(std::string("1%5EA%20"), util::percentEncode("1^A "));
 }
 
+void UtilTest::testPercentEncodeMini()
+{
+  CPPUNIT_ASSERT_EQUAL(std::string("%80"),
+                       util::percentEncodeMini({(char)0x80}));
+}
+
 void UtilTest::testHtmlEscape()
 {
   CPPUNIT_ASSERT_EQUAL(std::string("aria2&lt;&gt;&quot;&#39;util"),
@@ -1891,28 +1898,31 @@ void UtilTest::testJoinPath()
   const std::string dir1dir2file[] = { "dir1", "dir2", "file" };
   CPPUNIT_ASSERT_EQUAL
     (std::string("dir1/dir2/file"),
-     util::joinPath(vbegin(dir1dir2file), vend(dir1dir2file)));
+     util::joinPath(std::begin(dir1dir2file), std::end(dir1dir2file)));
 
   const std::string dirparentfile[] = { "dir", "..", "file" };
   CPPUNIT_ASSERT_EQUAL
     (std::string("file"),
-     util::joinPath(vbegin(dirparentfile), vend(dirparentfile)));
+     util::joinPath(std::begin(dirparentfile), std::end(dirparentfile)));
 
   const std::string dirparentparentfile[] = { "dir", "..", "..", "file" };
   CPPUNIT_ASSERT_EQUAL
     (std::string("file"),
-     util::joinPath(vbegin(dirparentparentfile), vend(dirparentparentfile)));
+     util::joinPath(std::begin(dirparentparentfile),
+                    std::end(dirparentparentfile)));
 
   const std::string dirdotfile[] = { "dir", ".", "file" };
   CPPUNIT_ASSERT_EQUAL(std::string("dir/file"),
-                       util::joinPath(vbegin(dirdotfile), vend(dirdotfile)));
+                       util::joinPath(std::begin(dirdotfile),
+                                      std::end(dirdotfile)));
 
   const std::string empty[] = {};
   CPPUNIT_ASSERT_EQUAL(std::string(""), util::joinPath(&empty[0], &empty[0]));
 
   const std::string parentdot[] = { "..", "." };
   CPPUNIT_ASSERT_EQUAL(std::string(""),
-                       util::joinPath(vbegin(parentdot), vend(parentdot)));
+                       util::joinPath(std::begin(parentdot),
+                                      std::end(parentdot)));
 }
 
 void UtilTest::testParseIndexPath()
@@ -1987,7 +1997,7 @@ void UtilTest::testParsePrioritizePieceRange()
   //                      |                    |
   //                      file4                |
   size_t pieceLength = 1024;
-  std::vector<SharedHandle<FileEntry> > entries(4, SharedHandle<FileEntry>());
+  std::vector<std::shared_ptr<FileEntry> > entries(4, std::shared_ptr<FileEntry>());
   entries[0].reset(new FileEntry("file1", 1024, 0));
   entries[1].reset(new FileEntry("file2",2560,entries[0]->getLastOffset()));
   entries[2].reset(new FileEntry("file3",0,entries[1]->getLastOffset()));
